AshlplotR
================
Ian Matthews & Joshua Pike
2022-12-13

# Introduction

This script can be used to create bi-plots and Harker plots of all
tephra major elemental data. It includes interactive exploration of the
data and some discussion on identifying useful elements for
discrimination. Guidance for saving plots as .svg or .pdf files is also
provided. All the code used to produce this document is downloadable as
an RMarkdown file. To run this you will require r and RStudio. We are
happy for you to use, share and improve our code, but would ask that you
cite this as a poin tof origin for the plots.

## load packages

We first load in packages required to generate the plots and manipulate
the data. You may need to install these packages in r or update them to
work correctly.

``` r
library(ggplot2)
library(factoextra)
library(readr)
library(compositions)
library(gganimate)
library(cowplot)
library(tidyverse)
library(gt)
library(plotly)
library(svglite)
library(png)
library(here)
library(ggdensity)
```

## Load your data

Any data placed within the the data file of the r project can be read
using the code outlined below. As this is a Markdown script the ‘here’
package is used to ensure that project links do not break when moving
scripts around. As long as you start a new R project and drop this
script into it (using the structure outlined on the home page) then it
will work. Data files should be in .csv format and contain the group of
the tephra as column 1 under the title “id” (see example files for
reference). Loaded here are some data for core ODP-980 in the North
Atlantic and a terrestrial site from the UK called MT.

``` r
chem <- here::here("Data","Borrobol_type.csv") %>% read.csv()
```

## Check your data has loaded correctly

The following script produces a summary table of mean values and number
of analyses in your data.

``` r
chem_sum <- chem %>% group_by(id) %>% dplyr::summarise(                                            
                                                       count=n(),
                                                       SiO2.= mean(SiO2),
                                                       dev_1 = sd(SiO2),
                                                       TiO2. = mean(TiO2),
                                                       dev_2 = sd(TiO2),
                                                       Al2O3. = mean(Al2O3),
                                                       dev_3 = sd(Al2O3),
                                                       FeOt = mean(FeO),
                                                       dev_4 = sd(FeO),
                                                       MnO.= mean(MnO),
                                                       dev_5 = sd(MnO),
                                                       MgO.= mean(MgO),
                                                       dev_6 = sd(MgO),
                                                       CaO.= mean(CaO),
                                                       dev_7 = sd(CaO),
                                                       Na2O. = mean(Na2O),
                                                       dev_8 = sd(Na2O),
                                                       K2O. = mean(K2O),
                                                       dev_9 = sd(K2O),
                                                       P2O5. = mean(P2O5),
                                                       dev_10 = sd(P2O5),
                                                       Total.=mean(Total),
                                                       dev_11 = sd(Total))
chem_sum <- chem_sum %>% mutate(across(where(is.numeric), ~ round(., digits = 2)))
chem_sum %>% rename(layer = id, n = count , SiO2 = SiO2., sd1 = dev_1, TiO2 = TiO2. , sd2 = dev_2)
```

    ## # A tibble: 12 x 24
    ##    layer          n  SiO2   sd1  TiO2   sd2 Al2O3. dev_3  FeOt dev_4  MnO. dev_5
    ##    <chr>      <dbl> <dbl> <dbl> <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl>
    ##  1 Borrobol-~     2  76.4  0.39  0.07  0.01   13.0  0.42  0.95  0.01  0.05  0.01
    ##  2 Borrobol-~    12  76.4  0.41  0.12  0.01   12.7  0.34  1.56  0.12  0.04  0.01
    ##  3 Borrobol-~     8  76.4  0.59  0.12  0.01   12.6  0.57  1.47  0.15  0.04  0.01
    ##  4 Borrobol-~    35  75.9  0.31  0.15  0.01   12.9  0.2   1.58  0.13  0.04  0.01
    ##  5 Borrobol ~   124  76.4  0.36  0.13  0.01   12.7  0.21  1.55  0.11  0.04  0.01
    ##  6 Borrobol ~    13  76.5  0.25  0.13  0.01   12.8  0.23  1.53  0.1   0.04  0.01
    ##  7 Borrobol ~    21  76.5  0.54  0.12  0.02   12.9  0.48  1.36  0.16  0.04  0.01
    ##  8 CRUM1 597~    28  76.7  0.27  0.13  0.01   12.6  0.21  1.53  0.11  0.04  0.01
    ##  9 Fosen Tep~    10  76.9  0.49  0.12  0.01   12.3  0.43  1.54  0.2   0.05  0   
    ## 10 Hasseldal~   104  77.8  0.5   0.09  0.02   12.2  0.32  1.14  0.14  0.04  0.02
    ## 11 Hovsdalur~    23  77.9  0.53  0.12  0.02   12.3  0.12  1.16  0.12  0.04  0.02
    ## 12 Penifiler~   171  76.8  0.49  0.12  0.02   12.8  0.31  1.36  0.2   0.04  0.02
    ## # ... with 12 more variables: MgO. <dbl>, dev_6 <dbl>, CaO. <dbl>, dev_7 <dbl>,
    ## #   Na2O. <dbl>, dev_8 <dbl>, K2O. <dbl>, dev_9 <dbl>, P2O5. <dbl>,
    ## #   dev_10 <dbl>, Total. <dbl>, dev_11 <dbl>

``` r
gt(chem_sum)
```

<div id="jorgcwxqir" style="overflow-x:auto;overflow-y:auto;width:auto;height:auto;">
<style>html {
  font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;
}

#jorgcwxqir .gt_table {
  display: table;
  border-collapse: collapse;
  margin-left: auto;
  margin-right: auto;
  color: #333333;
  font-size: 16px;
  font-weight: normal;
  font-style: normal;
  background-color: #FFFFFF;
  width: auto;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #A8A8A8;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #A8A8A8;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
}

#jorgcwxqir .gt_heading {
  background-color: #FFFFFF;
  text-align: center;
  border-bottom-color: #FFFFFF;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
}

#jorgcwxqir .gt_title {
  color: #333333;
  font-size: 125%;
  font-weight: initial;
  padding-top: 4px;
  padding-bottom: 4px;
  border-bottom-color: #FFFFFF;
  border-bottom-width: 0;
}

#jorgcwxqir .gt_subtitle {
  color: #333333;
  font-size: 85%;
  font-weight: initial;
  padding-top: 0;
  padding-bottom: 4px;
  border-top-color: #FFFFFF;
  border-top-width: 0;
}

#jorgcwxqir .gt_bottom_border {
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
}

#jorgcwxqir .gt_col_headings {
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
}

#jorgcwxqir .gt_col_heading {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: normal;
  text-transform: inherit;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: bottom;
  padding-top: 5px;
  padding-bottom: 6px;
  padding-left: 5px;
  padding-right: 5px;
  overflow-x: hidden;
}

#jorgcwxqir .gt_column_spanner_outer {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: normal;
  text-transform: inherit;
  padding-top: 0;
  padding-bottom: 0;
  padding-left: 4px;
  padding-right: 4px;
}

#jorgcwxqir .gt_column_spanner_outer:first-child {
  padding-left: 0;
}

#jorgcwxqir .gt_column_spanner_outer:last-child {
  padding-right: 0;
}

#jorgcwxqir .gt_column_spanner {
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  vertical-align: bottom;
  padding-top: 5px;
  padding-bottom: 6px;
  overflow-x: hidden;
  display: inline-block;
  width: 100%;
}

#jorgcwxqir .gt_group_heading {
  padding: 8px;
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  text-transform: inherit;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: middle;
}

#jorgcwxqir .gt_empty_group_heading {
  padding: 0.5px;
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  vertical-align: middle;
}

#jorgcwxqir .gt_from_md > :first-child {
  margin-top: 0;
}

#jorgcwxqir .gt_from_md > :last-child {
  margin-bottom: 0;
}

#jorgcwxqir .gt_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  margin: 10px;
  border-top-style: solid;
  border-top-width: 1px;
  border-top-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: middle;
  overflow-x: hidden;
}

#jorgcwxqir .gt_stub {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  text-transform: inherit;
  border-right-style: solid;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
  padding-left: 12px;
}

#jorgcwxqir .gt_summary_row {
  color: #333333;
  background-color: #FFFFFF;
  text-transform: inherit;
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
}

#jorgcwxqir .gt_first_summary_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
}

#jorgcwxqir .gt_grand_summary_row {
  color: #333333;
  background-color: #FFFFFF;
  text-transform: inherit;
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
}

#jorgcwxqir .gt_first_grand_summary_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  border-top-style: double;
  border-top-width: 6px;
  border-top-color: #D3D3D3;
}

#jorgcwxqir .gt_striped {
  background-color: rgba(128, 128, 128, 0.05);
}

#jorgcwxqir .gt_table_body {
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
}

#jorgcwxqir .gt_footnotes {
  color: #333333;
  background-color: #FFFFFF;
  border-bottom-style: none;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
}

#jorgcwxqir .gt_footnote {
  margin: 0px;
  font-size: 90%;
  padding: 4px;
}

#jorgcwxqir .gt_sourcenotes {
  color: #333333;
  background-color: #FFFFFF;
  border-bottom-style: none;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
}

#jorgcwxqir .gt_sourcenote {
  font-size: 90%;
  padding: 4px;
}

#jorgcwxqir .gt_left {
  text-align: left;
}

#jorgcwxqir .gt_center {
  text-align: center;
}

#jorgcwxqir .gt_right {
  text-align: right;
  font-variant-numeric: tabular-nums;
}

#jorgcwxqir .gt_font_normal {
  font-weight: normal;
}

#jorgcwxqir .gt_font_bold {
  font-weight: bold;
}

#jorgcwxqir .gt_font_italic {
  font-style: italic;
}

#jorgcwxqir .gt_super {
  font-size: 65%;
}

#jorgcwxqir .gt_footnote_marks {
  font-style: italic;
  font-weight: normal;
  font-size: 65%;
}
</style>
<table class="gt_table">
  
  <thead class="gt_col_headings">
    <tr>
      <th class="gt_col_heading gt_columns_bottom_border gt_left" rowspan="1" colspan="1">id</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">count</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">SiO2.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_1</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">TiO2.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_2</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Al2O3.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_3</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">FeOt</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_4</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">MnO.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_5</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">MgO.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_6</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">CaO.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_7</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Na2O.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_8</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">K2O.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_9</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">P2O5.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_10</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Total.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_11</th>
    </tr>
  </thead>
  <tbody class="gt_table_body">
    <tr><td class="gt_row gt_left">Borrobol-type Tephra GI-1a</td>
<td class="gt_row gt_right">2</td>
<td class="gt_row gt_right">76.37</td>
<td class="gt_row gt_right">0.39</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">13.04</td>
<td class="gt_row gt_right">0.42</td>
<td class="gt_row gt_right">0.95</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">0.69</td>
<td class="gt_row gt_right">0.18</td>
<td class="gt_row gt_right">4.01</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">4.77</td>
<td class="gt_row gt_right">0.21</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Borrobol-type Tephra GI-1e_pt1</td>
<td class="gt_row gt_right">12</td>
<td class="gt_row gt_right">76.38</td>
<td class="gt_row gt_right">0.41</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.72</td>
<td class="gt_row gt_right">0.34</td>
<td class="gt_row gt_right">1.56</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.08</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.81</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">4.13</td>
<td class="gt_row gt_right">0.15</td>
<td class="gt_row gt_right">3.92</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Borrobol-type Tephra GI-1e_pt2</td>
<td class="gt_row gt_right">8</td>
<td class="gt_row gt_right">76.42</td>
<td class="gt_row gt_right">0.59</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.64</td>
<td class="gt_row gt_right">0.57</td>
<td class="gt_row gt_right">1.47</td>
<td class="gt_row gt_right">0.15</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.84</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">4.16</td>
<td class="gt_row gt_right">0.20</td>
<td class="gt_row gt_right">3.99</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Borrobol-type:GS-2.1-RHY Tephra</td>
<td class="gt_row gt_right">35</td>
<td class="gt_row gt_right">75.87</td>
<td class="gt_row gt_right">0.31</td>
<td class="gt_row gt_right">0.15</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.91</td>
<td class="gt_row gt_right">0.20</td>
<td class="gt_row gt_right">1.58</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.96</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">4.27</td>
<td class="gt_row gt_right">0.15</td>
<td class="gt_row gt_right">3.94</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Borrobol Tephra</td>
<td class="gt_row gt_right">124</td>
<td class="gt_row gt_right">76.43</td>
<td class="gt_row gt_right">0.36</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.74</td>
<td class="gt_row gt_right">0.21</td>
<td class="gt_row gt_right">1.55</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.08</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.78</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">4.26</td>
<td class="gt_row gt_right">0.21</td>
<td class="gt_row gt_right">3.94</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Borrobol Tephra-Sweden</td>
<td class="gt_row gt_right">13</td>
<td class="gt_row gt_right">76.50</td>
<td class="gt_row gt_right">0.25</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.76</td>
<td class="gt_row gt_right">0.23</td>
<td class="gt_row gt_right">1.53</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.77</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">4.24</td>
<td class="gt_row gt_right">0.32</td>
<td class="gt_row gt_right">3.96</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Borrobol Tephra - ASHIK</td>
<td class="gt_row gt_right">21</td>
<td class="gt_row gt_right">76.46</td>
<td class="gt_row gt_right">0.54</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">12.92</td>
<td class="gt_row gt_right">0.48</td>
<td class="gt_row gt_right">1.36</td>
<td class="gt_row gt_right">0.16</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.06</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.70</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">4.21</td>
<td class="gt_row gt_right">0.51</td>
<td class="gt_row gt_right">3.95</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">CRUM1 597 Tephra</td>
<td class="gt_row gt_right">28</td>
<td class="gt_row gt_right">76.67</td>
<td class="gt_row gt_right">0.27</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.59</td>
<td class="gt_row gt_right">0.21</td>
<td class="gt_row gt_right">1.53</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.77</td>
<td class="gt_row gt_right">0.06</td>
<td class="gt_row gt_right">4.30</td>
<td class="gt_row gt_right">0.14</td>
<td class="gt_row gt_right">3.91</td>
<td class="gt_row gt_right">0.09</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Fosen Tephra</td>
<td class="gt_row gt_right">10</td>
<td class="gt_row gt_right">76.88</td>
<td class="gt_row gt_right">0.49</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.31</td>
<td class="gt_row gt_right">0.43</td>
<td class="gt_row gt_right">1.54</td>
<td class="gt_row gt_right">0.20</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.70</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">4.30</td>
<td class="gt_row gt_right">0.14</td>
<td class="gt_row gt_right">4.02</td>
<td class="gt_row gt_right">0.30</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Hasseldalen Tephra</td>
<td class="gt_row gt_right">104</td>
<td class="gt_row gt_right">77.75</td>
<td class="gt_row gt_right">0.50</td>
<td class="gt_row gt_right">0.09</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">12.15</td>
<td class="gt_row gt_right">0.32</td>
<td class="gt_row gt_right">1.14</td>
<td class="gt_row gt_right">0.14</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.51</td>
<td class="gt_row gt_right">0.09</td>
<td class="gt_row gt_right">4.03</td>
<td class="gt_row gt_right">0.27</td>
<td class="gt_row gt_right">4.22</td>
<td class="gt_row gt_right">0.24</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Hovsdalur Tephra</td>
<td class="gt_row gt_right">23</td>
<td class="gt_row gt_right">77.88</td>
<td class="gt_row gt_right">0.53</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">12.27</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">1.16</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.49</td>
<td class="gt_row gt_right">0.06</td>
<td class="gt_row gt_right">3.61</td>
<td class="gt_row gt_right">0.24</td>
<td class="gt_row gt_right">4.38</td>
<td class="gt_row gt_right">0.60</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">Penifiler Tephra</td>
<td class="gt_row gt_right">171</td>
<td class="gt_row gt_right">76.78</td>
<td class="gt_row gt_right">0.49</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">12.77</td>
<td class="gt_row gt_right">0.31</td>
<td class="gt_row gt_right">1.36</td>
<td class="gt_row gt_right">0.20</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.69</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">4.10</td>
<td class="gt_row gt_right">0.40</td>
<td class="gt_row gt_right">4.02</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
  </tbody>
  
  
</table>
</div>

## Make TAS calculations

To calculate for the TAS plot the data require normalisation of the
data. The rest of the script uses unnormalised data for plotting, but
the code below can be used to normalise other data also by replacing the
element to be normalise.

``` r
TAS_x <- (100/ chem [["Total"]]) * chem [["SiO2"]]
TAS_y <- (100/ chem [["Total"]]) * (chem [["K2O"]] + chem [["Na2O"]])

chem <- cbind(chem, TAS_x, TAS_y)
```

# Filtering mixed datasets

It is possible your datasheet contains multiple types of tephra which
would benefit from filtering before plotting. I suggest this is carried
out by using silica values as a divisor. Rhyolites \>69% silica is a
case for this. However, it might be worth plotting everything first
before then selecting a filter to ensure vital data is not being
excluded.

``` r
chem <- filter(chem, SiO2 >68)
```

# Plotting the data

First we generate a series of plots from all possible pairs of elements.

``` r
p1 <- ggplot(chem, aes(x = TAS_x, y = TAS_y, fill = id, shape = id))
p2 <- ggplot(chem, aes(x = SiO2, y = TiO2, fill = id, shape = id))
p3 <- ggplot(chem, aes(x = SiO2, y = Al2O3, fill = id, shape = id))
p4 <- ggplot(chem, aes(x = SiO2, y = FeO,  fill = id, shape = id))
p5 <- ggplot(chem, aes(x = SiO2, y = MnO,  fill = id, shape = id))
p6 <- ggplot(chem, aes(x = SiO2, y = MgO,  fill = id, shape = id))
p7 <- ggplot(chem, aes(x = SiO2, y = CaO,  fill = id, shape = id))
p8 <- ggplot(chem, aes(x = SiO2, y = Na2O,  fill = id, shape = id))
p9 <- ggplot(chem, aes(x = SiO2, y = K2O,  fill = id, shape = id))
p47 <- ggplot(chem, aes(x = SiO2, y = K2O, fill = id, shape = id))
p10 <- ggplot(chem, aes(x = SiO2, y = P2O5,  fill = id, shape = id))
p11 <- ggplot(chem, aes(x = TiO2, y = Al2O3,  fill = id, shape = id))
p12 <- ggplot(chem, aes(x = TiO2, y = FeO,  fill = id, shape = id))
p13 <- ggplot(chem, aes(x = TiO2, y = MnO,  fill = id, shape = id))
p14 <- ggplot(chem, aes(x = TiO2, y = MgO,  fill = id, shape = id))
p15 <- ggplot(chem, aes(x = TiO2, y = CaO,  fill = id, shape = id))
p16 <- ggplot(chem, aes(x = TiO2, y = Na2O,  fill = id, shape = id))
p17 <- ggplot(chem, aes(x = TiO2, y = K2O,  fill = id, shape = id))
p18 <- ggplot(chem, aes(x = TiO2, y = P2O5,  fill = id, shape = id))
p19 <- ggplot(chem, aes(x = Al2O3, y = FeO,  fill = id, shape = id))
p20 <- ggplot(chem, aes(x = Al2O3, y = MnO,  fill = id, shape = id))
p21 <- ggplot(chem, aes(x = Al2O3, y = MgO,  fill = id, shape = id))
p22 <- ggplot(chem, aes(x = Al2O3, y = CaO,  fill = id, shape = id))
p23 <- ggplot(chem, aes(x = Al2O3, y = Na2O,  fill = id, shape = id))
p24 <- ggplot(chem, aes(x = Al2O3, y = K2O,  fill = id, shape = id))
p25 <- ggplot(chem, aes(x = Al2O3, y = P2O5,  fill = id, shape = id))
p26 <- ggplot(chem, aes(x = FeO, y = MnO,  fill = id, shape = id))
p27 <- ggplot(chem, aes(x = FeO, y = MgO,  fill = id, shape = id))
p28 <- ggplot(chem, aes(x = FeO, y = CaO,  fill = id, shape = id))
p29 <- ggplot(chem, aes(x = FeO, y = Na2O,  fill = id, shape = id))
p30 <- ggplot(chem, aes(x = FeO, y = K2O,  fill = id, shape = id))
p31 <- ggplot(chem, aes(x = FeO, y = P2O5,  fill = id, shape = id))
p32 <- ggplot(chem, aes(x = MnO, y = MgO,  fill = id, shape = id))
p33 <- ggplot(chem, aes(x = MnO, y = CaO,  fill = id, shape = id))
p34 <- ggplot(chem, aes(x = MnO, y = Na2O,  fill = id, shape = id))
p35 <- ggplot(chem, aes(x = MnO, y = K2O,  fill = id, shape = id))
p36 <- ggplot(chem, aes(x = MnO, y = P2O5,  fill = id, shape = id))
p37 <- ggplot(chem, aes(x = MgO, y = CaO,  fill = id, shape = id))
p38 <- ggplot(chem, aes(x = MgO, y = Na2O,  fill = id, shape = id))
p39 <- ggplot(chem, aes(x = MgO, y = K2O,  fill = id, shape = id))
p40 <- ggplot(chem, aes(x = MgO, y = P2O5,  fill = id, shape = id))
p41 <- ggplot(chem, aes(x = CaO, y = Na2O,  fill = id, shape = id))
p42 <- ggplot(chem, aes(x = CaO, y = K2O,  fill = id, shape = id))
p43 <- ggplot(chem, aes(x = CaO, y = P2O5,  fill = id, shape = id))
p44 <- ggplot(chem, aes(x = Na2O, y = K2O,  fill = id, shape = id))
p45 <- ggplot(chem, aes(x = Na2O, y = P2O5,  fill = id, shape = id))
p46 <- ggplot(chem, aes(x = K2O, y = P2O5,  fill = id, shape = id))
```

## Custom tephra theme

To ensure consistency and to provide a shortcut of coding it everytime
we set up\[ a custom tephra plotting theme. This means all of our plots
will have the same sized fonts etc…

``` r
Tephra.theme <-theme_bw()+theme(axis.title.x=element_text(size=16),
                                axis.title.y=element_text(size=16), 
                                axis.text.x=element_text(size=16),
                                axis.text.y=element_text(size=16))+
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank())
```

## Custom colour palette

The hex numbers below specify a custom colour palette for plotting.
These can be altered but were slected in order to help those with colour
vision deficiencies, and this should be considered when making changes.
At present 35 layers can be plotted using this pallete. If you have more
than 35 groups of data you will either have to specify additional
colours or consider splitting your dataset. The latter might be more
appropriate for improving the final clarity in the plots.

``` r
chempalette <- c("#209A24","#A769EE","#B4C428","#e30303","#000000","#EF139D","#3A700F","#5288FF","#E64701","#7F9AF5","#F36D20","#0B3075","#C18522","#9634A6","#1D7D46","#80ddb8","#7CBC92","#B10E89","#384B27","#F896FD","#C6A766","#20628E","#9C0323","#C3AFE0","#572D24","#FF79A2","#3E6D6F","#E18C63","#6F2B40","#DF9FB4", "#291700", "#7e005b", "#00597a" , "#7b003a",  "#470600")
```

The palette is known as “chempalette”.

# Figures

We first generate the simple bi-plots of each element. This initial
explorative approach facilitates data checking for unusual analyses and
permits the identification of elements with significant variability.

## TAS plot Le Maitre et al. (2002)

![](Title_files/figure-gfm/TAS%20plot-1.png)<!-- -->

## SiO2 VS TiO2

![](Title_files/figure-gfm/unnamed-chunk-9-1.png)<!-- -->

## SiO2 VS Al2O3

![](Title_files/figure-gfm/unnamed-chunk-10-1.png)<!-- -->

## SiO2 VS FeO

![](Title_files/figure-gfm/unnamed-chunk-11-1.png)<!-- -->

## SiO2 VS MnO

![](Title_files/figure-gfm/unnamed-chunk-12-1.png)<!-- -->

## SiO2 VS MgO

![](Title_files/figure-gfm/unnamed-chunk-13-1.png)<!-- -->

## SiO2 VS CaO

![](Title_files/figure-gfm/unnamed-chunk-14-1.png)<!-- -->

## SiO2 VS Na2O

![](Title_files/figure-gfm/unnamed-chunk-15-1.png)<!-- -->

## SiO2 VS K2O

![](Title_files/figure-gfm/unnamed-chunk-16-1.png)<!-- -->

![](Title_files/figure-gfm/unnamed-chunk-17-1.png)<!-- -->

## SiO2 VS P2O5

![](Title_files/figure-gfm/unnamed-chunk-18-1.png)<!-- -->

## TiO2 VS Al2O3

![](Title_files/figure-gfm/unnamed-chunk-19-1.png)<!-- -->

## TiO2 vs FeO

![](Title_files/figure-gfm/unnamed-chunk-20-1.png)<!-- -->

## TiO2 vs MnO

![](Title_files/figure-gfm/unnamed-chunk-21-1.png)<!-- -->

## TiO2 VS MgO

![](Title_files/figure-gfm/unnamed-chunk-22-1.png)<!-- -->

## TiO2 VS CaO

![](Title_files/figure-gfm/unnamed-chunk-23-1.png)<!-- -->

## TiO2 VS Na2O

![](Title_files/figure-gfm/unnamed-chunk-24-1.png)<!-- -->

## TiO2 VS K2O

![](Title_files/figure-gfm/unnamed-chunk-25-1.png)<!-- -->

## TiO2 VS P2O5

![](Title_files/figure-gfm/unnamed-chunk-26-1.png)<!-- -->

## Al2O3 VS FeO

![](Title_files/figure-gfm/unnamed-chunk-27-1.png)<!-- -->

## Al2O3 VS MnO

![](Title_files/figure-gfm/unnamed-chunk-28-1.png)<!-- -->

## Al2O3 VS MgO

``` r
p21 <- p21 + geom_point(aes(fill = id), size=4, alpha=0.8)+xlab("Al2O3 (wt%)")+ylab("MgO (wt%)")+scale_shape_manual(values=c(21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25))+
  scale_fill_manual(values = chempalette) +
  Tephra.theme
p21
```

![](Title_files/figure-gfm/unnamed-chunk-29-1.png)<!-- -->

## Al2O3 VS CaO

![](Title_files/figure-gfm/unnamed-chunk-30-1.png)<!-- -->

## Al2O3 VS Na2O

![](Title_files/figure-gfm/unnamed-chunk-31-1.png)<!-- -->

## Al2O3 VS K2O

![](Title_files/figure-gfm/unnamed-chunk-32-1.png)<!-- -->

## Al2O3 VS P2O5

![](Title_files/figure-gfm/unnamed-chunk-33-1.png)<!-- -->

## FeO VS MnO

![](Title_files/figure-gfm/unnamed-chunk-34-1.png)<!-- -->

## FeO vs MgO

![](Title_files/figure-gfm/unnamed-chunk-35-1.png)<!-- -->

## FeO vs CaO

![](Title_files/figure-gfm/unnamed-chunk-36-1.png)<!-- -->

## FeO VS Na2O

![](Title_files/figure-gfm/unnamed-chunk-37-1.png)<!-- -->

## FeO VS K2O

![](Title_files/figure-gfm/unnamed-chunk-38-1.png)<!-- -->

## FeO VS P2O5

![](Title_files/figure-gfm/unnamed-chunk-39-1.png)<!-- -->

## MnO VS MgO

![](Title_files/figure-gfm/unnamed-chunk-40-1.png)<!-- -->

## MnO VS CaO

![](Title_files/figure-gfm/unnamed-chunk-41-1.png)<!-- -->

## MnO VS Na2O

![](Title_files/figure-gfm/unnamed-chunk-42-1.png)<!-- -->

## MnO VS K2O

![](Title_files/figure-gfm/unnamed-chunk-43-1.png)<!-- -->

## MnO VS P2O5

![](Title_files/figure-gfm/unnamed-chunk-44-1.png)<!-- -->

## MgO VS CaO

![](Title_files/figure-gfm/unnamed-chunk-45-1.png)<!-- -->

## MgO VS Na2O

![](Title_files/figure-gfm/unnamed-chunk-46-1.png)<!-- -->

## MgO VS K2O

![](Title_files/figure-gfm/unnamed-chunk-47-1.png)<!-- -->

## MgO VS P2O5

![](Title_files/figure-gfm/unnamed-chunk-48-1.png)<!-- -->

## CaO VS Na2O

![](Title_files/figure-gfm/unnamed-chunk-49-1.png)<!-- -->

## CaO VS K2O

![](Title_files/figure-gfm/unnamed-chunk-50-1.png)<!-- -->

## CaO VS P2O5

![](Title_files/figure-gfm/unnamed-chunk-51-1.png)<!-- -->

## Na2O VS K2O

![](Title_files/figure-gfm/unnamed-chunk-52-1.png)<!-- -->

## Na2O VS P2O5

![](Title_files/figure-gfm/unnamed-chunk-53-1.png)<!-- -->

## K2O VS P2O5

![](Title_files/figure-gfm/unnamed-chunk-54-1.png)<!-- --> \# {-}

# Saving individual plots

We propose exporting your plots in .svg format. This is a vector file
format that preserves your data without size and scaling issues. It is
also readable and editable by software like Adobe Illustrator, Affinity
Designer, or free alternatives like Inkscape. .Using the file structure
presented here the all plots can be named appropriately and will be
saved in the Output -\> Plots folder. The width and height and dpi
outputs can be altered but override the preview functions in Rstudio and
we recommend that you view the svg file directly in you preferred image
editor to understand how it might look.

``` r
ggsave( filename = file.path("Script", "Output","Plots","fig1.svg"), plot = p1, width = 12, height = 6, dpi = 300)
```

# Multivariate analysis

Multivariate analysis via ordination is often a helpful way of exploring
your data. It permits the identification of useful elements for
discrimination and facilitates dimension reduction. Unfortunately,
percentage data can have problematic covariation and should be ‘freed’
from their compositional sum where possible. This can be achieved via
undertaking a centred log-ratio transform.

## centred log-ratio data table

``` r
chem_multi <- chem[ -c(1,6,11,12)] ## check columns to drop. Currently dropping id, MnO, P2O5, and Total to perform the clr transform.
chem_multi[is.na(chem_multi)] <- 0.005 # replace NAs with half the detection limit
chem_multi_clr <- clr(chem_multi)
cmclr <- as.data.frame(chem_multi_clr)
head(cmclr)
```

    ##      Sites   Country       age     SiO2    Al2O3        FeO       MnO       MgO
    ## 1 1.642765 0.3618315 0.3618315 3.093085 1.280336 -0.8536068 -4.394162 -3.397470
    ## 2 1.667643 0.3867093 0.3867093 3.117234 1.315663 -0.7952411 -4.167768 -3.906574
    ## 3 1.670452 0.3895177 0.3895177 3.118529 1.321894 -0.7552432 -4.170679 -3.650339
    ## 4 1.652841 0.3719074 0.3719074 3.100923 1.300696 -0.8593681 -4.363371 -3.507648
    ## 5 1.668021 0.3870871 0.3870871 3.116741 1.313589 -0.7739540 -4.443730 -3.871661
    ## 6 1.662949 0.3820153 0.3820153 3.110569 1.319112 -0.8551696 -4.348718 -3.800505
    ##         K2O      P2O5 Cl F    Total    TAS_x     TAS_y
    ## 1 0.1503695 -5.545292  0 0 3.357564 3.093085 0.8496628
    ## 2 0.1328745 -5.505815  0 0 3.382442 3.117234 0.8688885
    ## 3 0.1163958 -5.795532  0 0 3.385250 3.118529 0.8617065
    ## 4 0.1676347 -5.580336  0 0 3.367640 3.100923 0.8762521
    ## 5 0.1645933 -5.314697  0 0 3.382819 3.116741 0.8673628
    ## 6 0.1412168 -5.362589  0 0 3.377748 3.110569 0.8807886

We can summarise the importance of the resulting principal components by
summarizing how much of the total variance is captured by each principal
component.

## PCA summary

<div id="ftoqkssvlw" style="overflow-x:auto;overflow-y:auto;width:auto;height:auto;">
<style>html {
  font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;
}

#ftoqkssvlw .gt_table {
  display: table;
  border-collapse: collapse;
  margin-left: auto;
  margin-right: auto;
  color: #333333;
  font-size: 16px;
  font-weight: normal;
  font-style: normal;
  background-color: #FFFFFF;
  width: auto;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #A8A8A8;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #A8A8A8;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
}

#ftoqkssvlw .gt_heading {
  background-color: #FFFFFF;
  text-align: center;
  border-bottom-color: #FFFFFF;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
}

#ftoqkssvlw .gt_title {
  color: #333333;
  font-size: 125%;
  font-weight: initial;
  padding-top: 4px;
  padding-bottom: 4px;
  border-bottom-color: #FFFFFF;
  border-bottom-width: 0;
}

#ftoqkssvlw .gt_subtitle {
  color: #333333;
  font-size: 85%;
  font-weight: initial;
  padding-top: 0;
  padding-bottom: 4px;
  border-top-color: #FFFFFF;
  border-top-width: 0;
}

#ftoqkssvlw .gt_bottom_border {
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
}

#ftoqkssvlw .gt_col_headings {
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
}

#ftoqkssvlw .gt_col_heading {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: normal;
  text-transform: inherit;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: bottom;
  padding-top: 5px;
  padding-bottom: 6px;
  padding-left: 5px;
  padding-right: 5px;
  overflow-x: hidden;
}

#ftoqkssvlw .gt_column_spanner_outer {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: normal;
  text-transform: inherit;
  padding-top: 0;
  padding-bottom: 0;
  padding-left: 4px;
  padding-right: 4px;
}

#ftoqkssvlw .gt_column_spanner_outer:first-child {
  padding-left: 0;
}

#ftoqkssvlw .gt_column_spanner_outer:last-child {
  padding-right: 0;
}

#ftoqkssvlw .gt_column_spanner {
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  vertical-align: bottom;
  padding-top: 5px;
  padding-bottom: 6px;
  overflow-x: hidden;
  display: inline-block;
  width: 100%;
}

#ftoqkssvlw .gt_group_heading {
  padding: 8px;
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  text-transform: inherit;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: middle;
}

#ftoqkssvlw .gt_empty_group_heading {
  padding: 0.5px;
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  vertical-align: middle;
}

#ftoqkssvlw .gt_from_md > :first-child {
  margin-top: 0;
}

#ftoqkssvlw .gt_from_md > :last-child {
  margin-bottom: 0;
}

#ftoqkssvlw .gt_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  margin: 10px;
  border-top-style: solid;
  border-top-width: 1px;
  border-top-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: middle;
  overflow-x: hidden;
}

#ftoqkssvlw .gt_stub {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  text-transform: inherit;
  border-right-style: solid;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
  padding-left: 12px;
}

#ftoqkssvlw .gt_summary_row {
  color: #333333;
  background-color: #FFFFFF;
  text-transform: inherit;
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
}

#ftoqkssvlw .gt_first_summary_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
}

#ftoqkssvlw .gt_grand_summary_row {
  color: #333333;
  background-color: #FFFFFF;
  text-transform: inherit;
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
}

#ftoqkssvlw .gt_first_grand_summary_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  border-top-style: double;
  border-top-width: 6px;
  border-top-color: #D3D3D3;
}

#ftoqkssvlw .gt_striped {
  background-color: rgba(128, 128, 128, 0.05);
}

#ftoqkssvlw .gt_table_body {
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
}

#ftoqkssvlw .gt_footnotes {
  color: #333333;
  background-color: #FFFFFF;
  border-bottom-style: none;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
}

#ftoqkssvlw .gt_footnote {
  margin: 0px;
  font-size: 90%;
  padding: 4px;
}

#ftoqkssvlw .gt_sourcenotes {
  color: #333333;
  background-color: #FFFFFF;
  border-bottom-style: none;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
}

#ftoqkssvlw .gt_sourcenote {
  font-size: 90%;
  padding: 4px;
}

#ftoqkssvlw .gt_left {
  text-align: left;
}

#ftoqkssvlw .gt_center {
  text-align: center;
}

#ftoqkssvlw .gt_right {
  text-align: right;
  font-variant-numeric: tabular-nums;
}

#ftoqkssvlw .gt_font_normal {
  font-weight: normal;
}

#ftoqkssvlw .gt_font_bold {
  font-weight: bold;
}

#ftoqkssvlw .gt_font_italic {
  font-style: italic;
}

#ftoqkssvlw .gt_super {
  font-size: 65%;
}

#ftoqkssvlw .gt_footnote_marks {
  font-style: italic;
  font-weight: normal;
  font-size: 65%;
}
</style>
<table class="gt_table">
  
  <thead class="gt_col_headings">
    <tr>
      <th class="gt_col_heading gt_columns_bottom_border gt_left" rowspan="1" colspan="1">Information</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC1</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC2</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC3</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC4</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC5</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC6</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC7</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC8</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC9</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC10</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC11</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC12</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC13</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC14</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">PC15</th>
    </tr>
  </thead>
  <tbody class="gt_table_body">
    <tr><td class="gt_row gt_left">Standard deviation</td>
<td class="gt_row gt_right">2.774224</td>
<td class="gt_row gt_right">2.161704</td>
<td class="gt_row gt_right">1.413388</td>
<td class="gt_row gt_right">0.7742391</td>
<td class="gt_row gt_right">0.6098498</td>
<td class="gt_row gt_right">0.5320467</td>
<td class="gt_row gt_right">0.2919113</td>
<td class="gt_row gt_right">0.2413936</td>
<td class="gt_row gt_right">0.1237158</td>
<td class="gt_row gt_right">0.04010732</td>
<td class="gt_row gt_right">0.0306669</td>
<td class="gt_row gt_right">0.02399163</td>
<td class="gt_row gt_right">0.001124607</td>
<td class="gt_row gt_right">8.722397e-16</td>
<td class="gt_row gt_right">7.458682e-17</td></tr>
    <tr><td class="gt_row gt_left">Proportion of Variance</td>
<td class="gt_row gt_right">0.487620</td>
<td class="gt_row gt_right">0.296070</td>
<td class="gt_row gt_right">0.126570</td>
<td class="gt_row gt_right">0.0379800</td>
<td class="gt_row gt_right">0.0235600</td>
<td class="gt_row gt_right">0.0179400</td>
<td class="gt_row gt_right">0.0054000</td>
<td class="gt_row gt_right">0.0036900</td>
<td class="gt_row gt_right">0.0009700</td>
<td class="gt_row gt_right">0.00010000</td>
<td class="gt_row gt_right">0.0000600</td>
<td class="gt_row gt_right">0.00004000</td>
<td class="gt_row gt_right">0.000000000</td>
<td class="gt_row gt_right">0.000000e+00</td>
<td class="gt_row gt_right">0.000000e+00</td></tr>
    <tr><td class="gt_row gt_left">Cumulative Proportion</td>
<td class="gt_row gt_right">0.487620</td>
<td class="gt_row gt_right">0.783690</td>
<td class="gt_row gt_right">0.910260</td>
<td class="gt_row gt_right">0.9482400</td>
<td class="gt_row gt_right">0.9718100</td>
<td class="gt_row gt_right">0.9897400</td>
<td class="gt_row gt_right">0.9951400</td>
<td class="gt_row gt_right">0.9988300</td>
<td class="gt_row gt_right">0.9998000</td>
<td class="gt_row gt_right">0.99990000</td>
<td class="gt_row gt_right">0.9999600</td>
<td class="gt_row gt_right">1.00000000</td>
<td class="gt_row gt_right">1.000000000</td>
<td class="gt_row gt_right">1.000000e+00</td>
<td class="gt_row gt_right">1.000000e+00</td></tr>
  </tbody>
  
  
</table>
</div>

If this has captured a significant amount of variation it would be worth
plotting the output in order to identify the important variables in
determining the changes observed.

## PCA scores scree plot

![](Title_files/figure-gfm/unnamed-chunk-58-1.png)<!-- -->

This is a visual representation of the summary table showing the
percentage of the total variance explained by each dimension.

## Variables PCA plot

![](Title_files/figure-gfm/unnamed-chunk-59-1.png)<!-- -->

## Loadings dimension 1

![](Title_files/figure-gfm/unnamed-chunk-60-1.png)<!-- -->

## Loadings dimension 2

![](Title_files/figure-gfm/unnamed-chunk-61-1.png)<!-- -->

## PCA - Biplot

![](Title_files/figure-gfm/unnamed-chunk-62-1.png)<!-- -->

## PCA - grouped

    ## Scale for 'shape' is already present. Adding another scale for 'shape', which
    ## will replace the existing scale.

![](Title_files/figure-gfm/unnamed-chunk-63-1.png)<!-- -->

# 

# Interactive figures

The function ggplotly within the plotly package is extremely useful for
interactively examining data. ggplotly plots allow you to zoom into
areas of interest and turn layers on and off as well as saving low
resolution .png files of zoomed sections of your plots.We refer to these
as iPlots in order to distinguish them from static plots presented
above.

## iTAS plot

    ## PhantomJS not found. You can install it with webshot::install_phantomjs(). If it is installed, please make sure the phantomjs executable can be found via the PATH variable.

<div id="htmlwidget-9eceb20dc2a931752ae4" style="width:1000px;height:800px;" class="plotly html-widget"></div>
<script type="application/json" data-for="htmlwidget-9eceb20dc2a931752ae4">{"x":{"data":[{"x":[76.6414,76.0912],"y":[8.9477,8.6084],"text":["TAS_x: 76.6414<br />TAS_y: 8.9477<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","TAS_x: 76.0912<br />TAS_y: 8.6084<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(32,154,36,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[75.9663,76.5964,76.2677,75.9144,77.1796,76.2725,76.4748,76.2156,76.4877,77.0297,75.8987,76.2993],"y":[7.9816,8.0323,8.084,8.141,7.6947,7.944,8.2289,8.3605,8.06,7.8152,8.2957,7.977],"text":["TAS_x: 75.9663<br />TAS_y: 7.9816<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 76.5964<br />TAS_y: 8.0323<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 76.2677<br />TAS_y: 8.0840<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 75.9144<br />TAS_y: 8.1410<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 77.1796<br />TAS_y: 7.6947<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 76.2725<br />TAS_y: 7.9440<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 76.4748<br />TAS_y: 8.2289<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 76.2156<br />TAS_y: 8.3605<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 76.4877<br />TAS_y: 8.0600<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 77.0297<br />TAS_y: 7.8152<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 75.8987<br />TAS_y: 8.2957<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TAS_x: 76.2993<br />TAS_y: 7.9770<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(167,105,238,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77.0388,75.9572,75.9818,76.8359,77.4005,75.9243,75.9255,76.3097],"y":[8.1654,8.2465,7.7641,8.1353,8.2523,8.2704,8.2223,8.0978],"text":["TAS_x: 77.0388<br />TAS_y: 8.1654<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TAS_x: 75.9572<br />TAS_y: 8.2465<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TAS_x: 75.9818<br />TAS_y: 7.7641<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TAS_x: 76.8359<br />TAS_y: 8.1353<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TAS_x: 77.4005<br />TAS_y: 8.2523<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TAS_x: 75.9243<br />TAS_y: 8.2704<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TAS_x: 75.9255<br />TAS_y: 8.2223<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TAS_x: 76.3097<br />TAS_y: 8.0978<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(180,196,40,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.7014,75.8117,75.4456,75.8194,76.0043,75.7921,76.0123,75.8281,75.9908,75.5313,75.9727,75.7785,75.7024,75.6315,76.3654,76.2871,75.5975,75.4888,75.5051,75.5283,75.2661,76.5414,75.7045,76.0911,76.1363,76.0117,75.7475,75.7048,76.1105,75.9877,75.7893,75.8453,76.0402,75.8036,75.997],"y":[8.4198,8.1901,8.1623,8.0891,7.9498,8.2425,8.1702,8.2171,8.089,8.2249,8.3513,8.1005,8.3367,8.1944,8.1623,7.9413,8.1762,8.3152,7.844,8.5441,8.5509,8.2883,8.3339,7.9147,7.9701,8.3318,8.2553,8.0946,8.5069,8.267,8.022,8.2512,8.1156,8.2329,8.3131],"text":["TAS_x: 76.7014<br />TAS_y: 8.4198<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.8117<br />TAS_y: 8.1901<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.4456<br />TAS_y: 8.1623<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.8194<br />TAS_y: 8.0891<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.0043<br />TAS_y: 7.9498<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.7921<br />TAS_y: 8.2425<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.0123<br />TAS_y: 8.1702<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.8281<br />TAS_y: 8.2171<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.9908<br />TAS_y: 8.0890<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.5313<br />TAS_y: 8.2249<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.9727<br />TAS_y: 8.3513<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.7785<br />TAS_y: 8.1005<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.7024<br />TAS_y: 8.3367<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.6315<br />TAS_y: 8.1944<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.3654<br />TAS_y: 8.1623<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.2871<br />TAS_y: 7.9413<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.5975<br />TAS_y: 8.1762<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.4888<br />TAS_y: 8.3152<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.5051<br />TAS_y: 7.8440<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.5283<br />TAS_y: 8.5441<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.2661<br />TAS_y: 8.5509<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.5414<br />TAS_y: 8.2883<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.7045<br />TAS_y: 8.3339<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.0911<br />TAS_y: 7.9147<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.1363<br />TAS_y: 7.9701<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.0117<br />TAS_y: 8.3318<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.7475<br />TAS_y: 8.2553<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.7048<br />TAS_y: 8.0946<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.1105<br />TAS_y: 8.5069<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.9877<br />TAS_y: 8.2670<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.7893<br />TAS_y: 8.0220<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.8453<br />TAS_y: 8.2512<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 76.0402<br />TAS_y: 8.1156<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.8036<br />TAS_y: 8.2329<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TAS_x: 75.9970<br />TAS_y: 8.3131<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(227,3,3,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.7606,76.7047,76.5887,76.589,76.6379,76.5536,76.6994,76.5965,76.6224,76.5877,76.5152,76.7566,76.2112,76.3371,76.6227,76.3625,76.4496,76.771,77.0719,76.2737,76.6759,76.3208,76.2672,76.4286,76.4247,76.6663,76.9906,76.1981,76.84,76.9193,76.8105,76.7597,76.5003,77.1195,76.3105,76.7366,76.4287,77.1186,76.3377,77.0422,77.0535,76.7902,76.6552,76.8116,76.5644,76.4784,76.3839,76.1324,76.2735,76.145,75.9065,75.8918,76.1635,75.9462,76.0865,76.1092,76.311,76.2173,76.3627,76.5086,75.7198,76.473,76.115,76.4731,76.7982,76.2335,76.2971,76.5464,76.8259,76.2424,76.3306,75.9945,77.4177,76.2744,76.1804,76.576,76.4724,76.2179,75.7236,76.3775,75.2246,75.8105,76.0538,76.1644,76.462,76.7912,75.9229,76.8551,76.3213,76.4768,76.2874,76.4336,76.4625,76.5277,75.987,76.751,76.4131,76.0092,76.0202,76.3043,76.7104,76.1884,76.6914,76.3526,76.2636,76.0935,76.3767,76.23,75.9413,75.8843,75.9392,76.9263,76.9183,76.7868,76.5575,76.7074,76.8842,76.9126,76.683,76.8408,75.3745,76.2896,75.9703,76.3398],"y":[8.1439,8.098,8.0175,8.2795,8.0826,8.2335,8.0517,8.0937,8.2431,8.0102,8.3285,8.1045,8.3044,8.3236,8.1103,8.3016,8.2912,8.098,8.1901,8.2658,8.0516,8.1047,8.1804,8.0632,8.2035,8.2336,7.9303,8.1805,8.2952,8.2615,8.232,8.1324,8.1782,8.0429,8.552,8.0996,8.2429,7.8335,8.2718,8.1223,7.9532,8.3346,8.1588,8.0148,8.1928,8.0854,8.1655,8.2396,8.1315,8.0693,8.3941,8.2996,8.4906,8.5601,8.5451,8.4097,8.4331,8.2786,8.1237,8.1958,8.3656,8.107,8.2535,8.2827,8.1666,8.3876,8.1997,8.2512,8.1218,8.2932,8.3803,8.5861,8.256,8.3707,8.3871,8.4193,8.1744,8.3525,8.5256,8.1081,8.3455,8.4948,8.4829,8.1349,8.3125,7.7328,8.3264,7.9465,8.2634,8.2805,8.0546,8.2713,8.4055,8.3052,8.2822,8.1817,8.3113,8.3097,8.5363,8.2574,8.4076,8.2657,8.1891,8.3688,8.2521,8.2534,8.4502,8.2721,8.3546,8.4335,8.4547,7.5464,7.4535,7.8037,7.6756,7.6202,7.64,7.5984,7.6371,7.6068,8.6825,8.2786,8.6014,8.0413],"text":["TAS_x: 76.7606<br />TAS_y: 8.1439<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7047<br />TAS_y: 8.0980<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5887<br />TAS_y: 8.0175<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5890<br />TAS_y: 8.2795<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.6379<br />TAS_y: 8.0826<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5536<br />TAS_y: 8.2335<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.6994<br />TAS_y: 8.0517<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5965<br />TAS_y: 8.0937<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.6224<br />TAS_y: 8.2431<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5877<br />TAS_y: 8.0102<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5152<br />TAS_y: 8.3285<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7566<br />TAS_y: 8.1045<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2112<br />TAS_y: 8.3044<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3371<br />TAS_y: 8.3236<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.6227<br />TAS_y: 8.1103<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3625<br />TAS_y: 8.3016<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4496<br />TAS_y: 8.2912<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7710<br />TAS_y: 8.0980<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 77.0719<br />TAS_y: 8.1901<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2737<br />TAS_y: 8.2658<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.6759<br />TAS_y: 8.0516<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3208<br />TAS_y: 8.1047<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2672<br />TAS_y: 8.1804<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4286<br />TAS_y: 8.0632<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4247<br />TAS_y: 8.2035<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.6663<br />TAS_y: 8.2336<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.9906<br />TAS_y: 7.9303<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.1981<br />TAS_y: 8.1805<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.8400<br />TAS_y: 8.2952<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.9193<br />TAS_y: 8.2615<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.8105<br />TAS_y: 8.2320<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7597<br />TAS_y: 8.1324<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5003<br />TAS_y: 8.1782<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 77.1195<br />TAS_y: 8.0429<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3105<br />TAS_y: 8.5520<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7366<br />TAS_y: 8.0996<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4287<br />TAS_y: 8.2429<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 77.1186<br />TAS_y: 7.8335<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3377<br />TAS_y: 8.2718<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 77.0422<br />TAS_y: 8.1223<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 77.0535<br />TAS_y: 7.9532<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7902<br />TAS_y: 8.3346<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.6552<br />TAS_y: 8.1588<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.8116<br />TAS_y: 8.0148<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5644<br />TAS_y: 8.1928<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4784<br />TAS_y: 8.0854<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3839<br />TAS_y: 8.1655<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.1324<br />TAS_y: 8.2396<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2735<br />TAS_y: 8.1315<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.1450<br />TAS_y: 8.0693<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.9065<br />TAS_y: 8.3941<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.8918<br />TAS_y: 8.2996<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.1635<br />TAS_y: 8.4906<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.9462<br />TAS_y: 8.5601<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.0865<br />TAS_y: 8.5451<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.1092<br />TAS_y: 8.4097<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3110<br />TAS_y: 8.4331<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2173<br />TAS_y: 8.2786<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3627<br />TAS_y: 8.1237<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5086<br />TAS_y: 8.1958<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.7198<br />TAS_y: 8.3656<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4730<br />TAS_y: 8.1070<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.1150<br />TAS_y: 8.2535<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4731<br />TAS_y: 8.2827<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7982<br />TAS_y: 8.1666<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2335<br />TAS_y: 8.3876<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2971<br />TAS_y: 8.1997<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5464<br />TAS_y: 8.2512<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.8259<br />TAS_y: 8.1218<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2424<br />TAS_y: 8.2932<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3306<br />TAS_y: 8.3803<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.9945<br />TAS_y: 8.5861<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 77.4177<br />TAS_y: 8.2560<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2744<br />TAS_y: 8.3707<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.1804<br />TAS_y: 8.3871<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5760<br />TAS_y: 8.4193<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4724<br />TAS_y: 8.1744<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2179<br />TAS_y: 8.3525<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.7236<br />TAS_y: 8.5256<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3775<br />TAS_y: 8.1081<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.2246<br />TAS_y: 8.3455<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.8105<br />TAS_y: 8.4948<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.0538<br />TAS_y: 8.4829<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.1644<br />TAS_y: 8.1349<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4620<br />TAS_y: 8.3125<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7912<br />TAS_y: 7.7328<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.9229<br />TAS_y: 8.3264<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.8551<br />TAS_y: 7.9465<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3213<br />TAS_y: 8.2634<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4768<br />TAS_y: 8.2805<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2874<br />TAS_y: 8.0546<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4336<br />TAS_y: 8.2713<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4625<br />TAS_y: 8.4055<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5277<br />TAS_y: 8.3052<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.9870<br />TAS_y: 8.2822<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7510<br />TAS_y: 8.1817<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.4131<br />TAS_y: 8.3113<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.0092<br />TAS_y: 8.3097<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.0202<br />TAS_y: 8.5363<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3043<br />TAS_y: 8.2574<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7104<br />TAS_y: 8.4076<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.1884<br />TAS_y: 8.2657<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.6914<br />TAS_y: 8.1891<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3526<br />TAS_y: 8.3688<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2636<br />TAS_y: 8.2521<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.0935<br />TAS_y: 8.2534<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3767<br />TAS_y: 8.4502<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2300<br />TAS_y: 8.2721<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.9413<br />TAS_y: 8.3546<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.8843<br />TAS_y: 8.4335<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.9392<br />TAS_y: 8.4547<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.9263<br />TAS_y: 7.5464<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.9183<br />TAS_y: 7.4535<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7868<br />TAS_y: 7.8037<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.5575<br />TAS_y: 7.6756<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.7074<br />TAS_y: 7.6202<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.8842<br />TAS_y: 7.6400<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.9126<br />TAS_y: 7.5984<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.6830<br />TAS_y: 7.6371<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.8408<br />TAS_y: 7.6068<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.3745<br />TAS_y: 8.6825<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.2896<br />TAS_y: 8.2786<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 75.9703<br />TAS_y: 8.6014<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TAS_x: 76.3398<br />TAS_y: 8.0413<br />id: Borrobol Tephra<br />id: Borrobol Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(0,0,0,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.251,76.6084,76.3589,76.3348,76.5163,76.6116,76.5044,77.1132,76.3445,76.4144,76.2334,76.3172,76.836],"y":[8.4263,8.276,8.384,8.2332,8.2896,7.5159,8.3159,8.2658,8.412,8.122,8.2749,8.3586,7.7527],"text":["TAS_x: 76.2510<br />TAS_y: 8.4263<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.6084<br />TAS_y: 8.2760<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.3589<br />TAS_y: 8.3840<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.3348<br />TAS_y: 8.2332<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.5163<br />TAS_y: 8.2896<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.6116<br />TAS_y: 7.5159<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.5044<br />TAS_y: 8.3159<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 77.1132<br />TAS_y: 8.2658<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.3445<br />TAS_y: 8.4120<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.4144<br />TAS_y: 8.1220<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.2334<br />TAS_y: 8.2749<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.3172<br />TAS_y: 8.3586<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TAS_x: 76.8360<br />TAS_y: 7.7527<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(239,19,157,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.5676,76.5808,76.5481,76.5047,76.7719,75.3898,76.8377,76.021,75.808,76.537,76.5586,76.3852,76.8061,76.1983,76.0111,76.1876,75.6226,76.4895,76.4996,77.5249,77.711],"y":[7.2866,7.2947,7.4576,7.396,7.2759,8.3202,8.5094,8.4489,8.7621,8.3966,8.2513,8.4233,8.3029,8.6563,8.5728,8.4228,8.6691,8.7788,8.3121,7.912,8.0062],"text":["TAS_x: 76.5676<br />TAS_y: 7.2866<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.5808<br />TAS_y: 7.2947<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.5481<br />TAS_y: 7.4576<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.5047<br />TAS_y: 7.3960<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.7719<br />TAS_y: 7.2759<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 75.3898<br />TAS_y: 8.3202<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.8377<br />TAS_y: 8.5094<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.0210<br />TAS_y: 8.4489<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 75.8080<br />TAS_y: 8.7621<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.5370<br />TAS_y: 8.3966<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.5586<br />TAS_y: 8.2513<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.3852<br />TAS_y: 8.4233<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.8061<br />TAS_y: 8.3029<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.1983<br />TAS_y: 8.6563<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.0111<br />TAS_y: 8.5728<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.1876<br />TAS_y: 8.4228<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 75.6226<br />TAS_y: 8.6691<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.4895<br />TAS_y: 8.7788<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 76.4996<br />TAS_y: 8.3121<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 77.5249<br />TAS_y: 7.9120<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TAS_x: 77.7110<br />TAS_y: 8.0062<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(58,112,15,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.0422,76.6732,76.6344,76.174,76.6436,76.8117,76.6803,76.88,76.2943,76.6069,76.5275,76.7478,76.9616,76.3331,76.9919,76.6496,76.6541,76.2446,76.8419,77.0577,76.6357,76.8808,76.9151,76.5024,76.6051,76.6881,77.0639,76.9429],"y":[8.5248,8.2483,8.2958,8.3278,8.0296,8.3028,7.964,8.071,8.3663,8.001,8.1238,8.3568,8.0663,8.2451,8.0503,8.3929,8.1864,8.2456,8.0558,8.0085,8.2831,8.3067,8.219,8.4729,8.0352,8.1388,8.1994,8.2102],"text":["TAS_x: 76.0422<br />TAS_y: 8.5248<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6732<br />TAS_y: 8.2483<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6344<br />TAS_y: 8.2958<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.1740<br />TAS_y: 8.3278<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6436<br />TAS_y: 8.0296<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.8117<br />TAS_y: 8.3028<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6803<br />TAS_y: 7.9640<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.8800<br />TAS_y: 8.0710<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.2943<br />TAS_y: 8.3663<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6069<br />TAS_y: 8.0010<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.5275<br />TAS_y: 8.1238<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.7478<br />TAS_y: 8.3568<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.9616<br />TAS_y: 8.0663<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.3331<br />TAS_y: 8.2451<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.9919<br />TAS_y: 8.0503<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6496<br />TAS_y: 8.3929<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6541<br />TAS_y: 8.1864<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.2446<br />TAS_y: 8.2456<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.8419<br />TAS_y: 8.0558<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 77.0577<br />TAS_y: 8.0085<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6357<br />TAS_y: 8.2831<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.8808<br />TAS_y: 8.3067<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.9151<br />TAS_y: 8.2190<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.5024<br />TAS_y: 8.4729<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6051<br />TAS_y: 8.0352<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.6881<br />TAS_y: 8.1388<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 77.0639<br />TAS_y: 8.1994<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TAS_x: 76.9429<br />TAS_y: 8.2102<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(82,136,255,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77.1741,76.8465,76.4511,76.9551,76.54,76.5951,76.4123,77.136,76.6504,78.0441],"y":[7.8099,8.2217,8.4645,8.1301,8.1133,8.3922,8.4233,8.2304,8.2131,9.2218],"text":["TAS_x: 77.1741<br />TAS_y: 7.8099<br />id: Fosen Tephra<br />id: Fosen Tephra","TAS_x: 76.8465<br />TAS_y: 8.2217<br />id: Fosen Tephra<br />id: Fosen Tephra","TAS_x: 76.4511<br />TAS_y: 8.4645<br />id: Fosen Tephra<br />id: Fosen Tephra","TAS_x: 76.9551<br />TAS_y: 8.1301<br />id: Fosen Tephra<br />id: Fosen Tephra","TAS_x: 76.5400<br />TAS_y: 8.1133<br />id: Fosen Tephra<br />id: Fosen Tephra","TAS_x: 76.5951<br />TAS_y: 8.3922<br />id: Fosen Tephra<br />id: Fosen Tephra","TAS_x: 76.4123<br />TAS_y: 8.4233<br />id: Fosen Tephra<br />id: Fosen Tephra","TAS_x: 77.1360<br />TAS_y: 8.2304<br />id: Fosen Tephra<br />id: Fosen Tephra","TAS_x: 76.6504<br />TAS_y: 8.2131<br />id: Fosen Tephra<br />id: Fosen Tephra","TAS_x: 78.0441<br />TAS_y: 9.2218<br />id: Fosen Tephra<br />id: Fosen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(230,71,1,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77.0902,77.9979,77.6365,78.0018,78.2455,77.9557,78.0717,78.3756,77.997,78.0799,78.1732,78.6674,77.5137,77.92,77.5632,78.1672,75.9142,76.5213,77.7823,77.9156,78.0574,78.049,77.872,77.4453,77.3502,77.6506,77.8356,77.4023,77.3446,77.9768,77.7429,77.7894,77.3723,77.7429,77.918,77.2059,77.1579,77.7824,77.2946,78.2317,77.3525,77.6037,77.5163,77.9606,77.8703,77.616,77.7972,77.0337,77.5667,77.4528,77.8604,77.7778,77.5733,78.2834,77.9281,77.441,78.1339,77.6946,78.3321,78.2336,78.5476,77.9862,77.7083,77.8427,77.3767,77.1459,77.6262,76.2979,77.4095,77.6482,78.3361,78.0928,76.3954,77.5774,78.2242,78.0117,77.8723,77.5858,77.992,78.2779,78.1,77.9372,78.1066,78.1922,78.2961,78.1722,77.9433,77.5553,78.0195,78.4613,78.6553,78.5774,78.2117,78.1682,78.0418,77.993,77.6006,76.9205,77.3437,77.2667,77.264,76.5211,78.1632,77.0655],"y":[8.5748,8.4725,8.5215,8.4177,8.2181,8.2607,7.9436,8.0681,8.0661,8.1101,7.6212,7.5601,8.4972,8.3395,8.1045,8.1136,8.7576,8.6876,8.5039,8.3127,8.2466,8.5603,8.3465,8.5506,8.6225,8.609,8.2414,8.3316,8.1033,8.2298,8.0982,8.2377,7.8206,8.0146,8.1598,8.0568,7.8105,8.1871,8.3403,8.2548,8.134,8.4613,8.3841,8.0248,8.421,8.1492,8.0579,8.5652,8.1986,8.3074,8.1831,8.0864,8.3697,8.3077,8.2524,8.3482,7.8545,8.2216,8.329,8.2155,8.0121,8.4845,8.4271,7.8625,8.6464,8.5625,8.3465,8.7021,8.5295,8.5751,8.3298,8.2441,8.5957,8.7772,8.5206,8.5487,8.3782,8.5636,8.1868,8.0508,8.0345,8.1256,8.2074,8.1332,8.1403,8.0507,8.012,8.1559,8.4589,7.4691,7.7477,7.623,7.7287,8.1032,8.1993,7.5145,8.0067,8.4261,8.4422,8.2298,8.2509,8.7551,8.7885,8.9052],"text":["TAS_x: 77.0902<br />TAS_y: 8.5748<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9979<br />TAS_y: 8.4725<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.6365<br />TAS_y: 8.5215<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.0018<br />TAS_y: 8.4177<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.2455<br />TAS_y: 8.2181<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9557<br />TAS_y: 8.2607<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.0717<br />TAS_y: 7.9436<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.3756<br />TAS_y: 8.0681<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9970<br />TAS_y: 8.0661<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.0799<br />TAS_y: 8.1101<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.1732<br />TAS_y: 7.6212<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.6674<br />TAS_y: 7.5601<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.5137<br />TAS_y: 8.4972<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9200<br />TAS_y: 8.3395<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.5632<br />TAS_y: 8.1045<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.1672<br />TAS_y: 8.1136<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 75.9142<br />TAS_y: 8.7576<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 76.5213<br />TAS_y: 8.6876<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.7823<br />TAS_y: 8.5039<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9156<br />TAS_y: 8.3127<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.0574<br />TAS_y: 8.2466<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.0490<br />TAS_y: 8.5603<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.8720<br />TAS_y: 8.3465<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.4453<br />TAS_y: 8.5506<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.3502<br />TAS_y: 8.6225<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.6506<br />TAS_y: 8.6090<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.8356<br />TAS_y: 8.2414<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.4023<br />TAS_y: 8.3316<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.3446<br />TAS_y: 8.1033<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9768<br />TAS_y: 8.2298<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.7429<br />TAS_y: 8.0982<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.7894<br />TAS_y: 8.2377<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.3723<br />TAS_y: 7.8206<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.7429<br />TAS_y: 8.0146<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9180<br />TAS_y: 8.1598<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.2059<br />TAS_y: 8.0568<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.1579<br />TAS_y: 7.8105<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.7824<br />TAS_y: 8.1871<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.2946<br />TAS_y: 8.3403<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.2317<br />TAS_y: 8.2548<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.3525<br />TAS_y: 8.1340<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.6037<br />TAS_y: 8.4613<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.5163<br />TAS_y: 8.3841<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9606<br />TAS_y: 8.0248<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.8703<br />TAS_y: 8.4210<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.6160<br />TAS_y: 8.1492<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.7972<br />TAS_y: 8.0579<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.0337<br />TAS_y: 8.5652<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.5667<br />TAS_y: 8.1986<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.4528<br />TAS_y: 8.3074<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.8604<br />TAS_y: 8.1831<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.7778<br />TAS_y: 8.0864<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.5733<br />TAS_y: 8.3697<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.2834<br />TAS_y: 8.3077<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9281<br />TAS_y: 8.2524<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.4410<br />TAS_y: 8.3482<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.1339<br />TAS_y: 7.8545<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.6946<br />TAS_y: 8.2216<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.3321<br />TAS_y: 8.3290<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.2336<br />TAS_y: 8.2155<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.5476<br />TAS_y: 8.0121<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9862<br />TAS_y: 8.4845<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.7083<br />TAS_y: 8.4271<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.8427<br />TAS_y: 7.8625<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.3767<br />TAS_y: 8.6464<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.1459<br />TAS_y: 8.5625<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.6262<br />TAS_y: 8.3465<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 76.2979<br />TAS_y: 8.7021<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.4095<br />TAS_y: 8.5295<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.6482<br />TAS_y: 8.5751<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.3361<br />TAS_y: 8.3298<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.0928<br />TAS_y: 8.2441<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 76.3954<br />TAS_y: 8.5957<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.5774<br />TAS_y: 8.7772<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.2242<br />TAS_y: 8.5206<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.0117<br />TAS_y: 8.5487<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.8723<br />TAS_y: 8.3782<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.5858<br />TAS_y: 8.5636<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9920<br />TAS_y: 8.1868<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.2779<br />TAS_y: 8.0508<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.1000<br />TAS_y: 8.0345<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9372<br />TAS_y: 8.1256<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.1066<br />TAS_y: 8.2074<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.1922<br />TAS_y: 8.1332<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.2961<br />TAS_y: 8.1403<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.1722<br />TAS_y: 8.0507<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9433<br />TAS_y: 8.0120<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.5553<br />TAS_y: 8.1559<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.0195<br />TAS_y: 8.4589<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.4613<br />TAS_y: 7.4691<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.6553<br />TAS_y: 7.7477<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.5774<br />TAS_y: 7.6230<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.2117<br />TAS_y: 7.7287<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.1682<br />TAS_y: 8.1032<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.0418<br />TAS_y: 8.1993<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.9930<br />TAS_y: 7.5145<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.6006<br />TAS_y: 8.0067<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 76.9205<br />TAS_y: 8.4261<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.3437<br />TAS_y: 8.4422<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.2667<br />TAS_y: 8.2298<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.2640<br />TAS_y: 8.2509<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 76.5211<br />TAS_y: 8.7551<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 78.1632<br />TAS_y: 8.7885<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TAS_x: 77.0655<br />TAS_y: 8.9052<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(127,154,245,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.3258,77.8075,76.8763,77.1161,77.6452,78.2549,78.1683,78.5187,78.0465,78.4069,78.2806,78.5578,78.3535,78.0909,77.7919,78.1714,77.7157,77.8977,77.8565,78.0234,77.7272,77.9018,77.7766],"y":[9.2465,8.1332,9.2957,8.9375,8.1951,7.6988,7.8682,7.5333,7.833,7.6379,7.5844,7.4341,7.5334,7.9457,7.9692,7.6899,8.2683,7.8332,8.0195,7.4495,7.7102,7.8975,7.9499],"text":["TAS_x: 76.3258<br />TAS_y: 9.2465<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.8075<br />TAS_y: 8.1332<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 76.8763<br />TAS_y: 9.2957<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.1161<br />TAS_y: 8.9375<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.6452<br />TAS_y: 8.1951<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.2549<br />TAS_y: 7.6988<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.1683<br />TAS_y: 7.8682<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.5187<br />TAS_y: 7.5333<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.0465<br />TAS_y: 7.8330<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.4069<br />TAS_y: 7.6379<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.2806<br />TAS_y: 7.5844<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.5578<br />TAS_y: 7.4341<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.3535<br />TAS_y: 7.5334<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.0909<br />TAS_y: 7.9457<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.7919<br />TAS_y: 7.9692<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.1714<br />TAS_y: 7.6899<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.7157<br />TAS_y: 8.2683<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.8977<br />TAS_y: 7.8332<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.8565<br />TAS_y: 8.0195<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 78.0234<br />TAS_y: 7.4495<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.7272<br />TAS_y: 7.7102<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.9018<br />TAS_y: 7.8975<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TAS_x: 77.7766<br />TAS_y: 7.9499<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(243,109,32,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77.0444,76.9022,76.5738,75.9228,75.8915,76.473,76.1159,76.3197,76.3854,76.2474,77.8524,76.121,77.0319,76.4407,76.5314,76.1896,76.6545,76.1691,76.7503,76.8278,76.792,76.9405,76.8066,76.5228,76.9615,76.6458,76.351,75.8413,76.368,76.9336,77.2737,76.6702,76.1129,75.8639,76.7396,76.3936,76.3194,76.3442,76.5748,76.478,75.81,76.9535,76.8945,77.2931,76.3173,76.4821,77.3998,77.6234,76.5821,77.5093,76.4363,77.3783,76.3841,76.3391,76.568,76.6609,77.0855,76.0128,76.4087,76.9676,76.5047,76.5996,76.3344,77.461,77.5372,77.7898,77.5286,77.4263,77.7334,77.5369,77.4599,77.4814,77.6427,77.4423,77.4075,77.6499,77.9087,77.6434,76.9573,76.5582,77.264,77.4321,76.4257,77.5715,77.6529,76.6782,76.8775,76.735,76.8499,76.6936,77.0798,76.7105,76.2825,76.7091,76.6004,76.5302,77.4672,76.5027,76.2503,76.6262,76.7719,76.5382,76.9528,76.875,76.2135,77.5215,76.2913,76.3481,76.8676,76.737,76.5642,76.6986,76.9791,76.7887,77.0678,77.4739,76.2047,76.0558,76.3567,75.9331,76.3197,76.453,77.5549,75.9875,76.967,76.4438,77.2031,76.2789,76.7433,77.0143,76.6347,77.0799,77.1763,77.1536,75.5286,76.6083,76.7808,76.7999,76.9198,76.7103,76.9133,76.9084,77.0963,76.8091,76.5665,77.6289,77.2356,76.8983,76.6876,76.8349,76.3642,77.0145,76.2885,76.3502,76.8239,77.3763,76.4161,76.8159,75.8491,76.9891,76.8685,75.6709,76.9872,77.0977,77.2267,76.9429,76.8574,76.8673,77.197,76.9849,77.0659],"y":[7.7366,8.2635,8.184,8.7518,8.3434,8.2069,8.6462,8.6571,8.5001,8.4739,8.0105,8.4889,8.48,8.6252,8.5833,8.5673,8.0399,8.4861,8.4812,8.3269,8.0503,8.1619,8.0423,7.9518,8.1099,8.2342,8.3645,8.2666,8.5009,8.28,8.4199,8.5,8.2967,8.2015,8.2872,8.4988,8.5802,8.3616,8.0191,8.1398,8.2731,8.455,8.3701,8.1825,8.5468,8.4812,8.4201,8.13,8.168,8.2863,8.4262,8.154,8.5482,8.5686,8.5052,8.0418,8.4444,8.4928,8.2057,8.3094,8.0134,8.2417,8.3966,7.2862,7.4687,7.4502,7.5204,7.5099,7.3982,7.3005,7.5279,7.3459,7.3353,7.3121,7.393,7.4108,7.4731,7.3305,7.3789,7.6266,7.4947,7.6511,7.3655,7.5499,7.3636,7.9021,8.2183,7.8571,8.003,7.9471,7.8799,7.9552,8.3322,7.9597,8.3081,7.9732,7.829,8.1746,8.0895,7.9112,7.9341,7.9418,8.1021,7.9558,8.1255,7.674,8.0597,8.1373,7.6624,7.8008,8.0284,7.6767,8.2222,7.6639,8.4361,8.5694,8.2764,8.5416,8.2164,8.3707,8.3256,8.4721,7.9996,8.1041,7.8887,8.5294,7.9811,8.4047,8.5219,8.1304,8.5333,7.9338,8.4493,8.5399,8.4809,8.1436,7.5646,7.5602,7.4777,7.6859,7.4739,7.6017,7.3646,8.3932,8.4109,8.2061,8.1254,8.1734,8.3244,8.5009,8.5747,8.1225,8.5633,8.255,8.5559,7.8709,8.4607,8.4655,8.0772,8.2727,8.2944,8.6725,8.233,8.4557,8.5824,8.2602,8.3259,8.4479,8.2518,8.1361,8.2667],"text":["TAS_x: 77.0444<br />TAS_y: 7.7366<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9022<br />TAS_y: 8.2635<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5738<br />TAS_y: 8.1840<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.9228<br />TAS_y: 8.7518<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.8915<br />TAS_y: 8.3434<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4730<br />TAS_y: 8.2069<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.1159<br />TAS_y: 8.6462<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3197<br />TAS_y: 8.6571<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3854<br />TAS_y: 8.5001<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.2474<br />TAS_y: 8.4739<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.8524<br />TAS_y: 8.0105<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.1210<br />TAS_y: 8.4889<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0319<br />TAS_y: 8.4800<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4407<br />TAS_y: 8.6252<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5314<br />TAS_y: 8.5833<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.1896<br />TAS_y: 8.5673<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6545<br />TAS_y: 8.0399<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.1691<br />TAS_y: 8.4861<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7503<br />TAS_y: 8.4812<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8278<br />TAS_y: 8.3269<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7920<br />TAS_y: 8.0503<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9405<br />TAS_y: 8.1619<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8066<br />TAS_y: 8.0423<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5228<br />TAS_y: 7.9518<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9615<br />TAS_y: 8.1099<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6458<br />TAS_y: 8.2342<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3510<br />TAS_y: 8.3645<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.8413<br />TAS_y: 8.2666<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3680<br />TAS_y: 8.5009<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9336<br />TAS_y: 8.2800<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.2737<br />TAS_y: 8.4199<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6702<br />TAS_y: 8.5000<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.1129<br />TAS_y: 8.2967<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.8639<br />TAS_y: 8.2015<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7396<br />TAS_y: 8.2872<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3936<br />TAS_y: 8.4988<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3194<br />TAS_y: 8.5802<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3442<br />TAS_y: 8.3616<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5748<br />TAS_y: 8.0191<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4780<br />TAS_y: 8.1398<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.8100<br />TAS_y: 8.2731<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9535<br />TAS_y: 8.4550<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8945<br />TAS_y: 8.3701<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.2931<br />TAS_y: 8.1825<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3173<br />TAS_y: 8.5468<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4821<br />TAS_y: 8.4812<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.3998<br />TAS_y: 8.4201<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.6234<br />TAS_y: 8.1300<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5821<br />TAS_y: 8.1680<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.5093<br />TAS_y: 8.2863<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4363<br />TAS_y: 8.4262<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.3783<br />TAS_y: 8.1540<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3841<br />TAS_y: 8.5482<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3391<br />TAS_y: 8.5686<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5680<br />TAS_y: 8.5052<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6609<br />TAS_y: 8.0418<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0855<br />TAS_y: 8.4444<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.0128<br />TAS_y: 8.4928<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4087<br />TAS_y: 8.2057<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9676<br />TAS_y: 8.3094<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5047<br />TAS_y: 8.0134<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5996<br />TAS_y: 8.2417<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3344<br />TAS_y: 8.3966<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.4610<br />TAS_y: 7.2862<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.5372<br />TAS_y: 7.4687<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.7898<br />TAS_y: 7.4502<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.5286<br />TAS_y: 7.5204<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.4263<br />TAS_y: 7.5099<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.7334<br />TAS_y: 7.3982<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.5369<br />TAS_y: 7.3005<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.4599<br />TAS_y: 7.5279<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.4814<br />TAS_y: 7.3459<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.6427<br />TAS_y: 7.3353<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.4423<br />TAS_y: 7.3121<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.4075<br />TAS_y: 7.3930<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.6499<br />TAS_y: 7.4108<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.9087<br />TAS_y: 7.4731<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.6434<br />TAS_y: 7.3305<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9573<br />TAS_y: 7.3789<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5582<br />TAS_y: 7.6266<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.2640<br />TAS_y: 7.4947<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.4321<br />TAS_y: 7.6511<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4257<br />TAS_y: 7.3655<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.5715<br />TAS_y: 7.5499<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.6529<br />TAS_y: 7.3636<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6782<br />TAS_y: 7.9021<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8775<br />TAS_y: 8.2183<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7350<br />TAS_y: 7.8571<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8499<br />TAS_y: 8.0030<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6936<br />TAS_y: 7.9471<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0798<br />TAS_y: 7.8799<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7105<br />TAS_y: 7.9552<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.2825<br />TAS_y: 8.3322<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7091<br />TAS_y: 7.9597<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6004<br />TAS_y: 8.3081<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5302<br />TAS_y: 7.9732<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.4672<br />TAS_y: 7.8290<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5027<br />TAS_y: 8.1746<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.2503<br />TAS_y: 8.0895<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6262<br />TAS_y: 7.9112<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7719<br />TAS_y: 7.9341<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5382<br />TAS_y: 7.9418<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9528<br />TAS_y: 8.1021<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8750<br />TAS_y: 7.9558<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.2135<br />TAS_y: 8.1255<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.5215<br />TAS_y: 7.6740<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.2913<br />TAS_y: 8.0597<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3481<br />TAS_y: 8.1373<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8676<br />TAS_y: 7.6624<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7370<br />TAS_y: 7.8008<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5642<br />TAS_y: 8.0284<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6986<br />TAS_y: 7.6767<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9791<br />TAS_y: 8.2222<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7887<br />TAS_y: 7.6639<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0678<br />TAS_y: 8.4361<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.4739<br />TAS_y: 8.5694<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.2047<br />TAS_y: 8.2764<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.0558<br />TAS_y: 8.5416<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3567<br />TAS_y: 8.2164<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.9331<br />TAS_y: 8.3707<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3197<br />TAS_y: 8.3256<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4530<br />TAS_y: 8.4721<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.5549<br />TAS_y: 7.9996<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.9875<br />TAS_y: 8.1041<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9670<br />TAS_y: 7.8887<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4438<br />TAS_y: 8.5294<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.2031<br />TAS_y: 7.9811<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.2789<br />TAS_y: 8.4047<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7433<br />TAS_y: 8.5219<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0143<br />TAS_y: 8.1304<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6347<br />TAS_y: 8.5333<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0799<br />TAS_y: 7.9338<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.1763<br />TAS_y: 8.4493<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.1536<br />TAS_y: 8.5399<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.5286<br />TAS_y: 8.4809<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6083<br />TAS_y: 8.1436<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7808<br />TAS_y: 7.5646<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7999<br />TAS_y: 7.5602<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9198<br />TAS_y: 7.4777<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.7103<br />TAS_y: 7.6859<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9133<br />TAS_y: 7.4739<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9084<br />TAS_y: 7.6017<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0963<br />TAS_y: 7.3646<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8091<br />TAS_y: 8.3932<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.5665<br />TAS_y: 8.4109<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.6289<br />TAS_y: 8.2061<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.2356<br />TAS_y: 8.1254<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8983<br />TAS_y: 8.1734<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.6876<br />TAS_y: 8.3244<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8349<br />TAS_y: 8.5009<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3642<br />TAS_y: 8.5747<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0145<br />TAS_y: 8.1225<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.2885<br />TAS_y: 8.5633<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.3502<br />TAS_y: 8.2550<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8239<br />TAS_y: 8.5559<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.3763<br />TAS_y: 7.8709<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.4161<br />TAS_y: 8.4607<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8159<br />TAS_y: 8.4655<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.8491<br />TAS_y: 8.0772<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9891<br />TAS_y: 8.2727<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8685<br />TAS_y: 8.2944<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 75.6709<br />TAS_y: 8.6725<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9872<br />TAS_y: 8.2330<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0977<br />TAS_y: 8.4557<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.2267<br />TAS_y: 8.5824<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9429<br />TAS_y: 8.2602<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8574<br />TAS_y: 8.3259<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.8673<br />TAS_y: 8.4479<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.1970<br />TAS_y: 8.2518<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 76.9849<br />TAS_y: 8.1361<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TAS_x: 77.0659<br />TAS_y: 8.2667<br />id: Penifiler Tephra<br />id: Penifiler Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(11,48,117,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69],"y":[0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69,null,77,69],"y":[0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8,null,0,8],"text":"TAS_x: 77<br />TAS_y: 0<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69],"y":[8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69,null,69,69],"y":[8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13,null,8,13],"text":"TAS_x: 69<br />TAS_y: 8<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5],"y":[7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5,null,41,52.5],"y":[7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14,null,7,14],"text":"TAS_x: 41<br />TAS_y: 7<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6,null,52.5,57.6],"y":[14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7,null,14,11.7],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45],"y":[0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45,null,45,45],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 45<br />TAS_y: 0<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63],"y":[5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63,null,45,63],"y":[5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56,null,5,14.56],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52],"y":[0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52,null,52,52],"y":[0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5,null,0,5],"text":"TAS_x: 52<br />TAS_y: 0<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63],"y":[5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63,null,52,63],"y":[5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7,null,5,7],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57],"y":[0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57,null,57,57],"y":[0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9,null,0,5.9],"text":"TAS_x: 57<br />TAS_y: 0<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63],"y":[0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63,null,63,63],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 63<br />TAS_y: 0<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52],"y":[5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52,null,45,52],"y":[5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5,null,5,5],"text":"TAS_x: 45<br />TAS_y: 5<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4,null,52,49.4],"y":[5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3,null,5,7.3],"text":"TAS_x: 52<br />TAS_y: 5<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53,null,57,53],"y":[5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3,null,5.9,9.3],"text":"TAS_x: 57<br />TAS_y: 5.9<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6,null,63,57.6],"y":[7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7,null,7,11.7],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45,null,49.4,45],"y":[7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4,null,7.3,9.4],"text":"TAS_x: 49.4<br />TAS_y: 7.3<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4,null,53,48.4],"y":[9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5,null,9.3,11.5],"text":"TAS_x: 53<br />TAS_y: 9.3<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41],"y":[0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41,null,41,41],"y":[0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7,null,0,7],"text":"TAS_x: 41<br />TAS_y: 0<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49,null,52.5,49],"y":[14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5,null,14,15.5],"text":"TAS_x: 52.5<br />TAS_y: 14<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45],"y":[3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45,null,41,45],"y":[3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3,null,3,3],"text":"TAS_x: 41<br />TAS_y: 3<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69],"y":[7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69,null,63,69],"y":[7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8,null,7,8],"text":"TAS_x: 63<br />TAS_y: 7<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76,67.5,59,54,48,42.5,48.5,53,57,63,43,48,53,57,42],"y":[6,5.2,4,3,2.5,1.5,6,7.5,8.8,11,7,10,12,14.5,13],"text":["R","O3","O2","O1","B","Pc","S1","S2","S3","T","U1","U2","U3","Ph","F"],"hovertext":["x: 76.0<br />y:  6.0","x: 67.5<br />y:  5.2","x: 59.0<br />y:  4.0","x: 54.0<br />y:  3.0","x: 48.0<br />y:  2.5","x: 42.5<br />y:  1.5","x: 48.5<br />y:  6.0","x: 53.0<br />y:  7.5","x: 57.0<br />y:  8.8","x: 63.0<br />y: 11.0","x: 43.0<br />y:  7.0","x: 48.0<br />y: 10.0","x: 53.0<br />y: 12.0","x: 57.0<br />y: 14.5","x: 42.0<br />y: 13.0"],"textfont":{"size":14.6645669291339,"color":"rgba(0,0,0,1)"},"type":"scatter","mode":"text","hoveron":"points","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null}],"layout":{"margin":{"t":25.1324200913242,"r":7.30593607305936,"b":55.2926525529265,"l":53.4661685346617},"plot_bgcolor":"rgba(255,255,255,1)","paper_bgcolor":"rgba(255,255,255,1)","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187},"xaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":false,"range":[40,80],"tickmode":"array","ticktext":["40","50","60","70","80"],"tickvals":[40,50,60,70,80],"categoryorder":"array","categoryarray":["40","50","60","70","80"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"y","title":{"text":"SiO2 (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"yaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":false,"range":[0,16],"tickmode":"array","ticktext":["0","4","8","12","16"],"tickvals":[0,4,8,12,16],"categoryorder":"array","categoryarray":["0","4","8","12","16"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"x","title":{"text":"Na2O + K2O (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"shapes":[{"type":"rect","fillcolor":"transparent","line":{"color":"rgba(51,51,51,1)","width":0.66417600664176,"linetype":"solid"},"yref":"paper","xref":"paper","x0":0,"x1":1,"y0":0,"y1":1}],"showlegend":true,"legend":{"bgcolor":"rgba(255,255,255,1)","bordercolor":"transparent","borderwidth":1.88976377952756,"font":{"color":"rgba(0,0,0,1)","family":"","size":11.689497716895},"title":{"text":"id","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187}}},"hovermode":"closest","width":1000,"height":800,"barmode":"relative"},"config":{"doubleClick":"reset","modeBarButtonsToAdd":["hoverclosest","hovercompare"],"showSendToCloud":false},"source":"A","attrs":{"724302527d1":{"x":{},"y":{},"fill":{},"shape":{},"type":"scatter"},"72454c97a11":{"x":{},"y":{},"fill":{},"shape":{}},"72420e7379a":{"x":{},"y":{},"fill":{},"shape":{}},"724636d2fb1":{"x":{},"y":{},"fill":{},"shape":{}},"7247fd0275d":{"x":{},"y":{},"fill":{},"shape":{}},"7241add4a2":{"x":{},"y":{},"fill":{},"shape":{}},"72473283c87":{"x":{},"y":{},"fill":{},"shape":{}},"72469d96253":{"x":{},"y":{},"fill":{},"shape":{}},"72426de69a4":{"x":{},"y":{},"fill":{},"shape":{}},"7245bd87a4d":{"x":{},"y":{},"fill":{},"shape":{}},"7243356c22":{"x":{},"y":{},"fill":{},"shape":{}},"72425577216":{"x":{},"y":{},"fill":{},"shape":{}},"7243bba7758":{"x":{},"y":{},"fill":{},"shape":{}},"7244a71655":{"x":{},"y":{},"fill":{},"shape":{}},"7244a7910c7":{"x":{},"y":{},"fill":{},"shape":{}},"72413b06936":{"x":{},"y":{},"fill":{},"shape":{}},"7242b7019f":{"x":{},"y":{},"fill":{},"shape":{}},"72445236010":{"x":{},"y":{},"fill":{},"shape":{}},"7246c44185":{"x":{},"y":{},"fill":{},"shape":{}},"7244bb06446":{"x":{},"y":{},"fill":{},"shape":{}},"72464337e93":{"x":{},"y":{},"fill":{},"shape":{}},"72454ac4b6b":{"x":{},"y":{}}},"cur_data":"724302527d1","visdat":{"724302527d1":["function (y) ","x"],"72454c97a11":["function (y) ","x"],"72420e7379a":["function (y) ","x"],"724636d2fb1":["function (y) ","x"],"7247fd0275d":["function (y) ","x"],"7241add4a2":["function (y) ","x"],"72473283c87":["function (y) ","x"],"72469d96253":["function (y) ","x"],"72426de69a4":["function (y) ","x"],"7245bd87a4d":["function (y) ","x"],"7243356c22":["function (y) ","x"],"72425577216":["function (y) ","x"],"7243bba7758":["function (y) ","x"],"7244a71655":["function (y) ","x"],"7244a7910c7":["function (y) ","x"],"72413b06936":["function (y) ","x"],"7242b7019f":["function (y) ","x"],"72445236010":["function (y) ","x"],"7246c44185":["function (y) ","x"],"7244bb06446":["function (y) ","x"],"72464337e93":["function (y) ","x"],"72454ac4b6b":["function (y) ","x"]},"highlight":{"on":"plotly_click","persistent":false,"dynamic":false,"selectize":false,"opacityDim":0.2,"selected":{"opacity":1},"debounce":0},"shinyEvents":["plotly_hover","plotly_click","plotly_selected","plotly_relayout","plotly_brushed","plotly_brushing","plotly_clickannotation","plotly_doubleclick","plotly_deselect","plotly_afterplot","plotly_sunburstclick"],"base_url":"https://plot.ly"},"evals":[],"jsHooks":[]}</script>

## iFeO-CaO

<div id="htmlwidget-f30d7598595affc4f25a" style="width:1000px;height:800px;" class="plotly html-widget"></div>
<script type="application/json" data-for="htmlwidget-f30d7598595affc4f25a">{"x":{"data":[{"x":[0.9479,0.959],"y":[0.5637,0.8226],"text":["FeO: 0.9479<br />CaO: 0.5637<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","FeO: 0.9590<br />CaO: 0.8226<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(32,154,36,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.661,1.6161,1.4207,1.6193,1.4953,1.3337,1.4372,1.6168,1.669,1.5678,1.5732,1.7156],"y":[0.7969,0.771,0.7725,0.9214,0.7891,0.7422,0.8209,0.8847,0.8635,0.697,0.8822,0.7739],"text":["FeO: 1.6610<br />CaO: 0.7969<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.6161<br />CaO: 0.7710<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.4207<br />CaO: 0.7725<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.6193<br />CaO: 0.9214<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.4953<br />CaO: 0.7891<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.3337<br />CaO: 0.7422<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.4372<br />CaO: 0.8209<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.6168<br />CaO: 0.8847<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.6690<br />CaO: 0.8635<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.5678<br />CaO: 0.6970<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.5732<br />CaO: 0.8822<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","FeO: 1.7156<br />CaO: 0.7739<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(167,105,238,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.6675,1.4748,1.4826,1.2199,1.5458,1.2707,1.4988,1.6017],"y":[0.8509,0.8654,0.8606,0.7576,0.8209,0.8403,0.8383,0.879],"text":["FeO: 1.6675<br />CaO: 0.8509<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","FeO: 1.4748<br />CaO: 0.8654<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","FeO: 1.4826<br />CaO: 0.8606<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","FeO: 1.2199<br />CaO: 0.7576<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","FeO: 1.5458<br />CaO: 0.8209<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","FeO: 1.2707<br />CaO: 0.8403<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","FeO: 1.4988<br />CaO: 0.8383<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","FeO: 1.6017<br />CaO: 0.8790<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(180,196,40,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.3013,1.6491,1.6082,1.5857,1.5998,1.7135,1.5096,1.4933,1.6272,1.6835,1.3803,1.6167,1.645,1.6165,1.4252,1.4708,1.7516,1.6061,1.7137,1.5599,1.8257,1.1974,1.5916,1.5857,1.6455,1.4562,1.7472,1.635,1.4325,1.5216,1.6508,1.6576,1.684,1.5218,1.5084],"y":[0.9134,0.9018,1.0067,1.0151,1.048,0.9426,0.954,0.9072,0.9884,0.9502,0.9566,0.9756,0.8845,0.9504,0.8973,0.908,0.991,1.0766,0.9515,0.9276,0.9345,0.8102,0.969,0.9232,0.9252,0.9688,0.9951,0.999,0.951,0.9828,1.0333,1.0223,1.0099,0.9539,1.0144],"text":["FeO: 1.3013<br />CaO: 0.9134<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6491<br />CaO: 0.9018<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6082<br />CaO: 1.0067<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5857<br />CaO: 1.0151<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5998<br />CaO: 1.0480<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.7135<br />CaO: 0.9426<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5096<br />CaO: 0.9540<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4933<br />CaO: 0.9072<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6272<br />CaO: 0.9884<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6835<br />CaO: 0.9502<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.3803<br />CaO: 0.9566<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6167<br />CaO: 0.9756<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6450<br />CaO: 0.8845<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6165<br />CaO: 0.9504<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4252<br />CaO: 0.8973<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4708<br />CaO: 0.9080<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.7516<br />CaO: 0.9910<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6061<br />CaO: 1.0766<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.7137<br />CaO: 0.9515<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5599<br />CaO: 0.9276<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.8257<br />CaO: 0.9345<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.1974<br />CaO: 0.8102<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5916<br />CaO: 0.9690<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5857<br />CaO: 0.9232<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6455<br />CaO: 0.9252<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4562<br />CaO: 0.9688<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.7472<br />CaO: 0.9951<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6350<br />CaO: 0.9990<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4325<br />CaO: 0.9510<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5216<br />CaO: 0.9828<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6508<br />CaO: 1.0333<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6576<br />CaO: 1.0223<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6840<br />CaO: 1.0099<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5218<br />CaO: 0.9539<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5084<br />CaO: 1.0144<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(227,3,3,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.4829,1.5334,1.5915,1.4596,1.5658,1.451,1.5396,1.5186,1.4584,1.6774,1.6552,1.5205,1.5743,1.7267,1.4836,1.4749,1.4743,1.4754,1.3884,1.6397,1.5442,1.6075,1.6104,1.5936,1.6838,1.6215,1.5273,1.7028,1.5041,1.4468,1.6387,1.6264,1.6338,1.2911,1.6035,1.5023,1.6094,1.5197,1.64,1.5258,1.4222,1.3991,1.5288,1.5742,1.5823,1.6041,1.4957,1.6185,1.618,1.4436,1.5752,1.7161,1.5199,1.491,1.6271,1.5492,1.6315,1.6787,1.4151,1.4035,1.6019,1.5253,1.4277,1.5412,1.3611,1.5431,1.667,1.7299,1.5228,1.4364,1.4924,1.522,1.1402,1.6887,1.5633,1.5317,1.5091,1.4949,1.6569,1.6132,1.619,1.6737,1.6381,1.549,1.4829,1.5676,1.6798,1.6314,1.552,1.3924,1.6466,1.3628,1.6156,1.5934,1.5501,1.4658,1.5003,1.5921,1.6922,1.6178,1.3084,1.7201,1.6029,1.5937,1.7079,1.554,1.5154,1.5373,1.9138,1.6874,1.5218,1.5474,1.5053,1.4482,1.6017,1.5704,1.4538,1.5343,1.5711,1.5468,1.5571,1.345,1.7633,1.6461],"y":[0.7822,0.7457,0.8213,0.7169,0.8313,0.729,0.7774,0.8527,0.7814,0.7732,0.7882,0.8417,0.7564,0.7601,0.7808,0.759,0.7277,0.7581,0.7801,0.8218,0.7261,0.8557,0.7716,0.7304,0.7229,0.7869,0.8023,0.7433,0.6712,0.7073,0.756,0.7471,0.8866,0.7516,0.7407,0.768,0.8132,0.7516,0.7791,0.7403,0.8142,0.6677,0.7567,0.773,0.7638,0.796,0.7818,0.7882,0.8142,0.7477,0.9092,0.8216,0.8595,0.8862,0.7768,0.8536,0.784,0.782,0.8281,0.6966,0.7538,0.794,0.8024,0.7968,0.7329,0.8398,0.8543,0.7549,0.7666,0.8807,0.8662,0.8292,0.6757,0.7818,0.8239,0.844,0.8174,0.8154,0.8075,0.7228,0.8252,0.9053,0.8243,0.9378,0.7519,0.7154,0.7466,0.7683,0.797,0.8122,0.8705,0.7233,0.8025,0.6647,0.8037,0.7861,0.6642,0.7589,0.7898,0.7788,0.8036,0.8391,0.7097,0.7747,0.7269,0.7987,0.7722,0.7999,0.7386,0.7664,0.8872,0.7525,0.8049,0.7814,0.8008,0.7694,0.7423,0.7619,0.8012,0.784,0.7619,0.7921,0.7763,0.8182],"text":["FeO: 1.4829<br />CaO: 0.7822<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5334<br />CaO: 0.7457<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5915<br />CaO: 0.8213<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4596<br />CaO: 0.7169<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5658<br />CaO: 0.8313<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4510<br />CaO: 0.7290<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5396<br />CaO: 0.7774<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5186<br />CaO: 0.8527<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4584<br />CaO: 0.7814<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6774<br />CaO: 0.7732<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6552<br />CaO: 0.7882<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5205<br />CaO: 0.8417<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5743<br />CaO: 0.7564<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7267<br />CaO: 0.7601<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4836<br />CaO: 0.7808<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4749<br />CaO: 0.7590<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4743<br />CaO: 0.7277<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4754<br />CaO: 0.7581<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3884<br />CaO: 0.7801<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6397<br />CaO: 0.8218<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5442<br />CaO: 0.7261<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6075<br />CaO: 0.8557<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6104<br />CaO: 0.7716<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5936<br />CaO: 0.7304<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6838<br />CaO: 0.7229<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6215<br />CaO: 0.7869<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5273<br />CaO: 0.8023<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7028<br />CaO: 0.7433<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5041<br />CaO: 0.6712<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4468<br />CaO: 0.7073<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6387<br />CaO: 0.7560<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6264<br />CaO: 0.7471<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6338<br />CaO: 0.8866<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.2911<br />CaO: 0.7516<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6035<br />CaO: 0.7407<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5023<br />CaO: 0.7680<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6094<br />CaO: 0.8132<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5197<br />CaO: 0.7516<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6400<br />CaO: 0.7791<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5258<br />CaO: 0.7403<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4222<br />CaO: 0.8142<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3991<br />CaO: 0.6677<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5288<br />CaO: 0.7567<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5742<br />CaO: 0.7730<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5823<br />CaO: 0.7638<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6041<br />CaO: 0.7960<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4957<br />CaO: 0.7818<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6185<br />CaO: 0.7882<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6180<br />CaO: 0.8142<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4436<br />CaO: 0.7477<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5752<br />CaO: 0.9092<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7161<br />CaO: 0.8216<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5199<br />CaO: 0.8595<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4910<br />CaO: 0.8862<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6271<br />CaO: 0.7768<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5492<br />CaO: 0.8536<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6315<br />CaO: 0.7840<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6787<br />CaO: 0.7820<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4151<br />CaO: 0.8281<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4035<br />CaO: 0.6966<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6019<br />CaO: 0.7538<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5253<br />CaO: 0.7940<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4277<br />CaO: 0.8024<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5412<br />CaO: 0.7968<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3611<br />CaO: 0.7329<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5431<br />CaO: 0.8398<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6670<br />CaO: 0.8543<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7299<br />CaO: 0.7549<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5228<br />CaO: 0.7666<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4364<br />CaO: 0.8807<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4924<br />CaO: 0.8662<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5220<br />CaO: 0.8292<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.1402<br />CaO: 0.6757<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6887<br />CaO: 0.7818<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5633<br />CaO: 0.8239<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5317<br />CaO: 0.8440<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5091<br />CaO: 0.8174<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4949<br />CaO: 0.8154<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6569<br />CaO: 0.8075<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6132<br />CaO: 0.7228<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6190<br />CaO: 0.8252<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6737<br />CaO: 0.9053<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6381<br />CaO: 0.8243<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5490<br />CaO: 0.9378<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4829<br />CaO: 0.7519<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5676<br />CaO: 0.7154<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6798<br />CaO: 0.7466<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6314<br />CaO: 0.7683<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5520<br />CaO: 0.7970<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3924<br />CaO: 0.8122<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6466<br />CaO: 0.8705<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3628<br />CaO: 0.7233<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6156<br />CaO: 0.8025<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5934<br />CaO: 0.6647<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5501<br />CaO: 0.8037<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4658<br />CaO: 0.7861<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5003<br />CaO: 0.6642<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5921<br />CaO: 0.7589<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6922<br />CaO: 0.7898<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6178<br />CaO: 0.7788<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3084<br />CaO: 0.8036<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7201<br />CaO: 0.8391<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6029<br />CaO: 0.7097<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5937<br />CaO: 0.7747<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7079<br />CaO: 0.7269<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5540<br />CaO: 0.7987<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5154<br />CaO: 0.7722<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5373<br />CaO: 0.7999<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.9138<br />CaO: 0.7386<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6874<br />CaO: 0.7664<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5218<br />CaO: 0.8872<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5474<br />CaO: 0.7525<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5053<br />CaO: 0.8049<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4482<br />CaO: 0.7814<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6017<br />CaO: 0.8008<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5704<br />CaO: 0.7694<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4538<br />CaO: 0.7423<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5343<br />CaO: 0.7619<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5711<br />CaO: 0.8012<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5468<br />CaO: 0.7840<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5571<br />CaO: 0.7619<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3450<br />CaO: 0.7921<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7633<br />CaO: 0.7763<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6461<br />CaO: 0.8182<br />id: Borrobol Tephra<br />id: Borrobol Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(0,0,0,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.6129,1.4782,1.6264,1.5672,1.6684,1.6194,1.5462,1.2669,1.4427,1.4786,1.4769,1.4979,1.5506],"y":[0.7134,0.7391,0.8604,0.7523,0.7975,0.8097,0.7522,0.6438,0.8062,0.7393,0.817,0.7751,0.7438],"text":["FeO: 1.6129<br />CaO: 0.7134<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.4782<br />CaO: 0.7391<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.6264<br />CaO: 0.8604<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.5672<br />CaO: 0.7523<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.6684<br />CaO: 0.7975<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.6194<br />CaO: 0.8097<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.5462<br />CaO: 0.7522<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.2669<br />CaO: 0.6438<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.4427<br />CaO: 0.8062<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.4786<br />CaO: 0.7393<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.4769<br />CaO: 0.8170<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.4979<br />CaO: 0.7751<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","FeO: 1.5506<br />CaO: 0.7438<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(239,19,157,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.5557,1.5329,1.5704,1.6236,1.4647,1.4913,1.1509,1.2205,1.3866,1.329,1.4184,1.2181,1.6155,1.2151,1.1694,1.3604,1.2176,1.2409,1.2833,1.3667,1.1153],"y":[0.8486,0.8787,0.8667,0.8431,0.8238,0.7407,0.6578,0.5896,0.643,0.6603,0.7285,0.7111,0.644,0.6373,0.6328,0.6782,0.5704,0.6997,0.6165,0.7084,0.5725],"text":["FeO: 1.5557<br />CaO: 0.8486<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.5329<br />CaO: 0.8787<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.5704<br />CaO: 0.8667<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.6236<br />CaO: 0.8431<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.4647<br />CaO: 0.8238<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.4913<br />CaO: 0.7407<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.1509<br />CaO: 0.6578<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2205<br />CaO: 0.5896<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.3866<br />CaO: 0.6430<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.3290<br />CaO: 0.6603<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.4184<br />CaO: 0.7285<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2181<br />CaO: 0.7111<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.6155<br />CaO: 0.6440<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2151<br />CaO: 0.6373<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.1694<br />CaO: 0.6328<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.3604<br />CaO: 0.6782<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2176<br />CaO: 0.5704<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2409<br />CaO: 0.6997<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2833<br />CaO: 0.6165<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.3667<br />CaO: 0.7084<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.1153<br />CaO: 0.5725<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(58,112,15,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.4536,1.445,1.5122,1.5621,1.6022,1.476,1.6259,1.5315,1.5183,1.6955,1.6632,1.3014,1.4657,1.6839,1.3647,1.5479,1.6219,1.6722,1.402,1.6388,1.482,1.5805,1.6949,1.3482,1.5915,1.5549,1.3531,1.4831],"y":[0.8221,0.8115,0.7074,0.7912,0.8141,0.7299,0.7868,0.7667,0.75,0.7664,0.7352,0.797,0.8185,0.8934,0.8209,0.8305,0.8177,0.7666,0.7061,0.7202,0.7538,0.7855,0.8142,0.659,0.7041,0.6523,0.6582,0.7839],"text":["FeO: 1.4536<br />CaO: 0.8221<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4450<br />CaO: 0.8115<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5122<br />CaO: 0.7074<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5621<br />CaO: 0.7912<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6022<br />CaO: 0.8141<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4760<br />CaO: 0.7299<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6259<br />CaO: 0.7868<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5315<br />CaO: 0.7667<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5183<br />CaO: 0.7500<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6955<br />CaO: 0.7664<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6632<br />CaO: 0.7352<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.3014<br />CaO: 0.7970<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4657<br />CaO: 0.8185<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6839<br />CaO: 0.8934<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.3647<br />CaO: 0.8209<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5479<br />CaO: 0.8305<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6219<br />CaO: 0.8177<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6722<br />CaO: 0.7666<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4020<br />CaO: 0.7061<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6388<br />CaO: 0.7202<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4820<br />CaO: 0.7538<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5805<br />CaO: 0.7855<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6949<br />CaO: 0.8142<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.3482<br />CaO: 0.6590<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5915<br />CaO: 0.7041<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5549<br />CaO: 0.6523<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.3531<br />CaO: 0.6582<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4831<br />CaO: 0.7839<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(82,136,255,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.4805,1.6153,1.5948,1.5118,1.8338,1.5481,1.6142,1.5409,1.636,1.0565],"y":[0.7178,0.7227,0.7332,0.7603,0.7712,0.7254,0.7374,0.7571,0.7421,0.3523],"text":["FeO: 1.4805<br />CaO: 0.7178<br />id: Fosen Tephra<br />id: Fosen Tephra","FeO: 1.6153<br />CaO: 0.7227<br />id: Fosen Tephra<br />id: Fosen Tephra","FeO: 1.5948<br />CaO: 0.7332<br />id: Fosen Tephra<br />id: Fosen Tephra","FeO: 1.5118<br />CaO: 0.7603<br />id: Fosen Tephra<br />id: Fosen Tephra","FeO: 1.8338<br />CaO: 0.7712<br />id: Fosen Tephra<br />id: Fosen Tephra","FeO: 1.5481<br />CaO: 0.7254<br />id: Fosen Tephra<br />id: Fosen Tephra","FeO: 1.6142<br />CaO: 0.7374<br />id: Fosen Tephra<br />id: Fosen Tephra","FeO: 1.5409<br />CaO: 0.7571<br />id: Fosen Tephra<br />id: Fosen Tephra","FeO: 1.6360<br />CaO: 0.7421<br />id: Fosen Tephra<br />id: Fosen Tephra","FeO: 1.0565<br />CaO: 0.3523<br />id: Fosen Tephra<br />id: Fosen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(230,71,1,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.1315,1.0823,1.3587,1.0129,1.0643,1.0409,1.1887,1.2041,1.1017,1.2095,1.2112,1.143,1.2496,1.1858,1.2066,1.3179,1.0336,0.9729,1.1329,1.1373,0.8631,1.0687,1.1729,1.0532,1.0305,1.0496,1.1446,1.1932,1.3066,1.1275,1.1599,0.9698,1.4911,1.1076,0.8307,1.229,1.3263,1.0194,1.1735,0.9638,1.361,1.0864,1.1977,1.16,1.3115,1.1312,1.1702,1.354,1.2492,1.3172,1.0687,1.0391,1.2477,0.9313,1.2497,1.3319,1.1914,1.2681,0.8767,0.914,1.1252,1.0423,1.0938,1.3261,0.9234,1.1647,1.1742,1.3511,1.2879,1.1139,0.9547,1.0502,1.2057,1.0737,0.8647,1.042,1.1199,1.1097,1.1438,1.1939,1.1745,1.267,1.2909,1.2115,1.0847,1.2256,1.3024,1.2499,1.1038,1.127,1.1292,1.0415,1.141,1.0257,0.9002,1.2823,0.7392,1.4098,1.3841,1.1846,1.3944,1.245,1.0152,1.0226],"y":[0.6372,0.4472,0.4242,0.5406,0.4983,0.4564,0.5061,0.4683,0.4368,0.4935,0.4685,0.555,0.5082,0.4736,0.532,0.5376,0.8222,0.7289,0.4493,0.4239,0.416,0.3982,0.4608,0.4588,0.5889,0.4983,0.4266,0.4646,0.5163,0.4953,0.4702,0.4588,0.5214,0.5225,0.3785,0.4832,0.5053,0.4834,0.5658,0.5028,0.5529,0.4805,0.4833,0.5062,0.51,0.5866,0.4722,0.4723,0.5354,0.5912,0.5239,0.4115,0.5303,0.508,0.5061,0.5873,0.5482,0.6444,0.3966,0.4358,0.3647,0.4274,0.3854,0.5743,0.5037,0.5456,0.4866,0.6277,0.4645,0.4729,0.4616,0.4936,0.5093,0.4274,0.4851,0.4678,0.3733,0.5444,0.4872,0.486,0.4885,0.4398,0.4408,0.4214,0.4318,0.5071,0.5522,0.5508,0.4882,0.7239,0.716,0.7308,0.5742,0.5345,0.5938,0.7066,0.7539,0.5999,0.6413,0.5483,0.523,0.6177,0.4192,0.5203],"text":["FeO: 1.1315<br />CaO: 0.6372<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0823<br />CaO: 0.4472<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3587<br />CaO: 0.4242<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0129<br />CaO: 0.5406<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0643<br />CaO: 0.4983<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0409<br />CaO: 0.4564<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1887<br />CaO: 0.5061<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2041<br />CaO: 0.4683<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1017<br />CaO: 0.4368<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2095<br />CaO: 0.4935<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2112<br />CaO: 0.4685<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1430<br />CaO: 0.5550<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2496<br />CaO: 0.5082<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1858<br />CaO: 0.4736<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2066<br />CaO: 0.5320<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3179<br />CaO: 0.5376<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0336<br />CaO: 0.8222<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.9729<br />CaO: 0.7289<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1329<br />CaO: 0.4493<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1373<br />CaO: 0.4239<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.8631<br />CaO: 0.4160<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0687<br />CaO: 0.3982<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1729<br />CaO: 0.4608<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0532<br />CaO: 0.4588<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0305<br />CaO: 0.5889<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0496<br />CaO: 0.4983<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1446<br />CaO: 0.4266<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1932<br />CaO: 0.4646<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3066<br />CaO: 0.5163<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1275<br />CaO: 0.4953<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1599<br />CaO: 0.4702<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.9698<br />CaO: 0.4588<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.4911<br />CaO: 0.5214<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1076<br />CaO: 0.5225<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.8307<br />CaO: 0.3785<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2290<br />CaO: 0.4832<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3263<br />CaO: 0.5053<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0194<br />CaO: 0.4834<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1735<br />CaO: 0.5658<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.9638<br />CaO: 0.5028<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3610<br />CaO: 0.5529<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0864<br />CaO: 0.4805<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1977<br />CaO: 0.4833<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1600<br />CaO: 0.5062<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3115<br />CaO: 0.5100<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1312<br />CaO: 0.5866<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1702<br />CaO: 0.4722<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3540<br />CaO: 0.4723<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2492<br />CaO: 0.5354<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3172<br />CaO: 0.5912<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0687<br />CaO: 0.5239<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0391<br />CaO: 0.4115<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2477<br />CaO: 0.5303<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.9313<br />CaO: 0.5080<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2497<br />CaO: 0.5061<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3319<br />CaO: 0.5873<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1914<br />CaO: 0.5482<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2681<br />CaO: 0.6444<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.8767<br />CaO: 0.3966<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.9140<br />CaO: 0.4358<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1252<br />CaO: 0.3647<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0423<br />CaO: 0.4274<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0938<br />CaO: 0.3854<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3261<br />CaO: 0.5743<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.9234<br />CaO: 0.5037<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1647<br />CaO: 0.5456<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1742<br />CaO: 0.4866<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3511<br />CaO: 0.6277<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2879<br />CaO: 0.4645<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1139<br />CaO: 0.4729<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.9547<br />CaO: 0.4616<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0502<br />CaO: 0.4936<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2057<br />CaO: 0.5093<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0737<br />CaO: 0.4274<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.8647<br />CaO: 0.4851<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0420<br />CaO: 0.4678<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1199<br />CaO: 0.3733<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1097<br />CaO: 0.5444<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1438<br />CaO: 0.4872<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1939<br />CaO: 0.4860<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1745<br />CaO: 0.4885<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2670<br />CaO: 0.4398<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2909<br />CaO: 0.4408<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2115<br />CaO: 0.4214<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0847<br />CaO: 0.4318<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2256<br />CaO: 0.5071<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3024<br />CaO: 0.5522<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2499<br />CaO: 0.5508<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1038<br />CaO: 0.4882<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1270<br />CaO: 0.7239<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1292<br />CaO: 0.7160<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0415<br />CaO: 0.7308<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1410<br />CaO: 0.5742<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0257<br />CaO: 0.5345<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.9002<br />CaO: 0.5938<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2823<br />CaO: 0.7066<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 0.7392<br />CaO: 0.7539<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.4098<br />CaO: 0.5999<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3841<br />CaO: 0.6413<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.1846<br />CaO: 0.5483<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.3944<br />CaO: 0.5230<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.2450<br />CaO: 0.6177<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0152<br />CaO: 0.4192<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","FeO: 1.0226<br />CaO: 0.5203<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(127,154,245,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.2778,1.2264,0.879,0.9256,1.1411,1.1522,1.0071,1.0867,1.0619,1.1937,1.2447,1.062,1.2079,1.0277,1.2033,1.1561,1.1917,1.2279,1.2167,1.3496,1.4086,1.2117,1.201],"y":[0.4774,0.5122,0.3677,0.387,0.5187,0.5237,0.4406,0.4959,0.5678,0.4648,0.5274,0.446,0.5616,0.3814,0.475,0.5728,0.4429,0.4763,0.4338,0.5313,0.5931,0.4889,0.5739],"text":["FeO: 1.2778<br />CaO: 0.4774<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.2264<br />CaO: 0.5122<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 0.8790<br />CaO: 0.3677<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 0.9256<br />CaO: 0.3870<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.1411<br />CaO: 0.5187<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.1522<br />CaO: 0.5237<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.0071<br />CaO: 0.4406<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.0867<br />CaO: 0.4959<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.0619<br />CaO: 0.5678<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.1937<br />CaO: 0.4648<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.2447<br />CaO: 0.5274<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.0620<br />CaO: 0.4460<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.2079<br />CaO: 0.5616<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.0277<br />CaO: 0.3814<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.2033<br />CaO: 0.4750<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.1561<br />CaO: 0.5728<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.1917<br />CaO: 0.4429<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.2279<br />CaO: 0.4763<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.2167<br />CaO: 0.4338<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.3496<br />CaO: 0.5313<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.4086<br />CaO: 0.5931<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.2117<br />CaO: 0.4889<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","FeO: 1.2010<br />CaO: 0.5739<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(243,109,32,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.4239,1.3992,1.6169,1.511,1.7797,1.4837,1.5169,1.4977,1.7797,1.5537,1.3727,1.6259,1.1187,1.4831,1.4908,1.5049,1.4448,1.6685,1.5434,1.4823,1.5478,1.4628,1.6112,1.5309,1.461,1.4981,1.4122,1.5463,1.3792,1.2068,1.0382,1.3191,1.4838,1.53,1.5591,1.4886,1.6672,1.6617,1.6473,1.4253,1.6148,1.2589,1.3156,1.1689,1.3964,1.2135,1.2766,0.9823,1.6758,1.113,1.3973,1.2582,1.3143,1.4523,1.3777,1.5464,1.052,1.488,1.4843,1.4091,1.6465,1.4594,1.4296,1.4021,1.1728,1.0362,1.2175,1.1409,1.1168,1.314,1.1131,1.27,1.2544,1.4209,1.3973,1.1771,1.1097,0.9711,1.8068,2.0565,1.3435,1.179,1.8985,1.057,1.167,1.4674,1.2782,1.3882,1.1677,1.4395,1.1583,1.5199,1.3316,1.4004,1.0589,1.2798,1.1018,1.4023,1.5622,1.4493,1.4068,1.5177,1.277,1.3755,1.483,1.345,1.5268,1.4329,1.4316,1.4547,1.2878,1.4722,1.0601,1.4174,1.1805,1.112,1.3872,1.4653,1.0683,1.4402,1.2821,1.4674,1.545,1.2092,1.4913,1.2449,1.0435,1.1614,0.9902,1.0491,0.9818,1.2806,1.2846,1.2547,1.6552,1.1489,1.5655,1.5375,1.5062,1.5625,1.5412,1.5373,1.4729,1.2296,1.1774,1.1908,1.3834,1.3145,1.481,1.3072,1.3966,1.2837,1.1684,1.3919,1.3378,1.1592,1.3975,1.3529,1.804,1.1856,1.1072,1.064,1.2698,1.1233,0.8976,1.3406,0.9696,1.2849,1.4364,1.1794,1.2033],"y":[0.7187,0.6785,0.7077,0.9433,0.8528,0.7712,0.7491,0.7389,0.7848,0.7924,0.5287,0.8265,0.6885,0.6968,0.7936,0.7631,0.8421,0.798,0.8183,0.6866,0.7862,0.6856,0.7733,0.7465,0.7963,0.7593,0.7874,0.7553,0.7296,0.829,0.8098,0.9043,0.8046,0.7702,0.7743,0.7918,0.5947,0.7832,0.6527,0.8024,0.8284,0.6065,0.666,0.6986,0.7686,0.8038,0.6769,0.5509,0.6683,0.6841,0.6214,0.6899,0.7344,0.6898,0.5839,0.7322,0.5549,0.7562,0.8519,0.6467,0.7673,0.6303,0.8071,0.6565,0.5974,0.5553,0.5941,0.6331,0.5991,0.6106,0.6197,0.6246,0.6235,0.6693,0.6763,0.5813,0.5288,0.5901,0.6206,0.9126,0.6085,0.6009,1.0087,0.6003,0.5494,0.6814,0.5814,0.665,0.6266,0.6705,0.5181,0.6972,0.7195,0.6077,0.5885,0.6329,0.5672,0.6486,0.6543,0.6277,0.5998,0.6703,0.6081,0.6341,0.7612,0.5379,0.7111,0.643,0.6808,0.745,0.5948,0.6502,0.5537,0.6898,0.545,0.5743,0.6023,0.662,0.509,0.6697,0.6371,0.6668,0.5674,0.585,0.665,0.6439,0.5451,0.596,0.5292,0.6546,0.5839,0.6039,0.65,0.7173,0.9806,0.7642,0.7565,0.7952,0.7531,0.7707,0.8023,0.7316,0.7891,0.6505,0.7247,0.622,0.7002,0.6138,0.6498,0.7048,0.6414,0.6709,0.7378,0.6915,0.5595,0.6497,0.6257,0.6815,1.0685,0.6389,0.5695,0.9084,0.6387,0.5827,0.6259,0.5842,0.6437,0.5826,0.6406,0.7078,0.6729],"text":["FeO: 1.4239<br />CaO: 0.7187<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3992<br />CaO: 0.6785<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6169<br />CaO: 0.7077<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5110<br />CaO: 0.9433<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.7797<br />CaO: 0.8528<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4837<br />CaO: 0.7712<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5169<br />CaO: 0.7491<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4977<br />CaO: 0.7389<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.7797<br />CaO: 0.7848<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5537<br />CaO: 0.7924<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3727<br />CaO: 0.5287<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6259<br />CaO: 0.8265<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1187<br />CaO: 0.6885<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4831<br />CaO: 0.6968<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4908<br />CaO: 0.7936<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5049<br />CaO: 0.7631<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4448<br />CaO: 0.8421<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6685<br />CaO: 0.7980<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5434<br />CaO: 0.8183<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4823<br />CaO: 0.6866<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5478<br />CaO: 0.7862<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4628<br />CaO: 0.6856<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6112<br />CaO: 0.7733<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5309<br />CaO: 0.7465<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4610<br />CaO: 0.7963<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4981<br />CaO: 0.7593<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4122<br />CaO: 0.7874<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5463<br />CaO: 0.7553<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3792<br />CaO: 0.7296<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2068<br />CaO: 0.8290<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0382<br />CaO: 0.8098<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3191<br />CaO: 0.9043<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4838<br />CaO: 0.8046<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5300<br />CaO: 0.7702<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5591<br />CaO: 0.7743<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4886<br />CaO: 0.7918<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6672<br />CaO: 0.5947<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6617<br />CaO: 0.7832<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6473<br />CaO: 0.6527<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4253<br />CaO: 0.8024<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6148<br />CaO: 0.8284<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2589<br />CaO: 0.6065<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3156<br />CaO: 0.6660<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1689<br />CaO: 0.6986<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3964<br />CaO: 0.7686<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2135<br />CaO: 0.8038<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2766<br />CaO: 0.6769<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9823<br />CaO: 0.5509<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6758<br />CaO: 0.6683<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1130<br />CaO: 0.6841<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3973<br />CaO: 0.6214<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2582<br />CaO: 0.6899<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3143<br />CaO: 0.7344<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4523<br />CaO: 0.6898<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3777<br />CaO: 0.5839<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5464<br />CaO: 0.7322<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0520<br />CaO: 0.5549<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4880<br />CaO: 0.7562<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4843<br />CaO: 0.8519<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4091<br />CaO: 0.6467<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6465<br />CaO: 0.7673<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4594<br />CaO: 0.6303<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4296<br />CaO: 0.8071<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4021<br />CaO: 0.6565<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1728<br />CaO: 0.5974<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0362<br />CaO: 0.5553<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2175<br />CaO: 0.5941<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1409<br />CaO: 0.6331<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1168<br />CaO: 0.5991<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3140<br />CaO: 0.6106<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1131<br />CaO: 0.6197<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2700<br />CaO: 0.6246<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2544<br />CaO: 0.6235<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4209<br />CaO: 0.6693<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3973<br />CaO: 0.6763<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1771<br />CaO: 0.5813<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1097<br />CaO: 0.5288<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9711<br />CaO: 0.5901<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.8068<br />CaO: 0.6206<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 2.0565<br />CaO: 0.9126<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3435<br />CaO: 0.6085<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1790<br />CaO: 0.6009<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.8985<br />CaO: 1.0087<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0570<br />CaO: 0.6003<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1670<br />CaO: 0.5494<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4674<br />CaO: 0.6814<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2782<br />CaO: 0.5814<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3882<br />CaO: 0.6650<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1677<br />CaO: 0.6266<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4395<br />CaO: 0.6705<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1583<br />CaO: 0.5181<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5199<br />CaO: 0.6972<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3316<br />CaO: 0.7195<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4004<br />CaO: 0.6077<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0589<br />CaO: 0.5885<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2798<br />CaO: 0.6329<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1018<br />CaO: 0.5672<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4023<br />CaO: 0.6486<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5622<br />CaO: 0.6543<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4493<br />CaO: 0.6277<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4068<br />CaO: 0.5998<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5177<br />CaO: 0.6703<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2770<br />CaO: 0.6081<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3755<br />CaO: 0.6341<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4830<br />CaO: 0.7612<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3450<br />CaO: 0.5379<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5268<br />CaO: 0.7111<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4329<br />CaO: 0.6430<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4316<br />CaO: 0.6808<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4547<br />CaO: 0.7450<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2878<br />CaO: 0.5948<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4722<br />CaO: 0.6502<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0601<br />CaO: 0.5537<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4174<br />CaO: 0.6898<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1805<br />CaO: 0.5450<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1120<br />CaO: 0.5743<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3872<br />CaO: 0.6023<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4653<br />CaO: 0.6620<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0683<br />CaO: 0.5090<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4402<br />CaO: 0.6697<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2821<br />CaO: 0.6371<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4674<br />CaO: 0.6668<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5450<br />CaO: 0.5674<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2092<br />CaO: 0.5850<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4913<br />CaO: 0.6650<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2449<br />CaO: 0.6439<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0435<br />CaO: 0.5451<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1614<br />CaO: 0.5960<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9902<br />CaO: 0.5292<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0491<br />CaO: 0.6546<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9818<br />CaO: 0.5839<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2806<br />CaO: 0.6039<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2846<br />CaO: 0.6500<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2547<br />CaO: 0.7173<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6552<br />CaO: 0.9806<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1489<br />CaO: 0.7642<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5655<br />CaO: 0.7565<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5375<br />CaO: 0.7952<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5062<br />CaO: 0.7531<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5625<br />CaO: 0.7707<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5412<br />CaO: 0.8023<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5373<br />CaO: 0.7316<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4729<br />CaO: 0.7891<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2296<br />CaO: 0.6505<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1774<br />CaO: 0.7247<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1908<br />CaO: 0.6220<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3834<br />CaO: 0.7002<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3145<br />CaO: 0.6138<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4810<br />CaO: 0.6498<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3072<br />CaO: 0.7048<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3966<br />CaO: 0.6414<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2837<br />CaO: 0.6709<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1684<br />CaO: 0.7378<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3919<br />CaO: 0.6915<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3378<br />CaO: 0.5595<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1592<br />CaO: 0.6497<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3975<br />CaO: 0.6257<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3529<br />CaO: 0.6815<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.8040<br />CaO: 1.0685<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1856<br />CaO: 0.6389<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1072<br />CaO: 0.5695<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0640<br />CaO: 0.9084<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2698<br />CaO: 0.6387<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1233<br />CaO: 0.5827<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.8976<br />CaO: 0.6259<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3406<br />CaO: 0.5842<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9696<br />CaO: 0.6437<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2849<br />CaO: 0.5826<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4364<br />CaO: 0.6406<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1794<br />CaO: 0.7078<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2033<br />CaO: 0.6729<br />id: Penifiler Tephra<br />id: Penifiler Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(11,48,117,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null}],"layout":{"margin":{"t":25.1324200913242,"r":7.30593607305936,"b":55.2926525529265,"l":64.0929846409298},"plot_bgcolor":"rgba(255,255,255,1)","paper_bgcolor":"rgba(255,255,255,1)","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187},"xaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":false,"range":[0.673335,2.122365],"tickmode":"array","ticktext":["1.0","1.5","2.0"],"tickvals":[1,1.5,2],"categoryorder":"array","categoryarray":["1.0","1.5","2.0"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"y","title":{"text":"FeO (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"yaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":false,"range":[0.316085,1.112815],"tickmode":"array","ticktext":["0.5","0.7","0.9","1.1"],"tickvals":[0.5,0.7,0.9,1.1],"categoryorder":"array","categoryarray":["0.5","0.7","0.9","1.1"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"x","title":{"text":"CaO (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"shapes":[{"type":"rect","fillcolor":"transparent","line":{"color":"rgba(51,51,51,1)","width":0.66417600664176,"linetype":"solid"},"yref":"paper","xref":"paper","x0":0,"x1":1,"y0":0,"y1":1}],"showlegend":true,"legend":{"bgcolor":"rgba(255,255,255,1)","bordercolor":"transparent","borderwidth":1.88976377952756,"font":{"color":"rgba(0,0,0,1)","family":"","size":11.689497716895},"title":{"text":"id","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187}}},"hovermode":"closest","width":1000,"height":800,"barmode":"relative"},"config":{"doubleClick":"reset","modeBarButtonsToAdd":["hoverclosest","hovercompare"],"showSendToCloud":false},"source":"A","attrs":{"7243a8f6963":{"x":{},"y":{},"fill":{},"shape":{},"type":"scatter"}},"cur_data":"7243a8f6963","visdat":{"7243a8f6963":["function (y) ","x"]},"highlight":{"on":"plotly_click","persistent":false,"dynamic":false,"selectize":false,"opacityDim":0.2,"selected":{"opacity":1},"debounce":0},"shinyEvents":["plotly_hover","plotly_click","plotly_selected","plotly_relayout","plotly_brushed","plotly_brushing","plotly_clickannotation","plotly_doubleclick","plotly_deselect","plotly_afterplot","plotly_sunburstclick"],"base_url":"https://plot.ly"},"evals":[],"jsHooks":[]}</script>

## iK-lines

<div id="htmlwidget-b85bf888dc62471906a9" style="width:1000px;height:800px;" class="plotly html-widget"></div>
<script type="application/json" data-for="htmlwidget-b85bf888dc62471906a9">{"x":{"data":[{"x":[76.6414,76.0912],"y":[4.9147,4.6207],"text":["SiO2: 76.6414<br />K2O: 4.9147<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","SiO2: 76.0912<br />K2O: 4.6207<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(32,154,36,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[75.9663,76.5964,76.2677,75.9144,77.1796,76.2725,76.4748,76.2156,76.4877,77.0297,75.8987,76.2993],"y":[3.8645,3.926,3.9026,3.9396,3.7375,4.0257,4.0407,3.958,3.8017,3.9353,4.1265,3.8413],"text":["SiO2: 75.9663<br />K2O: 3.8645<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 76.5964<br />K2O: 3.9260<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 76.2677<br />K2O: 3.9026<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 75.9144<br />K2O: 3.9396<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 77.1796<br />K2O: 3.7375<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 76.2725<br />K2O: 4.0257<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 76.4748<br />K2O: 4.0407<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 76.2156<br />K2O: 3.9580<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 76.4877<br />K2O: 3.8017<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 77.0297<br />K2O: 3.9353<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 75.8987<br />K2O: 4.1265<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","SiO2: 76.2993<br />K2O: 3.8413<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(167,105,238,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77.0388,75.9572,75.9818,76.8359,77.4005,75.9243,75.9255,76.3097],"y":[3.9084,4.0527,4.0832,3.9885,3.969,4.0446,3.9939,3.8609],"text":["SiO2: 77.0388<br />K2O: 3.9084<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","SiO2: 75.9572<br />K2O: 4.0527<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","SiO2: 75.9818<br />K2O: 4.0832<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","SiO2: 76.8359<br />K2O: 3.9885<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","SiO2: 77.4005<br />K2O: 3.9690<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","SiO2: 75.9243<br />K2O: 4.0446<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","SiO2: 75.9255<br />K2O: 3.9939<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","SiO2: 76.3097<br />K2O: 3.8609<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(180,196,40,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.7014,75.8117,75.4456,75.8194,76.0043,75.7921,76.0123,75.8281,75.9908,75.5313,75.9727,75.7785,75.7024,75.6315,76.3654,76.2871,75.5975,75.4888,75.5051,75.5283,75.2661,76.5414,75.7045,76.0911,76.1363,76.0117,75.7475,75.7048,76.1105,75.9877,75.7893,75.8453,76.0402,75.8036,75.997],"y":[3.8218,3.9253,3.8797,3.8743,3.8076,3.955,3.9586,3.8575,3.8128,3.9921,3.9881,3.7914,4.018,3.9546,4.0097,3.8067,3.9509,4.0063,3.8028,4.1124,4.01,3.9196,3.8586,4.0011,3.8758,3.9892,3.7353,3.9513,3.965,3.9965,3.9339,4.0229,4.0402,3.969,4.1691],"text":["SiO2: 76.7014<br />K2O: 3.8218<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.8117<br />K2O: 3.9253<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.4456<br />K2O: 3.8797<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.8194<br />K2O: 3.8743<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.0043<br />K2O: 3.8076<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.7921<br />K2O: 3.9550<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.0123<br />K2O: 3.9586<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.8281<br />K2O: 3.8575<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.9908<br />K2O: 3.8128<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.5313<br />K2O: 3.9921<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.9727<br />K2O: 3.9881<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.7785<br />K2O: 3.7914<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.7024<br />K2O: 4.0180<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.6315<br />K2O: 3.9546<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.3654<br />K2O: 4.0097<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.2871<br />K2O: 3.8067<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.5975<br />K2O: 3.9509<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.4888<br />K2O: 4.0063<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.5051<br />K2O: 3.8028<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.5283<br />K2O: 4.1124<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.2661<br />K2O: 4.0100<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.5414<br />K2O: 3.9196<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.7045<br />K2O: 3.8586<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.0911<br />K2O: 4.0011<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.1363<br />K2O: 3.8758<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.0117<br />K2O: 3.9892<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.7475<br />K2O: 3.7353<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.7048<br />K2O: 3.9513<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.1105<br />K2O: 3.9650<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.9877<br />K2O: 3.9965<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.7893<br />K2O: 3.9339<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.8453<br />K2O: 4.0229<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 76.0402<br />K2O: 4.0402<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.8036<br />K2O: 3.9690<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","SiO2: 75.9970<br />K2O: 4.1691<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(227,3,3,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.7606,76.7047,76.5887,76.589,76.6379,76.5536,76.6994,76.5965,76.6224,76.5877,76.5152,76.7566,76.2112,76.3371,76.6227,76.3625,76.4496,76.771,77.0719,76.2737,76.6759,76.3208,76.2672,76.4286,76.4247,76.6663,76.9906,76.1981,76.84,76.9193,76.8105,76.7597,76.5003,77.1195,76.3105,76.7366,76.4287,77.1186,76.3377,77.0422,77.0535,76.7902,76.6552,76.8116,76.5644,76.4784,76.3839,76.1324,76.2735,76.145,75.9065,75.8918,76.1635,75.9462,76.0865,76.1092,76.311,76.2173,76.3627,76.5086,75.7198,76.473,76.115,76.4731,76.7982,76.2335,76.2971,76.5464,76.8259,76.2424,76.3306,75.9945,77.4177,76.2744,76.1804,76.576,76.4724,76.2179,75.7236,76.3775,75.2246,75.8105,76.0538,76.1644,76.462,76.7912,75.9229,76.8551,76.3213,76.4768,76.2874,76.4336,76.4625,76.5277,75.987,76.751,76.4131,76.0092,76.0202,76.3043,76.7104,76.1884,76.6914,76.3526,76.2636,76.0935,76.3767,76.23,75.9413,75.8843,75.9392,76.9263,76.9183,76.7868,76.5575,76.7074,76.8842,76.9126,76.683,76.8408,75.3745,76.2896,75.9703,76.3398],"y":[4.047,3.8791,3.805,4.0762,4.0026,3.93,3.8949,3.9131,4.0203,3.8354,3.9763,3.8936,3.9523,3.9952,3.8675,4.1725,4.0111,3.8279,4.0494,3.9118,3.8432,3.7777,4.0133,3.8349,3.8755,4.0017,3.7891,3.8678,3.8988,4.0104,3.953,3.7472,3.8288,3.8085,3.9449,3.7617,3.8212,3.5963,3.8774,3.7684,3.8462,4.0115,3.9356,3.6891,3.6751,3.7454,3.9898,4.0042,3.9353,3.8633,4.0173,3.8066,4.13,4.0559,3.9996,4.0046,3.9305,3.9516,3.9518,4.0057,3.9786,3.8237,3.9079,3.9631,3.8739,3.8631,3.9071,3.9841,3.9159,4.1204,4.0075,4.0306,3.9063,3.8778,3.9823,3.97,3.8566,3.9306,3.922,3.876,4.0213,3.9053,4.0171,3.9199,3.9683,3.7454,3.8366,3.6838,4.0373,3.9662,4.0273,4.0151,3.9916,4.0729,4.0491,3.9893,4.1422,4.035,3.9646,3.9326,3.9727,3.8899,3.9914,4.0136,3.9253,3.9906,3.9574,3.9473,4.0537,4.084,4.1098,4.0064,3.847,3.9904,3.921,4.0367,3.8767,4.0184,3.9434,3.9623,4.0636,3.899,4.0722,3.9563],"text":["SiO2: 76.7606<br />K2O: 4.0470<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7047<br />K2O: 3.8791<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5887<br />K2O: 3.8050<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5890<br />K2O: 4.0762<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.6379<br />K2O: 4.0026<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5536<br />K2O: 3.9300<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.6994<br />K2O: 3.8949<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5965<br />K2O: 3.9131<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.6224<br />K2O: 4.0203<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5877<br />K2O: 3.8354<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5152<br />K2O: 3.9763<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7566<br />K2O: 3.8936<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2112<br />K2O: 3.9523<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3371<br />K2O: 3.9952<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.6227<br />K2O: 3.8675<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3625<br />K2O: 4.1725<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4496<br />K2O: 4.0111<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7710<br />K2O: 3.8279<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 77.0719<br />K2O: 4.0494<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2737<br />K2O: 3.9118<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.6759<br />K2O: 3.8432<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3208<br />K2O: 3.7777<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2672<br />K2O: 4.0133<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4286<br />K2O: 3.8349<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4247<br />K2O: 3.8755<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.6663<br />K2O: 4.0017<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.9906<br />K2O: 3.7891<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.1981<br />K2O: 3.8678<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.8400<br />K2O: 3.8988<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.9193<br />K2O: 4.0104<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.8105<br />K2O: 3.9530<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7597<br />K2O: 3.7472<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5003<br />K2O: 3.8288<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 77.1195<br />K2O: 3.8085<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3105<br />K2O: 3.9449<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7366<br />K2O: 3.7617<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4287<br />K2O: 3.8212<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 77.1186<br />K2O: 3.5963<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3377<br />K2O: 3.8774<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 77.0422<br />K2O: 3.7684<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 77.0535<br />K2O: 3.8462<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7902<br />K2O: 4.0115<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.6552<br />K2O: 3.9356<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.8116<br />K2O: 3.6891<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5644<br />K2O: 3.6751<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4784<br />K2O: 3.7454<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3839<br />K2O: 3.9898<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.1324<br />K2O: 4.0042<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2735<br />K2O: 3.9353<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.1450<br />K2O: 3.8633<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.9065<br />K2O: 4.0173<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.8918<br />K2O: 3.8066<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.1635<br />K2O: 4.1300<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.9462<br />K2O: 4.0559<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.0865<br />K2O: 3.9996<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.1092<br />K2O: 4.0046<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3110<br />K2O: 3.9305<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2173<br />K2O: 3.9516<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3627<br />K2O: 3.9518<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5086<br />K2O: 4.0057<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.7198<br />K2O: 3.9786<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4730<br />K2O: 3.8237<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.1150<br />K2O: 3.9079<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4731<br />K2O: 3.9631<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7982<br />K2O: 3.8739<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2335<br />K2O: 3.8631<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2971<br />K2O: 3.9071<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5464<br />K2O: 3.9841<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.8259<br />K2O: 3.9159<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2424<br />K2O: 4.1204<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3306<br />K2O: 4.0075<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.9945<br />K2O: 4.0306<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 77.4177<br />K2O: 3.9063<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2744<br />K2O: 3.8778<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.1804<br />K2O: 3.9823<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5760<br />K2O: 3.9700<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4724<br />K2O: 3.8566<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2179<br />K2O: 3.9306<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.7236<br />K2O: 3.9220<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3775<br />K2O: 3.8760<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.2246<br />K2O: 4.0213<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.8105<br />K2O: 3.9053<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.0538<br />K2O: 4.0171<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.1644<br />K2O: 3.9199<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4620<br />K2O: 3.9683<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7912<br />K2O: 3.7454<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.9229<br />K2O: 3.8366<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.8551<br />K2O: 3.6838<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3213<br />K2O: 4.0373<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4768<br />K2O: 3.9662<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2874<br />K2O: 4.0273<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4336<br />K2O: 4.0151<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4625<br />K2O: 3.9916<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5277<br />K2O: 4.0729<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.9870<br />K2O: 4.0491<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7510<br />K2O: 3.9893<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.4131<br />K2O: 4.1422<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.0092<br />K2O: 4.0350<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.0202<br />K2O: 3.9646<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3043<br />K2O: 3.9326<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7104<br />K2O: 3.9727<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.1884<br />K2O: 3.8899<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.6914<br />K2O: 3.9914<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3526<br />K2O: 4.0136<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2636<br />K2O: 3.9253<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.0935<br />K2O: 3.9906<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3767<br />K2O: 3.9574<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2300<br />K2O: 3.9473<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.9413<br />K2O: 4.0537<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.8843<br />K2O: 4.0840<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.9392<br />K2O: 4.1098<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.9263<br />K2O: 4.0064<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.9183<br />K2O: 3.8470<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7868<br />K2O: 3.9904<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.5575<br />K2O: 3.9210<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.7074<br />K2O: 4.0367<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.8842<br />K2O: 3.8767<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.9126<br />K2O: 4.0184<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.6830<br />K2O: 3.9434<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.8408<br />K2O: 3.9623<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.3745<br />K2O: 4.0636<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.2896<br />K2O: 3.8990<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 75.9703<br />K2O: 4.0722<br />id: Borrobol Tephra<br />id: Borrobol Tephra","SiO2: 76.3398<br />K2O: 3.9563<br />id: Borrobol Tephra<br />id: Borrobol Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(0,0,0,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.251,76.6084,76.3589,76.3348,76.5163,76.6116,76.5044,77.1132,76.3445,76.4144,76.2334,76.3172,76.836],"y":[4.0012,3.8413,3.9559,3.9285,3.9874,4.059,3.9072,4.3302,3.9143,3.8505,3.8756,3.8546,3.9916],"text":["SiO2: 76.2510<br />K2O: 4.0012<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.6084<br />K2O: 3.8413<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.3589<br />K2O: 3.9559<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.3348<br />K2O: 3.9285<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.5163<br />K2O: 3.9874<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.6116<br />K2O: 4.0590<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.5044<br />K2O: 3.9072<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 77.1132<br />K2O: 4.3302<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.3445<br />K2O: 3.9143<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.4144<br />K2O: 3.8505<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.2334<br />K2O: 3.8756<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.3172<br />K2O: 3.8546<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","SiO2: 76.8360<br />K2O: 3.9916<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(239,19,157,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.5676,76.5808,76.5481,76.5047,76.7719,75.3898,76.8377,76.021,75.808,76.537,76.5586,76.3852,76.8061,76.1983,76.0111,76.1876,75.6226,76.4895,76.4996,77.5249,77.711],"y":[3.8892,4.0667,3.9154,3.9244,3.8545,3.9645,3.9509,3.9185,3.98,4.1526,3.7472,3.9098,3.9754,3.9098,3.9366,4.0366,4.0392,4.0334,3.754,4.0307,4.0258],"text":["SiO2: 76.5676<br />K2O: 3.8892<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.5808<br />K2O: 4.0667<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.5481<br />K2O: 3.9154<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.5047<br />K2O: 3.9244<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.7719<br />K2O: 3.8545<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 75.3898<br />K2O: 3.9645<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.8377<br />K2O: 3.9509<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.0210<br />K2O: 3.9185<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 75.8080<br />K2O: 3.9800<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.5370<br />K2O: 4.1526<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.5586<br />K2O: 3.7472<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.3852<br />K2O: 3.9098<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.8061<br />K2O: 3.9754<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.1983<br />K2O: 3.9098<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.0111<br />K2O: 3.9366<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.1876<br />K2O: 4.0366<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 75.6226<br />K2O: 4.0392<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.4895<br />K2O: 4.0334<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 76.4996<br />K2O: 3.7540<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 77.5249<br />K2O: 4.0307<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","SiO2: 77.7110<br />K2O: 4.0258<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(58,112,15,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.0422,76.6732,76.6344,76.174,76.6436,76.8117,76.6803,76.88,76.2943,76.6069,76.5275,76.7478,76.9616,76.3331,76.9919,76.6496,76.6541,76.2446,76.8419,77.0577,76.6357,76.8808,76.9151,76.5024,76.6051,76.6881,77.0639,76.9429],"y":[4.0202,3.9697,3.9324,3.9588,3.8883,4.1087,3.8667,3.796,3.8975,3.8257,3.9889,3.9451,3.923,3.9578,3.9702,3.7459,3.8543,4.0731,3.6984,3.8694,3.8751,3.8855,3.9306,3.9689,3.8744,3.9055,3.85,3.8513],"text":["SiO2: 76.0422<br />K2O: 4.0202<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6732<br />K2O: 3.9697<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6344<br />K2O: 3.9324<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.1740<br />K2O: 3.9588<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6436<br />K2O: 3.8883<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.8117<br />K2O: 4.1087<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6803<br />K2O: 3.8667<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.8800<br />K2O: 3.7960<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.2943<br />K2O: 3.8975<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6069<br />K2O: 3.8257<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.5275<br />K2O: 3.9889<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.7478<br />K2O: 3.9451<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.9616<br />K2O: 3.9230<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.3331<br />K2O: 3.9578<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.9919<br />K2O: 3.9702<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6496<br />K2O: 3.7459<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6541<br />K2O: 3.8543<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.2446<br />K2O: 4.0731<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.8419<br />K2O: 3.6984<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 77.0577<br />K2O: 3.8694<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6357<br />K2O: 3.8751<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.8808<br />K2O: 3.8855<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.9151<br />K2O: 3.9306<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.5024<br />K2O: 3.9689<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6051<br />K2O: 3.8744<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.6881<br />K2O: 3.9055<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 77.0639<br />K2O: 3.8500<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","SiO2: 76.9429<br />K2O: 3.8513<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(82,136,255,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77.1741,76.8465,76.4511,76.9551,76.54,76.5951,76.4123,77.136,76.6504,78.0441],"y":[3.705,4.1507,4.0601,3.9232,3.8633,3.9632,4.0053,3.9183,3.8371,4.7937],"text":["SiO2: 77.1741<br />K2O: 3.7050<br />id: Fosen Tephra<br />id: Fosen Tephra","SiO2: 76.8465<br />K2O: 4.1507<br />id: Fosen Tephra<br />id: Fosen Tephra","SiO2: 76.4511<br />K2O: 4.0601<br />id: Fosen Tephra<br />id: Fosen Tephra","SiO2: 76.9551<br />K2O: 3.9232<br />id: Fosen Tephra<br />id: Fosen Tephra","SiO2: 76.5400<br />K2O: 3.8633<br />id: Fosen Tephra<br />id: Fosen Tephra","SiO2: 76.5951<br />K2O: 3.9632<br />id: Fosen Tephra<br />id: Fosen Tephra","SiO2: 76.4123<br />K2O: 4.0053<br />id: Fosen Tephra<br />id: Fosen Tephra","SiO2: 77.1360<br />K2O: 3.9183<br />id: Fosen Tephra<br />id: Fosen Tephra","SiO2: 76.6504<br />K2O: 3.8371<br />id: Fosen Tephra<br />id: Fosen Tephra","SiO2: 78.0441<br />K2O: 4.7937<br />id: Fosen Tephra<br />id: Fosen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(230,71,1,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77.0902,77.9979,77.6365,78.0018,78.2455,77.9557,78.0717,78.3756,77.997,78.0799,78.1732,78.6674,77.5137,77.92,77.5632,78.1672,75.9142,76.5213,77.7823,77.9156,78.0574,78.049,77.872,77.4453,77.3502,77.6506,77.8356,77.4023,77.3446,77.9768,77.7429,77.7894,77.3723,77.7429,77.918,77.2059,77.1579,77.7824,77.2946,78.2317,77.3525,77.6037,77.5163,77.9606,77.8703,77.616,77.7972,77.0337,77.5667,77.4528,77.8604,77.7778,77.5733,78.2834,77.9281,77.441,78.1339,77.6946,78.3321,78.2336,78.5476,77.9862,77.7083,77.8427,77.3767,77.1459,77.6262,76.2979,77.4095,77.6482,78.3361,78.0928,76.3954,77.5774,78.2242,78.0117,77.8723,77.5858,77.992,78.2779,78.1,77.9372,78.1066,78.1922,78.2961,78.1722,77.9433,77.5553,78.0195,78.4613,78.6553,78.5774,78.2117,78.1682,78.0418,77.993,77.6006,76.9205,77.3437,77.2667,77.264,76.5211,78.1632,77.0655],"y":[3.817,4.2334,4.3654,4.2497,4.1885,4.2572,4.1064,4.2504,4.0727,4.3622,4.3783,4.4741,4.3945,4.3405,4.0722,4.2631,4.6049,4.4894,4.5012,4.2701,4.2429,4.3692,4.4717,4.3483,4.2587,4.665,4.3184,4.2978,4.0569,4.1834,4.0334,4.3691,4.0146,4.0752,4.4059,4.1597,3.9158,4.8135,4.1282,4.3369,3.9022,4.1157,4.1395,3.9544,4.2157,4.1584,4.1983,4.3246,4.0416,3.9826,4.1806,4.2078,4.4292,4.2544,4.0074,4.1217,4.0169,4.0121,4.3419,4.315,4.4593,4.6279,4.1667,4.3959,4.3337,4.2288,4.1468,4.2872,4.0853,4.3401,4.2593,4.2638,4.1991,4.6492,4.2603,4.2637,4.1891,4.3865,4.247,4.3001,4.2095,4.356,4.3136,4.2984,4.4861,4.3212,4.23,4.5016,4.5319,3.475,3.5018,3.9225,3.815,3.8096,3.8339,3.2427,3.9874,4.1135,4.3683,4.3737,4.3876,4.452,4.3634,4.197],"text":["SiO2: 77.0902<br />K2O: 3.8170<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9979<br />K2O: 4.2334<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.6365<br />K2O: 4.3654<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.0018<br />K2O: 4.2497<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.2455<br />K2O: 4.1885<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9557<br />K2O: 4.2572<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.0717<br />K2O: 4.1064<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.3756<br />K2O: 4.2504<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9970<br />K2O: 4.0727<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.0799<br />K2O: 4.3622<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.1732<br />K2O: 4.3783<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.6674<br />K2O: 4.4741<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.5137<br />K2O: 4.3945<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9200<br />K2O: 4.3405<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.5632<br />K2O: 4.0722<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.1672<br />K2O: 4.2631<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 75.9142<br />K2O: 4.6049<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 76.5213<br />K2O: 4.4894<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.7823<br />K2O: 4.5012<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9156<br />K2O: 4.2701<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.0574<br />K2O: 4.2429<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.0490<br />K2O: 4.3692<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.8720<br />K2O: 4.4717<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.4453<br />K2O: 4.3483<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.3502<br />K2O: 4.2587<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.6506<br />K2O: 4.6650<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.8356<br />K2O: 4.3184<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.4023<br />K2O: 4.2978<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.3446<br />K2O: 4.0569<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9768<br />K2O: 4.1834<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.7429<br />K2O: 4.0334<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.7894<br />K2O: 4.3691<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.3723<br />K2O: 4.0146<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.7429<br />K2O: 4.0752<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9180<br />K2O: 4.4059<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.2059<br />K2O: 4.1597<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.1579<br />K2O: 3.9158<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.7824<br />K2O: 4.8135<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.2946<br />K2O: 4.1282<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.2317<br />K2O: 4.3369<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.3525<br />K2O: 3.9022<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.6037<br />K2O: 4.1157<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.5163<br />K2O: 4.1395<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9606<br />K2O: 3.9544<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.8703<br />K2O: 4.2157<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.6160<br />K2O: 4.1584<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.7972<br />K2O: 4.1983<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.0337<br />K2O: 4.3246<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.5667<br />K2O: 4.0416<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.4528<br />K2O: 3.9826<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.8604<br />K2O: 4.1806<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.7778<br />K2O: 4.2078<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.5733<br />K2O: 4.4292<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.2834<br />K2O: 4.2544<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9281<br />K2O: 4.0074<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.4410<br />K2O: 4.1217<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.1339<br />K2O: 4.0169<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.6946<br />K2O: 4.0121<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.3321<br />K2O: 4.3419<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.2336<br />K2O: 4.3150<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.5476<br />K2O: 4.4593<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9862<br />K2O: 4.6279<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.7083<br />K2O: 4.1667<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.8427<br />K2O: 4.3959<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.3767<br />K2O: 4.3337<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.1459<br />K2O: 4.2288<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.6262<br />K2O: 4.1468<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 76.2979<br />K2O: 4.2872<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.4095<br />K2O: 4.0853<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.6482<br />K2O: 4.3401<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.3361<br />K2O: 4.2593<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.0928<br />K2O: 4.2638<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 76.3954<br />K2O: 4.1991<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.5774<br />K2O: 4.6492<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.2242<br />K2O: 4.2603<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.0117<br />K2O: 4.2637<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.8723<br />K2O: 4.1891<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.5858<br />K2O: 4.3865<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9920<br />K2O: 4.2470<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.2779<br />K2O: 4.3001<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.1000<br />K2O: 4.2095<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9372<br />K2O: 4.3560<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.1066<br />K2O: 4.3136<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.1922<br />K2O: 4.2984<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.2961<br />K2O: 4.4861<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.1722<br />K2O: 4.3212<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9433<br />K2O: 4.2300<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.5553<br />K2O: 4.5016<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.0195<br />K2O: 4.5319<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.4613<br />K2O: 3.4750<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.6553<br />K2O: 3.5018<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.5774<br />K2O: 3.9225<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.2117<br />K2O: 3.8150<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.1682<br />K2O: 3.8096<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.0418<br />K2O: 3.8339<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.9930<br />K2O: 3.2427<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.6006<br />K2O: 3.9874<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 76.9205<br />K2O: 4.1135<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.3437<br />K2O: 4.3683<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.2667<br />K2O: 4.3737<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.2640<br />K2O: 4.3876<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 76.5211<br />K2O: 4.4520<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 78.1632<br />K2O: 4.3634<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","SiO2: 77.0655<br />K2O: 4.1970<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(127,154,245,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[76.3258,77.8075,76.8763,77.1161,77.6452,78.2549,78.1683,78.5187,78.0465,78.4069,78.2806,78.5578,78.3535,78.0909,77.7919,78.1714,77.7157,77.8977,77.8565,78.0234,77.7272,77.9018,77.7766],"y":[5.7971,4.1246,5.9052,5.8832,4.2324,4.1479,4.1754,3.8616,4.0479,4.1517,4.2405,4.1737,4.2276,4.2801,4.2432,4.0624,4.2396,4.0754,4.2319,3.9745,4.194,4.156,4.2619],"text":["SiO2: 76.3258<br />K2O: 5.7971<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.8075<br />K2O: 4.1246<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 76.8763<br />K2O: 5.9052<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.1161<br />K2O: 5.8832<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.6452<br />K2O: 4.2324<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.2549<br />K2O: 4.1479<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.1683<br />K2O: 4.1754<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.5187<br />K2O: 3.8616<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.0465<br />K2O: 4.0479<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.4069<br />K2O: 4.1517<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.2806<br />K2O: 4.2405<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.5578<br />K2O: 4.1737<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.3535<br />K2O: 4.2276<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.0909<br />K2O: 4.2801<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.7919<br />K2O: 4.2432<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.1714<br />K2O: 4.0624<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.7157<br />K2O: 4.2396<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.8977<br />K2O: 4.0754<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.8565<br />K2O: 4.2319<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 78.0234<br />K2O: 3.9745<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.7272<br />K2O: 4.1940<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.9018<br />K2O: 4.1560<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","SiO2: 77.7766<br />K2O: 4.2619<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(243,109,32,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[77.0444,76.9022,76.5738,75.9228,75.8915,76.473,76.1159,76.3197,76.3854,76.2474,77.8524,76.121,77.0319,76.4407,76.5314,76.1896,76.6545,76.1691,76.7503,76.8278,76.792,76.9405,76.8066,76.5228,76.9615,76.6458,76.351,75.8413,76.368,76.9336,77.2737,76.6702,76.1129,75.8639,76.7396,76.3936,76.3194,76.3442,76.5748,76.478,75.81,76.9535,76.8945,77.2931,76.3173,76.4821,77.3998,77.6234,76.5821,77.5093,76.4363,77.3783,76.3841,76.3391,76.568,76.6609,77.0855,76.0128,76.4087,76.9676,76.5047,76.5996,76.3344,77.461,77.5372,77.7898,77.5286,77.4263,77.7334,77.5369,77.4599,77.4814,77.6427,77.4423,77.4075,77.6499,77.9087,77.6434,76.9573,76.5582,77.264,77.4321,76.4257,77.5715,77.6529,76.6782,76.8775,76.735,76.8499,76.6936,77.0798,76.7105,76.2825,76.7091,76.6004,76.5302,77.4672,76.5027,76.2503,76.6262,76.7719,76.5382,76.9528,76.875,76.2135,77.5215,76.2913,76.3481,76.8676,76.737,76.5642,76.6986,76.9791,76.7887,77.0678,77.4739,76.2047,76.0558,76.3567,75.9331,76.3197,76.453,77.5549,75.9875,76.967,76.4438,77.2031,76.2789,76.7433,77.0143,76.6347,77.0799,77.1763,77.1536,75.5286,76.6083,76.7808,76.7999,76.9198,76.7103,76.9133,76.9084,77.0963,76.8091,76.5665,77.6289,77.2356,76.8983,76.6876,76.8349,76.3642,77.0145,76.2885,76.3502,76.8239,77.3763,76.4161,76.8159,75.8491,76.9891,76.8685,75.6709,76.9872,77.0977,77.2267,76.9429,76.8574,76.8673,77.197,76.9849,77.0659],"y":[3.7941,3.9689,3.8626,3.964,3.9496,3.7449,3.9984,4.08,3.9815,4.044,3.9748,3.9539,4.0212,4.179,4.0033,3.9901,3.8403,3.9986,3.9647,3.9946,3.8822,3.961,3.9114,3.8275,3.8667,4.0281,4.0584,3.9476,4.0036,3.9249,4.0179,4.0957,3.9289,4.0071,4.0285,4.0752,4.1308,3.9903,3.7816,3.9063,3.9216,4.1556,4.0962,3.8098,4.2071,3.9487,4.1318,3.9805,4.0036,4.0284,4.0429,3.9473,4.1366,4.1567,4.1128,3.8297,4.268,4.045,3.9067,4.0541,3.8115,4.0491,4.0855,4.1213,4.2385,4.1866,4.0907,4.1833,4.125,4.1413,4.1322,4.1229,4.1259,4.047,4.0169,4.1669,4.2492,4.105,4.0693,4.112,4.0925,4.4052,3.9551,4.1454,4.0794,3.9199,4.0163,3.8484,4.0531,4.0143,3.9756,3.895,3.7497,3.9554,3.8861,4.0983,3.8619,4.0244,4.072,3.7932,4.04,3.9267,4.0796,3.9636,3.9718,4.2846,4.0501,3.8682,4.0469,3.8246,3.8687,3.8565,4.0636,3.8545,3.9632,4.035,3.9914,3.9545,3.9735,3.9637,3.967,4.0435,4.1257,3.8884,3.7886,4.0173,4.0281,4.088,4.1048,4.0895,4.2122,4.0419,4.0427,4.0359,3.849,3.9214,3.8979,4.0611,3.9775,4.0541,3.9903,4.0076,3.9769,4.1435,3.8887,3.8286,3.9347,4.1057,3.9322,4.1344,4.1484,3.9833,4.1244,3.981,4.2941,4.1371,4.1551,3.9956,4.0059,4.122,4.0129,4.1523,4.1843,4.0056,4.3228,3.9578,4.1139,4.1358,4.133,4.0131,4.0469],"text":["SiO2: 77.0444<br />K2O: 3.7941<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9022<br />K2O: 3.9689<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5738<br />K2O: 3.8626<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.9228<br />K2O: 3.9640<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.8915<br />K2O: 3.9496<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4730<br />K2O: 3.7449<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.1159<br />K2O: 3.9984<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3197<br />K2O: 4.0800<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3854<br />K2O: 3.9815<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.2474<br />K2O: 4.0440<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.8524<br />K2O: 3.9748<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.1210<br />K2O: 3.9539<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0319<br />K2O: 4.0212<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4407<br />K2O: 4.1790<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5314<br />K2O: 4.0033<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.1896<br />K2O: 3.9901<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6545<br />K2O: 3.8403<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.1691<br />K2O: 3.9986<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7503<br />K2O: 3.9647<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8278<br />K2O: 3.9946<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7920<br />K2O: 3.8822<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9405<br />K2O: 3.9610<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8066<br />K2O: 3.9114<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5228<br />K2O: 3.8275<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9615<br />K2O: 3.8667<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6458<br />K2O: 4.0281<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3510<br />K2O: 4.0584<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.8413<br />K2O: 3.9476<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3680<br />K2O: 4.0036<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9336<br />K2O: 3.9249<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.2737<br />K2O: 4.0179<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6702<br />K2O: 4.0957<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.1129<br />K2O: 3.9289<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.8639<br />K2O: 4.0071<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7396<br />K2O: 4.0285<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3936<br />K2O: 4.0752<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3194<br />K2O: 4.1308<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3442<br />K2O: 3.9903<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5748<br />K2O: 3.7816<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4780<br />K2O: 3.9063<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.8100<br />K2O: 3.9216<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9535<br />K2O: 4.1556<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8945<br />K2O: 4.0962<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.2931<br />K2O: 3.8098<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3173<br />K2O: 4.2071<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4821<br />K2O: 3.9487<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.3998<br />K2O: 4.1318<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.6234<br />K2O: 3.9805<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5821<br />K2O: 4.0036<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.5093<br />K2O: 4.0284<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4363<br />K2O: 4.0429<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.3783<br />K2O: 3.9473<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3841<br />K2O: 4.1366<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3391<br />K2O: 4.1567<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5680<br />K2O: 4.1128<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6609<br />K2O: 3.8297<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0855<br />K2O: 4.2680<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.0128<br />K2O: 4.0450<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4087<br />K2O: 3.9067<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9676<br />K2O: 4.0541<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5047<br />K2O: 3.8115<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5996<br />K2O: 4.0491<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3344<br />K2O: 4.0855<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.4610<br />K2O: 4.1213<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.5372<br />K2O: 4.2385<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.7898<br />K2O: 4.1866<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.5286<br />K2O: 4.0907<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.4263<br />K2O: 4.1833<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.7334<br />K2O: 4.1250<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.5369<br />K2O: 4.1413<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.4599<br />K2O: 4.1322<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.4814<br />K2O: 4.1229<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.6427<br />K2O: 4.1259<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.4423<br />K2O: 4.0470<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.4075<br />K2O: 4.0169<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.6499<br />K2O: 4.1669<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.9087<br />K2O: 4.2492<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.6434<br />K2O: 4.1050<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9573<br />K2O: 4.0693<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5582<br />K2O: 4.1120<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.2640<br />K2O: 4.0925<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.4321<br />K2O: 4.4052<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4257<br />K2O: 3.9551<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.5715<br />K2O: 4.1454<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.6529<br />K2O: 4.0794<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6782<br />K2O: 3.9199<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8775<br />K2O: 4.0163<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7350<br />K2O: 3.8484<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8499<br />K2O: 4.0531<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6936<br />K2O: 4.0143<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0798<br />K2O: 3.9756<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7105<br />K2O: 3.8950<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.2825<br />K2O: 3.7497<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7091<br />K2O: 3.9554<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6004<br />K2O: 3.8861<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5302<br />K2O: 4.0983<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.4672<br />K2O: 3.8619<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5027<br />K2O: 4.0244<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.2503<br />K2O: 4.0720<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6262<br />K2O: 3.7932<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7719<br />K2O: 4.0400<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5382<br />K2O: 3.9267<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9528<br />K2O: 4.0796<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8750<br />K2O: 3.9636<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.2135<br />K2O: 3.9718<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.5215<br />K2O: 4.2846<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.2913<br />K2O: 4.0501<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3481<br />K2O: 3.8682<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8676<br />K2O: 4.0469<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7370<br />K2O: 3.8246<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5642<br />K2O: 3.8687<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6986<br />K2O: 3.8565<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9791<br />K2O: 4.0636<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7887<br />K2O: 3.8545<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0678<br />K2O: 3.9632<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.4739<br />K2O: 4.0350<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.2047<br />K2O: 3.9914<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.0558<br />K2O: 3.9545<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3567<br />K2O: 3.9735<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.9331<br />K2O: 3.9637<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3197<br />K2O: 3.9670<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4530<br />K2O: 4.0435<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.5549<br />K2O: 4.1257<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.9875<br />K2O: 3.8884<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9670<br />K2O: 3.7886<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4438<br />K2O: 4.0173<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.2031<br />K2O: 4.0281<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.2789<br />K2O: 4.0880<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7433<br />K2O: 4.1048<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0143<br />K2O: 4.0895<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6347<br />K2O: 4.2122<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0799<br />K2O: 4.0419<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.1763<br />K2O: 4.0427<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.1536<br />K2O: 4.0359<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.5286<br />K2O: 3.8490<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6083<br />K2O: 3.9214<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7808<br />K2O: 3.8979<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7999<br />K2O: 4.0611<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9198<br />K2O: 3.9775<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.7103<br />K2O: 4.0541<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9133<br />K2O: 3.9903<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9084<br />K2O: 4.0076<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0963<br />K2O: 3.9769<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8091<br />K2O: 4.1435<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.5665<br />K2O: 3.8887<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.6289<br />K2O: 3.8286<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.2356<br />K2O: 3.9347<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8983<br />K2O: 4.1057<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.6876<br />K2O: 3.9322<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8349<br />K2O: 4.1344<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3642<br />K2O: 4.1484<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0145<br />K2O: 3.9833<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.2885<br />K2O: 4.1244<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.3502<br />K2O: 3.9810<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8239<br />K2O: 4.2941<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.3763<br />K2O: 4.1371<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.4161<br />K2O: 4.1551<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8159<br />K2O: 3.9956<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.8491<br />K2O: 4.0059<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9891<br />K2O: 4.1220<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8685<br />K2O: 4.0129<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 75.6709<br />K2O: 4.1523<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9872<br />K2O: 4.1843<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0977<br />K2O: 4.0056<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.2267<br />K2O: 4.3228<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9429<br />K2O: 3.9578<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8574<br />K2O: 4.1139<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.8673<br />K2O: 4.1358<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.1970<br />K2O: 4.1330<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 76.9849<br />K2O: 4.0131<br />id: Penifiler Tephra<br />id: Penifiler Tephra","SiO2: 77.0659<br />K2O: 4.0469<br />id: Penifiler Tephra<br />id: Penifiler Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(11,48,117,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4,null,1.6,2.4],"text":"SiO2: 48<br />K2O: 1.6<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2,null,2.4,3.2],"text":"SiO2: 52<br />K2O: 2.4<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63],"y":[3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4,null,3.2,4],"text":"SiO2: 56<br />K2O: 3.2<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5,null,1.2,1.5],"text":"SiO2: 48<br />K2O: 1.2<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8,null,1.5,1.8],"text":"SiO2: 52<br />K2O: 1.5<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4,null,1.8,2.4],"text":"SiO2: 56<br />K2O: 1.8<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70],"y":[2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3,null,2.4,3],"text":"SiO2: 63<br />K2O: 2.4<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52,null,48,52],"y":[0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5,null,0.3,0.5],"text":"SiO2: 48<br />K2O: 0.3<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56,null,52,56],"y":[0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7,null,0.5,0.7],"text":"SiO2: 52<br />K2O: 0.5<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63],"y":[0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63,null,56,63],"y":[0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1,null,0.7,1],"text":"SiO2: 56<br />K2O: 0.7<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70],"y":[1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70,null,63,70],"y":[1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3,null,1,1.3],"text":"SiO2: 63<br />K2O: 1<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Borrobol Tephra<br />id: Borrobol Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Fosen Tephra<br />id: Fosen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80,null,70,80],"y":[1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6,null,1.3,1.6],"text":"SiO2: 70<br />K2O: 1.3<br />id: Penifiler Tephra<br />id: Penifiler Tephra","type":"scatter","mode":"lines","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)","dash":"solid"},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":false,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null}],"layout":{"margin":{"t":25.1324200913242,"r":7.30593607305936,"b":55.2926525529265,"l":42.8393524283935},"plot_bgcolor":"rgba(255,255,255,1)","paper_bgcolor":"rgba(255,255,255,1)","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187},"xaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":true,"range":[75.05246,78.83954],"tickmode":"auto","ticktext":["76","77","78"],"tickvals":[76,77,78],"categoryorder":"array","categoryarray":["76","77","78"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"y","title":{"text":"SiO2 (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"yaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":true,"range":[3.109575,6.038325],"tickmode":"auto","ticktext":["4","5","6"],"tickvals":[4,5,6],"categoryorder":"array","categoryarray":["4","5","6"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"x","title":{"text":"K2O (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"shapes":[{"type":"rect","fillcolor":"transparent","line":{"color":"rgba(51,51,51,1)","width":0.66417600664176,"linetype":"solid"},"yref":"paper","xref":"paper","x0":0,"x1":1,"y0":0,"y1":1}],"showlegend":true,"legend":{"bgcolor":"rgba(255,255,255,1)","bordercolor":"transparent","borderwidth":1.88976377952756,"font":{"color":"rgba(0,0,0,1)","family":"","size":11.689497716895},"title":{"text":"id","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187}}},"hovermode":"closest","width":1000,"height":800,"barmode":"relative"},"config":{"doubleClick":"reset","modeBarButtonsToAdd":["hoverclosest","hovercompare"],"showSendToCloud":false},"source":"A","attrs":{"7247ea151a":{"x":{},"y":{},"fill":{},"shape":{},"type":"scatter"},"72451be3e32":{"x":{},"y":{},"fill":{},"shape":{}},"724792e5c4f":{"x":{},"y":{},"fill":{},"shape":{}},"724175b850":{"x":{},"y":{},"fill":{},"shape":{}},"7244ba2bd7":{"x":{},"y":{},"fill":{},"shape":{}},"72435c06577":{"x":{},"y":{},"fill":{},"shape":{}},"7247d75f55":{"x":{},"y":{},"fill":{},"shape":{}},"72479b273ec":{"x":{},"y":{},"fill":{},"shape":{}},"7241e5169d1":{"x":{},"y":{},"fill":{},"shape":{}},"7243ed716a7":{"x":{},"y":{},"fill":{},"shape":{}},"72432595aa3":{"x":{},"y":{},"fill":{},"shape":{}},"7244bb23156":{"x":{},"y":{},"fill":{},"shape":{}},"72470447993":{"x":{},"y":{},"fill":{},"shape":{}}},"cur_data":"7247ea151a","visdat":{"7247ea151a":["function (y) ","x"],"72451be3e32":["function (y) ","x"],"724792e5c4f":["function (y) ","x"],"724175b850":["function (y) ","x"],"7244ba2bd7":["function (y) ","x"],"72435c06577":["function (y) ","x"],"7247d75f55":["function (y) ","x"],"72479b273ec":["function (y) ","x"],"7241e5169d1":["function (y) ","x"],"7243ed716a7":["function (y) ","x"],"72432595aa3":["function (y) ","x"],"7244bb23156":["function (y) ","x"],"72470447993":["function (y) ","x"]},"highlight":{"on":"plotly_click","persistent":false,"dynamic":false,"selectize":false,"opacityDim":0.2,"selected":{"opacity":1},"debounce":0},"shinyEvents":["plotly_hover","plotly_click","plotly_selected","plotly_relayout","plotly_brushed","plotly_brushing","plotly_clickannotation","plotly_doubleclick","plotly_deselect","plotly_afterplot","plotly_sunburstclick"],"base_url":"https://plot.ly"},"evals":[],"jsHooks":[]}</script>

## iTiO2 vs Al2O3

<div id="htmlwidget-88fdd2a34d502a66744b" style="width:1000px;height:800px;" class="plotly html-widget"></div>
<script type="application/json" data-for="htmlwidget-88fdd2a34d502a66744b">{"x":{"data":[{"x":[0.0601,0.0752],"y":[12.7428,13.3358],"text":["TiO2: 0.0601<br />Al2O3: 12.7428<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","TiO2: 0.0752<br />Al2O3: 13.3358<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(32,154,36,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1345,0.1078,0.1212,0.1273,0.1334,0.1181,0.0839,0.1315,0.117,0.1261,0.1132,0.1263],"y":[13.0647,12.4057,13.1087,13.0127,12.4436,13.3202,12.6475,12.4551,12.304,12.4128,12.6238,12.8101],"text":["TiO2: 0.1345<br />Al2O3: 13.0647<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1078<br />Al2O3: 12.4057<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1212<br />Al2O3: 13.1087<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1273<br />Al2O3: 13.0127<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1334<br />Al2O3: 12.4436<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1181<br />Al2O3: 13.3202<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.0839<br />Al2O3: 12.6475<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1315<br />Al2O3: 12.4551<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1170<br />Al2O3: 12.3040<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1261<br />Al2O3: 12.4128<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1132<br />Al2O3: 12.6238<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","TiO2: 0.1263<br />Al2O3: 12.8101<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(167,105,238,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1236,0.1211,0.0997,0.1379,0.1164,0.1257,0.1197,0.123],"y":[11.8927,13.0783,12.846,12.6605,11.6628,13.2782,12.9891,12.7065],"text":["TiO2: 0.1236<br />Al2O3: 11.8927<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TiO2: 0.1211<br />Al2O3: 13.0783<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TiO2: 0.0997<br />Al2O3: 12.8460<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TiO2: 0.1379<br />Al2O3: 12.6605<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TiO2: 0.1164<br />Al2O3: 11.6628<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TiO2: 0.1257<br />Al2O3: 13.2782<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TiO2: 0.1197<br />Al2O3: 12.9891<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","TiO2: 0.1230<br />Al2O3: 12.7065<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(180,196,40,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1483,0.1436,0.1475,0.1486,0.153,0.1544,0.157,0.1364,0.1654,0.1519,0.1443,0.1558,0.1468,0.1535,0.1476,0.1547,0.1507,0.1482,0.163,0.1449,0.1555,0.1365,0.1421,0.1646,0.1503,0.1856,0.1581,0.1533,0.1533,0.142,0.1592,0.1615,0.1816,0.1575,0.1719],"y":[12.2582,13.0313,13.3355,12.818,12.9582,12.8759,12.8598,12.9437,12.8374,13.1623,12.9517,12.9219,12.9486,13.0592,12.733,12.7444,13.068,13.0497,13.1956,12.7386,12.961,12.7962,12.9764,12.6757,12.8927,12.7101,12.817,13.2564,12.6869,12.9567,13.1533,12.833,12.7847,13.1719,12.8215],"text":["TiO2: 0.1483<br />Al2O3: 12.2582<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1436<br />Al2O3: 13.0313<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1475<br />Al2O3: 13.3355<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1486<br />Al2O3: 12.8180<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1530<br />Al2O3: 12.9582<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1544<br />Al2O3: 12.8759<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1570<br />Al2O3: 12.8598<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1364<br />Al2O3: 12.9437<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1654<br />Al2O3: 12.8374<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1519<br />Al2O3: 13.1623<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1443<br />Al2O3: 12.9517<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1558<br />Al2O3: 12.9219<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1468<br />Al2O3: 12.9486<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1535<br />Al2O3: 13.0592<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1476<br />Al2O3: 12.7330<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1547<br />Al2O3: 12.7444<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1507<br />Al2O3: 13.0680<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1482<br />Al2O3: 13.0497<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1630<br />Al2O3: 13.1956<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1449<br />Al2O3: 12.7386<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1555<br />Al2O3: 12.9610<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1365<br />Al2O3: 12.7962<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1421<br />Al2O3: 12.9764<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1646<br />Al2O3: 12.6757<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1503<br />Al2O3: 12.8927<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1856<br />Al2O3: 12.7101<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1581<br />Al2O3: 12.8170<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1533<br />Al2O3: 13.2564<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1533<br />Al2O3: 12.6869<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1420<br />Al2O3: 12.9567<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1592<br />Al2O3: 13.1533<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1615<br />Al2O3: 12.8330<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1816<br />Al2O3: 12.7847<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1575<br />Al2O3: 13.1719<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","TiO2: 0.1719<br />Al2O3: 12.8215<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(227,3,3,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1296,0.1243,0.1275,0.1375,0.1268,0.1336,0.1152,0.1191,0.1249,0.1468,0.1259,0.1207,0.1241,0.1229,0.126,0.1242,0.1309,0.1315,0.1177,0.1225,0.1296,0.1349,0.1238,0.1343,0.135,0.1308,0.1307,0.132,0.1229,0.1119,0.1186,0.1331,0.1447,0.1357,0.1247,0.1196,0.125,0.1258,0.1242,0.1291,0.1284,0.1217,0.1256,0.1242,0.1306,0.1262,0.1219,0.1156,0.1357,0.1246,0.1269,0.1248,0.1363,0.1355,0.126,0.1265,0.1271,0.1355,0.1258,0.1229,0.1152,0.1254,0.1251,0.1258,0.1256,0.126,0.1354,0.1363,0.1243,0.1258,0.1357,0.1365,0.1161,0.1355,0.1373,0.125,0.1362,0.1359,0.1258,0.1257,0.1358,0.1368,0.1356,0.1264,0.1358,0.1262,0.1348,0.1368,0.1363,0.1371,0.1259,0.1258,0.1267,0.1155,0.1316,0.124,0.1309,0.1288,0.1188,0.1298,0.1275,0.1352,0.1165,0.132,0.1341,0.1303,0.1274,0.1258,0.1251,0.1242,0.1289,0.159,0.1464,0.1354,0.156,0.1476,0.1547,0.1357,0.1457,0.1271,0.126,0.1247,0.1279,0.1385],"y":[12.5277,12.6593,12.7027,12.6572,12.6283,12.7628,12.6753,12.6755,12.6632,12.6077,12.4576,12.5642,12.9156,12.5976,12.7842,12.8181,12.8204,12.6388,12.3293,12.7576,12.7321,12.819,12.9039,12.9073,12.687,12.4541,12.4679,12.8885,12.4588,12.3977,12.2879,12.4774,12.4907,12.5615,12.5117,12.6539,12.6046,12.515,12.7542,12.3228,12.4991,12.5587,12.6327,12.5893,12.6796,12.7505,12.9161,12.9375,12.8914,13.3139,12.9823,13.0213,12.6834,12.8558,12.6916,12.8254,12.5543,12.8037,12.9874,12.9802,13.2761,12.8395,13.1096,12.6546,12.6793,12.7441,12.7318,12.4554,12.5142,12.8748,12.6592,12.7742,12.2783,12.6759,12.7918,12.3684,12.7541,12.8476,13.0138,12.9269,12.6593,12.8211,12.7087,12.9505,12.7297,12.9616,13.0133,12.5039,12.7936,12.7426,12.9418,12.8211,12.5343,12.5489,13.0045,12.4288,12.7221,12.9347,12.5886,12.6494,12.4284,12.6162,12.4427,12.5435,12.6525,12.9363,12.465,12.7876,12.6496,12.8443,12.7957,12.9624,13.0985,12.9298,13.0629,13.0586,13.022,12.9005,13.0163,12.9675,13.3186,13.0637,12.6009,12.886],"text":["TiO2: 0.1296<br />Al2O3: 12.5277<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1243<br />Al2O3: 12.6593<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1275<br />Al2O3: 12.7027<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1375<br />Al2O3: 12.6572<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1268<br />Al2O3: 12.6283<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1336<br />Al2O3: 12.7628<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1152<br />Al2O3: 12.6753<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1191<br />Al2O3: 12.6755<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1249<br />Al2O3: 12.6632<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1468<br />Al2O3: 12.6077<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1259<br />Al2O3: 12.4576<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1207<br />Al2O3: 12.5642<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1241<br />Al2O3: 12.9156<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1229<br />Al2O3: 12.5976<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1260<br />Al2O3: 12.7842<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1242<br />Al2O3: 12.8181<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1309<br />Al2O3: 12.8204<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1315<br />Al2O3: 12.6388<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1177<br />Al2O3: 12.3293<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1225<br />Al2O3: 12.7576<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1296<br />Al2O3: 12.7321<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1349<br />Al2O3: 12.8190<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1238<br />Al2O3: 12.9039<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1343<br />Al2O3: 12.9073<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1350<br />Al2O3: 12.6870<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1308<br />Al2O3: 12.4541<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1307<br />Al2O3: 12.4679<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1320<br />Al2O3: 12.8885<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1229<br />Al2O3: 12.4588<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1119<br />Al2O3: 12.3977<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1186<br />Al2O3: 12.2879<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1331<br />Al2O3: 12.4774<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1447<br />Al2O3: 12.4907<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1357<br />Al2O3: 12.5615<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1247<br />Al2O3: 12.5117<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1196<br />Al2O3: 12.6539<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1250<br />Al2O3: 12.6046<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1258<br />Al2O3: 12.5150<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1242<br />Al2O3: 12.7542<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1291<br />Al2O3: 12.3228<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1284<br />Al2O3: 12.4991<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1217<br />Al2O3: 12.5587<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1256<br />Al2O3: 12.6327<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1242<br />Al2O3: 12.5893<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1306<br />Al2O3: 12.6796<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1262<br />Al2O3: 12.7505<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1219<br />Al2O3: 12.9161<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1156<br />Al2O3: 12.9375<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1357<br />Al2O3: 12.8914<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1246<br />Al2O3: 13.3139<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1269<br />Al2O3: 12.9823<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1248<br />Al2O3: 13.0213<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1363<br />Al2O3: 12.6834<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1355<br />Al2O3: 12.8558<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1260<br />Al2O3: 12.6916<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1265<br />Al2O3: 12.8254<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1271<br />Al2O3: 12.5543<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1355<br />Al2O3: 12.8037<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1258<br />Al2O3: 12.9874<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1229<br />Al2O3: 12.9802<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1152<br />Al2O3: 13.2761<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1254<br />Al2O3: 12.8395<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1251<br />Al2O3: 13.1096<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1258<br />Al2O3: 12.6546<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1256<br />Al2O3: 12.6793<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1260<br />Al2O3: 12.7441<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1354<br />Al2O3: 12.7318<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1363<br />Al2O3: 12.4554<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1243<br />Al2O3: 12.5142<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1258<br />Al2O3: 12.8748<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1357<br />Al2O3: 12.6592<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1365<br />Al2O3: 12.7742<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1161<br />Al2O3: 12.2783<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1355<br />Al2O3: 12.6759<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1373<br />Al2O3: 12.7918<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1250<br />Al2O3: 12.3684<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1362<br />Al2O3: 12.7541<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1359<br />Al2O3: 12.8476<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1258<br />Al2O3: 13.0138<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1257<br />Al2O3: 12.9269<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1358<br />Al2O3: 12.6593<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1368<br />Al2O3: 12.8211<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1356<br />Al2O3: 12.7087<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1264<br />Al2O3: 12.9505<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1358<br />Al2O3: 12.7297<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1262<br />Al2O3: 12.9616<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1348<br />Al2O3: 13.0133<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1368<br />Al2O3: 12.5039<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1363<br />Al2O3: 12.7936<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1371<br />Al2O3: 12.7426<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1259<br />Al2O3: 12.9418<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1258<br />Al2O3: 12.8211<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1267<br />Al2O3: 12.5343<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1155<br />Al2O3: 12.5489<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1316<br />Al2O3: 13.0045<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1240<br />Al2O3: 12.4288<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1309<br />Al2O3: 12.7221<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1288<br />Al2O3: 12.9347<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1188<br />Al2O3: 12.5886<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1298<br />Al2O3: 12.6494<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1275<br />Al2O3: 12.4284<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1352<br />Al2O3: 12.6162<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1165<br />Al2O3: 12.4427<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1320<br />Al2O3: 12.5435<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1341<br />Al2O3: 12.6525<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1303<br />Al2O3: 12.9363<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1274<br />Al2O3: 12.4650<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1258<br />Al2O3: 12.7876<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1251<br />Al2O3: 12.6496<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1242<br />Al2O3: 12.8443<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1289<br />Al2O3: 12.7957<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1590<br />Al2O3: 12.9624<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1464<br />Al2O3: 13.0985<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1354<br />Al2O3: 12.9298<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1560<br />Al2O3: 13.0629<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1476<br />Al2O3: 13.0586<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1547<br />Al2O3: 13.0220<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1357<br />Al2O3: 12.9005<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1457<br />Al2O3: 13.0163<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1271<br />Al2O3: 12.9675<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1260<br />Al2O3: 13.3186<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1247<br />Al2O3: 13.0637<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1279<br />Al2O3: 12.6009<br />id: Borrobol Tephra<br />id: Borrobol Tephra","TiO2: 0.1385<br />Al2O3: 12.8860<br />id: Borrobol Tephra<br />id: Borrobol Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(0,0,0,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1241,0.1249,0.1469,0.1254,0.1364,0.135,0.1254,0.1142,0.1273,0.1335,0.1362,0.1362,0.1362],"y":[12.7378,12.6483,12.4449,12.8722,12.4239,13.1942,12.6097,12.5337,12.7506,13.0404,12.9674,12.7998,12.8654],"text":["TiO2: 0.1241<br />Al2O3: 12.7378<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1249<br />Al2O3: 12.6483<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1469<br />Al2O3: 12.4449<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1254<br />Al2O3: 12.8722<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1364<br />Al2O3: 12.4239<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1350<br />Al2O3: 13.1942<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1254<br />Al2O3: 12.6097<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1142<br />Al2O3: 12.5337<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1273<br />Al2O3: 12.7506<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1335<br />Al2O3: 13.0404<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1362<br />Al2O3: 12.9674<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1362<br />Al2O3: 12.7998<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","TiO2: 0.1362<br />Al2O3: 12.8654<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(239,19,157,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1193,0.1717,0.1631,0.144,0.1302,0.0993,0.1104,0.1038,0.109,0.0957,0.1062,0.1143,0.1216,0.1086,0.1074,0.101,0.1127,0.1131,0.114,0.1195,0.1076],"y":[13.4461,13.3989,13.2759,13.3395,13.4053,13.6301,12.4189,13.2923,12.9484,12.6725,12.5904,12.7995,12.2279,12.8624,13.182,12.945,13.4956,12.3608,12.8199,12.0351,12.1744],"text":["TiO2: 0.1193<br />Al2O3: 13.4461<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1717<br />Al2O3: 13.3989<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1631<br />Al2O3: 13.2759<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1440<br />Al2O3: 13.3395<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1302<br />Al2O3: 13.4053<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.0993<br />Al2O3: 13.6301<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1104<br />Al2O3: 12.4189<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1038<br />Al2O3: 13.2923<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1090<br />Al2O3: 12.9484<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.0957<br />Al2O3: 12.6725<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1062<br />Al2O3: 12.5904<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1143<br />Al2O3: 12.7995<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1216<br />Al2O3: 12.2279<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1086<br />Al2O3: 12.8624<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1074<br />Al2O3: 13.1820<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1010<br />Al2O3: 12.9450<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1127<br />Al2O3: 13.4956<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1131<br />Al2O3: 12.3608<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1140<br />Al2O3: 12.8199<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1195<br />Al2O3: 12.0351<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","TiO2: 0.1076<br />Al2O3: 12.1744<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(58,112,15,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1429,0.1266,0.1318,0.1307,0.1308,0.1312,0.1324,0.1338,0.1278,0.1283,0.1275,0.1245,0.124,0.124,0.1279,0.1054,0.1212,0.1287,0.1237,0.1233,0.1215,0.1272,0.1119,0.1286,0.1242,0.1302,0.1287,0.1196],"y":[12.9193,12.5429,12.606,12.8865,12.6858,12.4479,12.7015,12.5097,12.8205,12.6848,12.7014,12.5735,12.4339,12.6291,12.5232,12.3454,12.4681,12.7942,12.7301,12.329,12.6043,12.2269,12.0796,12.7896,12.8678,12.7098,12.462,12.333],"text":["TiO2: 0.1429<br />Al2O3: 12.9193<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1266<br />Al2O3: 12.5429<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1318<br />Al2O3: 12.6060<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1307<br />Al2O3: 12.8865<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1308<br />Al2O3: 12.6858<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1312<br />Al2O3: 12.4479<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1324<br />Al2O3: 12.7015<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1338<br />Al2O3: 12.5097<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1278<br />Al2O3: 12.8205<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1283<br />Al2O3: 12.6848<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1275<br />Al2O3: 12.7014<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1245<br />Al2O3: 12.5735<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1240<br />Al2O3: 12.4339<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1240<br />Al2O3: 12.6291<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1279<br />Al2O3: 12.5232<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1054<br />Al2O3: 12.3454<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1212<br />Al2O3: 12.4681<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1287<br />Al2O3: 12.7942<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1237<br />Al2O3: 12.7301<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1233<br />Al2O3: 12.3290<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1215<br />Al2O3: 12.6043<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1272<br />Al2O3: 12.2269<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1119<br />Al2O3: 12.0796<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1286<br />Al2O3: 12.7896<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1242<br />Al2O3: 12.8678<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1302<br />Al2O3: 12.7098<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1287<br />Al2O3: 12.4620<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","TiO2: 0.1196<br />Al2O3: 12.3330<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(82,136,255,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1179,0.1221,0.1163,0.1266,0.1292,0.1103,0.1319,0.1114,0.1197,0.0942],"y":[12.6016,12.348,12.5065,12.3714,12.467,12.5101,12.5093,12.1618,12.4787,11.1465],"text":["TiO2: 0.1179<br />Al2O3: 12.6016<br />id: Fosen Tephra<br />id: Fosen Tephra","TiO2: 0.1221<br />Al2O3: 12.3480<br />id: Fosen Tephra<br />id: Fosen Tephra","TiO2: 0.1163<br />Al2O3: 12.5065<br />id: Fosen Tephra<br />id: Fosen Tephra","TiO2: 0.1266<br />Al2O3: 12.3714<br />id: Fosen Tephra<br />id: Fosen Tephra","TiO2: 0.1292<br />Al2O3: 12.4670<br />id: Fosen Tephra<br />id: Fosen Tephra","TiO2: 0.1103<br />Al2O3: 12.5101<br />id: Fosen Tephra<br />id: Fosen Tephra","TiO2: 0.1319<br />Al2O3: 12.5093<br />id: Fosen Tephra<br />id: Fosen Tephra","TiO2: 0.1114<br />Al2O3: 12.1618<br />id: Fosen Tephra<br />id: Fosen Tephra","TiO2: 0.1197<br />Al2O3: 12.4787<br />id: Fosen Tephra<br />id: Fosen Tephra","TiO2: 0.0942<br />Al2O3: 11.1465<br />id: Fosen Tephra<br />id: Fosen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(230,71,1,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.0865,0.0941,0.0966,0.0639,0.0797,0.0825,0.0839,0.0818,0.084,0.0875,0.0816,0.0852,0.0833,0.0884,0.0889,0.0937,0.0768,0.0733,0.0801,0.0827,0.0936,0.0838,0.1257,0.0834,0.0946,0.0954,0.0937,0.0528,0.1054,0.0632,0.0836,0.073,0.1147,0.1358,0.0946,0.0525,0.1053,0.0841,0.0943,0.0943,0.1063,0.094,0.1051,0.0949,0.1041,0.0943,0.0719,0.0945,0.105,0.1037,0.0943,0.0823,0.0832,0.0847,0.0826,0.0944,0.0949,0.0935,0.0939,0.0744,0.0938,0.0938,0.0938,0.094,0.0839,0.0944,0.0952,0.1064,0.095,0.0841,0.0839,0.084,0.0935,0.0938,0.0949,0.0957,0.0726,0.0942,0.0953,0.0528,0.0624,0.1361,0.0105,0.0843,0.1264,0.1057,0.1459,0.1271,0.0743,0.1177,0.1265,0.1174,0.1131,0.0729,0.0849,0.1164,0.1016,0.0961,0.0968,0.0985,0.0945,0.0972,0.0732,0.0974],"y":[12.4017,11.8695,11.9142,11.8892,11.8405,12.0995,12.1704,11.7369,12.253,11.9279,12.3428,11.9505,12.0546,11.912,12.4446,11.6563,13.2523,12.851,11.9931,12.0554,12.292,11.777,11.9803,12.367,12.2713,12.0229,12.1748,12.4604,12.6449,12.118,12.3302,12.3045,12.7216,12.4347,12.5131,12.8151,12.9474,12.3489,12.4581,11.8898,12.3658,12.2114,12.261,12.1902,11.6998,12.3599,12.3897,12.3963,12.2612,12.1344,12.2381,12.572,12.1231,11.8319,11.8777,12.1238,12.1244,12.005,11.9403,12.0948,11.8045,11.9137,12.2292,12.2377,12.4239,12.4344,12.1866,12.8085,12.1609,12.0429,11.7814,11.9408,11.8075,11.9671,11.7368,11.8022,12.1319,12.0184,12.0737,11.8965,12.0154,11.9476,11.9332,11.9153,11.8997,11.8436,11.9608,12.2762,11.7597,11.9467,11.5054,11.7597,12.1153,11.9832,12.0538,12.2298,12.7394,12.4583,12.016,12.6042,12.4021,12.6345,11.5127,12.3064],"text":["TiO2: 0.0865<br />Al2O3: 12.4017<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0941<br />Al2O3: 11.8695<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0966<br />Al2O3: 11.9142<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0639<br />Al2O3: 11.8892<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0797<br />Al2O3: 11.8405<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0825<br />Al2O3: 12.0995<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0839<br />Al2O3: 12.1704<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0818<br />Al2O3: 11.7369<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0840<br />Al2O3: 12.2530<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0875<br />Al2O3: 11.9279<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0816<br />Al2O3: 12.3428<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0852<br />Al2O3: 11.9505<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0833<br />Al2O3: 12.0546<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0884<br />Al2O3: 11.9120<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0889<br />Al2O3: 12.4446<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0937<br />Al2O3: 11.6563<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0768<br />Al2O3: 13.2523<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0733<br />Al2O3: 12.8510<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0801<br />Al2O3: 11.9931<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0827<br />Al2O3: 12.0554<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0936<br />Al2O3: 12.2920<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0838<br />Al2O3: 11.7770<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1257<br />Al2O3: 11.9803<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0834<br />Al2O3: 12.3670<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0946<br />Al2O3: 12.2713<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0954<br />Al2O3: 12.0229<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0937<br />Al2O3: 12.1748<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0528<br />Al2O3: 12.4604<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1054<br />Al2O3: 12.6449<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0632<br />Al2O3: 12.1180<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0836<br />Al2O3: 12.3302<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0730<br />Al2O3: 12.3045<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1147<br />Al2O3: 12.7216<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1358<br />Al2O3: 12.4347<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0946<br />Al2O3: 12.5131<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0525<br />Al2O3: 12.8151<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1053<br />Al2O3: 12.9474<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0841<br />Al2O3: 12.3489<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0943<br />Al2O3: 12.4581<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0943<br />Al2O3: 11.8898<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1063<br />Al2O3: 12.3658<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0940<br />Al2O3: 12.2114<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1051<br />Al2O3: 12.2610<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0949<br />Al2O3: 12.1902<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1041<br />Al2O3: 11.6998<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0943<br />Al2O3: 12.3599<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0719<br />Al2O3: 12.3897<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0945<br />Al2O3: 12.3963<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1050<br />Al2O3: 12.2612<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1037<br />Al2O3: 12.1344<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0943<br />Al2O3: 12.2381<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0823<br />Al2O3: 12.5720<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0832<br />Al2O3: 12.1231<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0847<br />Al2O3: 11.8319<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0826<br />Al2O3: 11.8777<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0944<br />Al2O3: 12.1238<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0949<br />Al2O3: 12.1244<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0935<br />Al2O3: 12.0050<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0939<br />Al2O3: 11.9403<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0744<br />Al2O3: 12.0948<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0938<br />Al2O3: 11.8045<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0938<br />Al2O3: 11.9137<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0938<br />Al2O3: 12.2292<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0940<br />Al2O3: 12.2377<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0839<br />Al2O3: 12.4239<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0944<br />Al2O3: 12.4344<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0952<br />Al2O3: 12.1866<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1064<br />Al2O3: 12.8085<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0950<br />Al2O3: 12.1609<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0841<br />Al2O3: 12.0429<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0839<br />Al2O3: 11.7814<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0840<br />Al2O3: 11.9408<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0935<br />Al2O3: 11.8075<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0938<br />Al2O3: 11.9671<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0949<br />Al2O3: 11.7368<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0957<br />Al2O3: 11.8022<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0726<br />Al2O3: 12.1319<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0942<br />Al2O3: 12.0184<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0953<br />Al2O3: 12.0737<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0528<br />Al2O3: 11.8965<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0624<br />Al2O3: 12.0154<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1361<br />Al2O3: 11.9476<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0105<br />Al2O3: 11.9332<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0843<br />Al2O3: 11.9153<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1264<br />Al2O3: 11.8997<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1057<br />Al2O3: 11.8436<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1459<br />Al2O3: 11.9608<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1271<br />Al2O3: 12.2762<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0743<br />Al2O3: 11.7597<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1177<br />Al2O3: 11.9467<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1265<br />Al2O3: 11.5054<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1174<br />Al2O3: 11.7597<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1131<br />Al2O3: 12.1153<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0729<br />Al2O3: 11.9832<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0849<br />Al2O3: 12.0538<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1164<br />Al2O3: 12.2298<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.1016<br />Al2O3: 12.7394<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0961<br />Al2O3: 12.4583<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0968<br />Al2O3: 12.0160<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0985<br />Al2O3: 12.6042<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0945<br />Al2O3: 12.4021<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0972<br />Al2O3: 12.6345<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0732<br />Al2O3: 11.5127<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","TiO2: 0.0974<br />Al2O3: 12.3064<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(127,154,245,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1072,0.0918,0.0979,0.0981,0.1245,0.1047,0.1364,0.1477,0.1367,0.1056,0.0949,0.1168,0.1166,0.1271,0.1161,0.1379,0.1055,0.1164,0.0952,0.1382,0.1377,0.1169,0.1169],"y":[12.5045,12.1245,12.4468,12.4889,12.2407,12.1923,12.2954,12.1439,12.291,12.1065,12.1519,12.3088,12.153,12.3106,12.3601,12.1871,12.1388,12.3214,12.3149,12.4548,12.2326,12.2874,12.2649],"text":["TiO2: 0.1072<br />Al2O3: 12.5045<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.0918<br />Al2O3: 12.1245<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.0979<br />Al2O3: 12.4468<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.0981<br />Al2O3: 12.4889<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1245<br />Al2O3: 12.2407<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1047<br />Al2O3: 12.1923<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1364<br />Al2O3: 12.2954<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1477<br />Al2O3: 12.1439<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1367<br />Al2O3: 12.2910<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1056<br />Al2O3: 12.1065<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.0949<br />Al2O3: 12.1519<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1168<br />Al2O3: 12.3088<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1166<br />Al2O3: 12.1530<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1271<br />Al2O3: 12.3106<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1161<br />Al2O3: 12.3601<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1379<br />Al2O3: 12.1871<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1055<br />Al2O3: 12.1388<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1164<br />Al2O3: 12.3214<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.0952<br />Al2O3: 12.3149<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1382<br />Al2O3: 12.4548<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1377<br />Al2O3: 12.2326<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1169<br />Al2O3: 12.2874<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","TiO2: 0.1169<br />Al2O3: 12.2649<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(243,109,32,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.1201,0.1199,0.1239,0.149,0.129,0.1269,0.1258,0.1164,0.1324,0.131,0.1048,0.1317,0.1186,0.1249,0.1341,0.1268,0.1366,0.1264,0.1225,0.1343,0.1265,0.1232,0.1226,0.1209,0.127,0.1318,0.1307,0.1224,0.1233,0.1049,0.0934,0.117,0.1254,0.1353,0.136,0.1372,0.1274,0.1376,0.1243,0.1372,0.1258,0.1134,0.1082,0.1057,0.1323,0.0907,0.1052,0.108,0.1044,0.1111,0.1137,0.0988,0.1227,0.108,0.1064,0.1115,0.0971,0.1192,0.1232,0.1142,0.1225,0.1162,0.1225,0.1489,0.1142,0.1414,0.1088,0.0846,0.0772,0.1106,0.096,0.1032,0.123,0.1011,0.1032,0.0979,0.1239,0.1301,0.1422,0.113,0.1047,0.1212,0.1292,0.1054,0.1281,0.1614,0.0678,0.0727,0.0821,0.1246,0,0.0994,0.1142,0.1004,0.1319,0.1227,0.1037,0.0921,0.1383,0.1895,0.1203,0.1765,0.1129,0.1696,0.1122,0.1364,0.0833,0.1891,0.2055,0.1279,0.0846,0.0956,0.0782,0.1552,0.0972,0.0995,0.0942,0.105,0.0891,0.1045,0.0998,0.1027,0.1122,0.1014,0.1052,0.1094,0.1049,0.0927,0.1085,0.0971,0.108,0.0971,0.1068,0.1072,0.1637,0.1067,0.1261,0.1484,0.1273,0.1372,0.1372,0.1484,0.1157,0.0991,0.1027,0.1032,0.1066,0.1094,0.1039,0.1156,0.1075,0.0918,0.1043,0.1013,0.111,0.1142,0.0944,0.1069,0.1148,0.0995,0.1034,0.1621,0.1033,0.1074,0.0978,0.1028,0.1047,0.0968,0.1006,0.092,0.1102],"y":[12.8076,12.5347,12.6873,12.5941,12.8602,12.8152,12.7042,12.569,12.3044,12.682,12.0692,12.6688,12.5025,12.53,12.308,12.7042,12.7374,12.6349,12.1721,12.406,12.5512,12.5238,12.5279,12.98,12.4118,12.6186,12.8428,13.3216,12.7986,12.4252,12.635,12.8936,12.9154,13.0933,12.5353,12.6795,12.7641,12.6058,12.5466,12.7111,13.0754,12.5341,12.5342,12.4415,12.7122,12.8806,12.0492,12.5252,12.5754,12.0522,12.7693,12.2279,12.5895,12.5925,12.6098,12.6965,12.55,12.9116,12.7105,12.31,12.6663,12.713,12.6424,12.971,13.0278,12.9957,12.9636,13.1079,13.0137,13.0522,13.1207,13.0945,12.9481,12.9573,12.903,13.0392,12.7747,13.2963,13.0039,12.5423,13.1194,12.9556,12.9834,13.0116,13.0439,12.9135,12.7497,13.1091,13.1141,12.8687,13.1667,12.7844,13.0341,13.056,13.1269,13.2606,12.7488,12.9794,13.1088,12.9619,12.9463,12.9253,12.7891,12.7408,13.0962,12.5786,13.0469,13.0618,12.9537,12.9479,13.2441,13.1428,12.918,13.0813,12.3942,11.9161,13.1129,12.8354,13.4898,13.1412,13.0476,12.5441,11.8846,13.6988,12.5487,12.7334,12.821,13.168,12.7858,12.7427,12.8285,12.7423,11.9849,11.8878,12.7713,12.933,13.0385,13.0103,13.0781,12.9856,13.0265,12.9665,13.0773,12.6223,12.9416,12.1407,12.3017,12.791,12.5256,12.4338,12.7116,12.6922,12.8714,13.0156,12.4546,12.7572,12.9288,12.5062,12.8351,12.7372,13.0107,13.418,12.6998,12.5481,12.4769,12.662,13.0034,12.6126,12.222,12.8715,12.5986],"text":["TiO2: 0.1201<br />Al2O3: 12.8076<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1199<br />Al2O3: 12.5347<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1239<br />Al2O3: 12.6873<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1490<br />Al2O3: 12.5941<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1290<br />Al2O3: 12.8602<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1269<br />Al2O3: 12.8152<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1258<br />Al2O3: 12.7042<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1164<br />Al2O3: 12.5690<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1324<br />Al2O3: 12.3044<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1310<br />Al2O3: 12.6820<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1048<br />Al2O3: 12.0692<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1317<br />Al2O3: 12.6688<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1186<br />Al2O3: 12.5025<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1249<br />Al2O3: 12.5300<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1341<br />Al2O3: 12.3080<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1268<br />Al2O3: 12.7042<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1366<br />Al2O3: 12.7374<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1264<br />Al2O3: 12.6349<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1225<br />Al2O3: 12.1721<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1343<br />Al2O3: 12.4060<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1265<br />Al2O3: 12.5512<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1232<br />Al2O3: 12.5238<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1226<br />Al2O3: 12.5279<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1209<br />Al2O3: 12.9800<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1270<br />Al2O3: 12.4118<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1318<br />Al2O3: 12.6186<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1307<br />Al2O3: 12.8428<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1224<br />Al2O3: 13.3216<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1233<br />Al2O3: 12.7986<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1049<br />Al2O3: 12.4252<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0934<br />Al2O3: 12.6350<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1170<br />Al2O3: 12.8936<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1254<br />Al2O3: 12.9154<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1353<br />Al2O3: 13.0933<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1360<br />Al2O3: 12.5353<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1372<br />Al2O3: 12.6795<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1274<br />Al2O3: 12.7641<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1376<br />Al2O3: 12.6058<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1243<br />Al2O3: 12.5466<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1372<br />Al2O3: 12.7111<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1258<br />Al2O3: 13.0754<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1134<br />Al2O3: 12.5341<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1082<br />Al2O3: 12.5342<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1057<br />Al2O3: 12.4415<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1323<br />Al2O3: 12.7122<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0907<br />Al2O3: 12.8806<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1052<br />Al2O3: 12.0492<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1080<br />Al2O3: 12.5252<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1044<br />Al2O3: 12.5754<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1111<br />Al2O3: 12.0522<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1137<br />Al2O3: 12.7693<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0988<br />Al2O3: 12.2279<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1227<br />Al2O3: 12.5895<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1080<br />Al2O3: 12.5925<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1064<br />Al2O3: 12.6098<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1115<br />Al2O3: 12.6965<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0971<br />Al2O3: 12.5500<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1192<br />Al2O3: 12.9116<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1232<br />Al2O3: 12.7105<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1142<br />Al2O3: 12.3100<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1225<br />Al2O3: 12.6663<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1162<br />Al2O3: 12.7130<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1225<br />Al2O3: 12.6424<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1489<br />Al2O3: 12.9710<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1142<br />Al2O3: 13.0278<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1414<br />Al2O3: 12.9957<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1088<br />Al2O3: 12.9636<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0846<br />Al2O3: 13.1079<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0772<br />Al2O3: 13.0137<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1106<br />Al2O3: 13.0522<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0960<br />Al2O3: 13.1207<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1032<br />Al2O3: 13.0945<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1230<br />Al2O3: 12.9481<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1011<br />Al2O3: 12.9573<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1032<br />Al2O3: 12.9030<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0979<br />Al2O3: 13.0392<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1239<br />Al2O3: 12.7747<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1301<br />Al2O3: 13.2963<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1422<br />Al2O3: 13.0039<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1130<br />Al2O3: 12.5423<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1047<br />Al2O3: 13.1194<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1212<br />Al2O3: 12.9556<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1292<br />Al2O3: 12.9834<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1054<br />Al2O3: 13.0116<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1281<br />Al2O3: 13.0439<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1614<br />Al2O3: 12.9135<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0678<br />Al2O3: 12.7497<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0727<br />Al2O3: 13.1091<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0821<br />Al2O3: 13.1141<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1246<br />Al2O3: 12.8687<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0000<br />Al2O3: 13.1667<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0994<br />Al2O3: 12.7844<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1142<br />Al2O3: 13.0341<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1004<br />Al2O3: 13.0560<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1319<br />Al2O3: 13.1269<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1227<br />Al2O3: 13.2606<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1037<br />Al2O3: 12.7488<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0921<br />Al2O3: 12.9794<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1383<br />Al2O3: 13.1088<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1895<br />Al2O3: 12.9619<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1203<br />Al2O3: 12.9463<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1765<br />Al2O3: 12.9253<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1129<br />Al2O3: 12.7891<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1696<br />Al2O3: 12.7408<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1122<br />Al2O3: 13.0962<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1364<br />Al2O3: 12.5786<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0833<br />Al2O3: 13.0469<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1891<br />Al2O3: 13.0618<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.2055<br />Al2O3: 12.9537<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1279<br />Al2O3: 12.9479<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0846<br />Al2O3: 13.2441<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0956<br />Al2O3: 13.1428<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0782<br />Al2O3: 12.9180<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1552<br />Al2O3: 13.0813<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0972<br />Al2O3: 12.3942<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0995<br />Al2O3: 11.9161<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0942<br />Al2O3: 13.1129<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1050<br />Al2O3: 12.8354<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0891<br />Al2O3: 13.4898<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1045<br />Al2O3: 13.1412<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0998<br />Al2O3: 13.0476<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1027<br />Al2O3: 12.5441<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1122<br />Al2O3: 11.8846<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1014<br />Al2O3: 13.6988<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1052<br />Al2O3: 12.5487<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1094<br />Al2O3: 12.7334<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1049<br />Al2O3: 12.8210<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0927<br />Al2O3: 13.1680<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1085<br />Al2O3: 12.7858<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0971<br />Al2O3: 12.7427<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1080<br />Al2O3: 12.8285<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0971<br />Al2O3: 12.7423<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1068<br />Al2O3: 11.9849<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1072<br />Al2O3: 11.8878<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1637<br />Al2O3: 12.7713<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1067<br />Al2O3: 12.9330<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1261<br />Al2O3: 13.0385<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1484<br />Al2O3: 13.0103<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1273<br />Al2O3: 13.0781<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1372<br />Al2O3: 12.9856<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1372<br />Al2O3: 13.0265<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1484<br />Al2O3: 12.9665<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1157<br />Al2O3: 13.0773<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0991<br />Al2O3: 12.6223<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1027<br />Al2O3: 12.9416<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1032<br />Al2O3: 12.1407<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1066<br />Al2O3: 12.3017<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1094<br />Al2O3: 12.7910<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1039<br />Al2O3: 12.5256<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1156<br />Al2O3: 12.4338<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1075<br />Al2O3: 12.7116<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0918<br />Al2O3: 12.6922<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1043<br />Al2O3: 12.8714<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1013<br />Al2O3: 13.0156<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1110<br />Al2O3: 12.4546<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1142<br />Al2O3: 12.7572<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0944<br />Al2O3: 12.9288<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1069<br />Al2O3: 12.5062<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1148<br />Al2O3: 12.8351<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0995<br />Al2O3: 12.7372<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1034<br />Al2O3: 13.0107<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1621<br />Al2O3: 13.4180<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1033<br />Al2O3: 12.6998<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1074<br />Al2O3: 12.5481<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0978<br />Al2O3: 12.4769<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1028<br />Al2O3: 12.6620<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1047<br />Al2O3: 13.0034<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0968<br />Al2O3: 12.6126<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1006<br />Al2O3: 12.2220<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.0920<br />Al2O3: 12.8715<br />id: Penifiler Tephra<br />id: Penifiler Tephra","TiO2: 0.1102<br />Al2O3: 12.5986<br />id: Penifiler Tephra<br />id: Penifiler Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(11,48,117,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null}],"layout":{"margin":{"t":25.1324200913242,"r":7.30593607305936,"b":55.2926525529265,"l":53.4661685346617},"plot_bgcolor":"rgba(255,255,255,1)","paper_bgcolor":"rgba(255,255,255,1)","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187},"xaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":true,"range":[-0.010275,0.215775],"tickmode":"auto","ticktext":["0.00","0.05","0.10","0.15","0.20"],"tickvals":[0,0.05,0.1,0.15,0.2],"categoryorder":"array","categoryarray":["0.00","0.05","0.10","0.15","0.20"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"y","title":{"text":"TiO2 (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"yaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":true,"range":[11.018885,13.826415],"tickmode":"auto","ticktext":["12","13"],"tickvals":[12,13],"categoryorder":"array","categoryarray":["12","13"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"x","title":{"text":"Al2O3 (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"shapes":[{"type":"rect","fillcolor":"transparent","line":{"color":"rgba(51,51,51,1)","width":0.66417600664176,"linetype":"solid"},"yref":"paper","xref":"paper","x0":0,"x1":1,"y0":0,"y1":1}],"showlegend":true,"legend":{"bgcolor":"rgba(255,255,255,1)","bordercolor":"transparent","borderwidth":1.88976377952756,"font":{"color":"rgba(0,0,0,1)","family":"","size":11.689497716895},"title":{"text":"id","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187}}},"hovermode":"closest","width":1000,"height":800,"barmode":"relative"},"config":{"doubleClick":"reset","modeBarButtonsToAdd":["hoverclosest","hovercompare"],"showSendToCloud":false},"source":"A","attrs":{"724c3636bc":{"x":{},"y":{},"fill":{},"shape":{},"type":"scatter"}},"cur_data":"724c3636bc","visdat":{"724c3636bc":["function (y) ","x"]},"highlight":{"on":"plotly_click","persistent":false,"dynamic":false,"selectize":false,"opacityDim":0.2,"selected":{"opacity":1},"debounce":0},"shinyEvents":["plotly_hover","plotly_click","plotly_selected","plotly_relayout","plotly_brushed","plotly_brushing","plotly_clickannotation","plotly_doubleclick","plotly_deselect","plotly_afterplot","plotly_sunburstclick"],"base_url":"https://plot.ly"},"evals":[],"jsHooks":[]}</script>

## iK2O vs CaO

<div id="htmlwidget-8e1fe96c0688a849169a" style="width:1000px;height:800px;" class="plotly html-widget"></div>
<script type="application/json" data-for="htmlwidget-8e1fe96c0688a849169a">{"x":{"data":[{"x":[0.5637,0.8226],"y":[4.9147,4.6207],"text":["CaO: 0.5637<br />K2O: 4.9147<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a","CaO: 0.8226<br />K2O: 4.6207<br />id: Borrobol-type Tephra GI-1a<br />id: Borrobol-type Tephra GI-1a"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(32,154,36,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1a","legendgroup":"Borrobol-type Tephra GI-1a","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.7969,0.771,0.7725,0.9214,0.7891,0.7422,0.8209,0.8847,0.8635,0.697,0.8822,0.7739],"y":[3.8645,3.926,3.9026,3.9396,3.7375,4.0257,4.0407,3.958,3.8017,3.9353,4.1265,3.8413],"text":["CaO: 0.7969<br />K2O: 3.8645<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.7710<br />K2O: 3.9260<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.7725<br />K2O: 3.9026<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.9214<br />K2O: 3.9396<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.7891<br />K2O: 3.7375<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.7422<br />K2O: 4.0257<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.8209<br />K2O: 4.0407<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.8847<br />K2O: 3.9580<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.8635<br />K2O: 3.8017<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.6970<br />K2O: 3.9353<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.8822<br />K2O: 4.1265<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1","CaO: 0.7739<br />K2O: 3.8413<br />id: Borrobol-type Tephra GI-1e_pt1<br />id: Borrobol-type Tephra GI-1e_pt1"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(167,105,238,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt1","legendgroup":"Borrobol-type Tephra GI-1e_pt1","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.8509,0.8654,0.8606,0.7576,0.8209,0.8403,0.8383,0.879],"y":[3.9084,4.0527,4.0832,3.9885,3.969,4.0446,3.9939,3.8609],"text":["CaO: 0.8509<br />K2O: 3.9084<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","CaO: 0.8654<br />K2O: 4.0527<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","CaO: 0.8606<br />K2O: 4.0832<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","CaO: 0.7576<br />K2O: 3.9885<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","CaO: 0.8209<br />K2O: 3.9690<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","CaO: 0.8403<br />K2O: 4.0446<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","CaO: 0.8383<br />K2O: 3.9939<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2","CaO: 0.8790<br />K2O: 3.8609<br />id: Borrobol-type Tephra GI-1e_pt2<br />id: Borrobol-type Tephra GI-1e_pt2"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(180,196,40,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type Tephra GI-1e_pt2","legendgroup":"Borrobol-type Tephra GI-1e_pt2","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.9134,0.9018,1.0067,1.0151,1.048,0.9426,0.954,0.9072,0.9884,0.9502,0.9566,0.9756,0.8845,0.9504,0.8973,0.908,0.991,1.0766,0.9515,0.9276,0.9345,0.8102,0.969,0.9232,0.9252,0.9688,0.9951,0.999,0.951,0.9828,1.0333,1.0223,1.0099,0.9539,1.0144],"y":[3.8218,3.9253,3.8797,3.8743,3.8076,3.955,3.9586,3.8575,3.8128,3.9921,3.9881,3.7914,4.018,3.9546,4.0097,3.8067,3.9509,4.0063,3.8028,4.1124,4.01,3.9196,3.8586,4.0011,3.8758,3.9892,3.7353,3.9513,3.965,3.9965,3.9339,4.0229,4.0402,3.969,4.1691],"text":["CaO: 0.9134<br />K2O: 3.8218<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9018<br />K2O: 3.9253<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 1.0067<br />K2O: 3.8797<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 1.0151<br />K2O: 3.8743<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 1.0480<br />K2O: 3.8076<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9426<br />K2O: 3.9550<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9540<br />K2O: 3.9586<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9072<br />K2O: 3.8575<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9884<br />K2O: 3.8128<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9502<br />K2O: 3.9921<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9566<br />K2O: 3.9881<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9756<br />K2O: 3.7914<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.8845<br />K2O: 4.0180<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9504<br />K2O: 3.9546<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.8973<br />K2O: 4.0097<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9080<br />K2O: 3.8067<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9910<br />K2O: 3.9509<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 1.0766<br />K2O: 4.0063<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9515<br />K2O: 3.8028<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9276<br />K2O: 4.1124<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9345<br />K2O: 4.0100<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.8102<br />K2O: 3.9196<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9690<br />K2O: 3.8586<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9232<br />K2O: 4.0011<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9252<br />K2O: 3.8758<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9688<br />K2O: 3.9892<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9951<br />K2O: 3.7353<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9990<br />K2O: 3.9513<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9510<br />K2O: 3.9650<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9828<br />K2O: 3.9965<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 1.0333<br />K2O: 3.9339<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 1.0223<br />K2O: 4.0229<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 1.0099<br />K2O: 4.0402<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 0.9539<br />K2O: 3.9690<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","CaO: 1.0144<br />K2O: 4.1691<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(227,3,3,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.7822,0.7457,0.8213,0.7169,0.8313,0.729,0.7774,0.8527,0.7814,0.7732,0.7882,0.8417,0.7564,0.7601,0.7808,0.759,0.7277,0.7581,0.7801,0.8218,0.7261,0.8557,0.7716,0.7304,0.7229,0.7869,0.8023,0.7433,0.6712,0.7073,0.756,0.7471,0.8866,0.7516,0.7407,0.768,0.8132,0.7516,0.7791,0.7403,0.8142,0.6677,0.7567,0.773,0.7638,0.796,0.7818,0.7882,0.8142,0.7477,0.9092,0.8216,0.8595,0.8862,0.7768,0.8536,0.784,0.782,0.8281,0.6966,0.7538,0.794,0.8024,0.7968,0.7329,0.8398,0.8543,0.7549,0.7666,0.8807,0.8662,0.8292,0.6757,0.7818,0.8239,0.844,0.8174,0.8154,0.8075,0.7228,0.8252,0.9053,0.8243,0.9378,0.7519,0.7154,0.7466,0.7683,0.797,0.8122,0.8705,0.7233,0.8025,0.6647,0.8037,0.7861,0.6642,0.7589,0.7898,0.7788,0.8036,0.8391,0.7097,0.7747,0.7269,0.7987,0.7722,0.7999,0.7386,0.7664,0.8872,0.7525,0.8049,0.7814,0.8008,0.7694,0.7423,0.7619,0.8012,0.784,0.7619,0.7921,0.7763,0.8182],"y":[4.047,3.8791,3.805,4.0762,4.0026,3.93,3.8949,3.9131,4.0203,3.8354,3.9763,3.8936,3.9523,3.9952,3.8675,4.1725,4.0111,3.8279,4.0494,3.9118,3.8432,3.7777,4.0133,3.8349,3.8755,4.0017,3.7891,3.8678,3.8988,4.0104,3.953,3.7472,3.8288,3.8085,3.9449,3.7617,3.8212,3.5963,3.8774,3.7684,3.8462,4.0115,3.9356,3.6891,3.6751,3.7454,3.9898,4.0042,3.9353,3.8633,4.0173,3.8066,4.13,4.0559,3.9996,4.0046,3.9305,3.9516,3.9518,4.0057,3.9786,3.8237,3.9079,3.9631,3.8739,3.8631,3.9071,3.9841,3.9159,4.1204,4.0075,4.0306,3.9063,3.8778,3.9823,3.97,3.8566,3.9306,3.922,3.876,4.0213,3.9053,4.0171,3.9199,3.9683,3.7454,3.8366,3.6838,4.0373,3.9662,4.0273,4.0151,3.9916,4.0729,4.0491,3.9893,4.1422,4.035,3.9646,3.9326,3.9727,3.8899,3.9914,4.0136,3.9253,3.9906,3.9574,3.9473,4.0537,4.084,4.1098,4.0064,3.847,3.9904,3.921,4.0367,3.8767,4.0184,3.9434,3.9623,4.0636,3.899,4.0722,3.9563],"text":["CaO: 0.7822<br />K2O: 4.0470<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7457<br />K2O: 3.8791<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8213<br />K2O: 3.8050<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7169<br />K2O: 4.0762<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8313<br />K2O: 4.0026<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7290<br />K2O: 3.9300<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7774<br />K2O: 3.8949<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8527<br />K2O: 3.9131<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7814<br />K2O: 4.0203<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7732<br />K2O: 3.8354<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7882<br />K2O: 3.9763<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8417<br />K2O: 3.8936<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7564<br />K2O: 3.9523<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7601<br />K2O: 3.9952<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7808<br />K2O: 3.8675<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7590<br />K2O: 4.1725<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7277<br />K2O: 4.0111<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7581<br />K2O: 3.8279<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7801<br />K2O: 4.0494<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8218<br />K2O: 3.9118<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7261<br />K2O: 3.8432<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8557<br />K2O: 3.7777<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7716<br />K2O: 4.0133<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7304<br />K2O: 3.8349<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7229<br />K2O: 3.8755<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7869<br />K2O: 4.0017<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8023<br />K2O: 3.7891<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7433<br />K2O: 3.8678<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.6712<br />K2O: 3.8988<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7073<br />K2O: 4.0104<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7560<br />K2O: 3.9530<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7471<br />K2O: 3.7472<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8866<br />K2O: 3.8288<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7516<br />K2O: 3.8085<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7407<br />K2O: 3.9449<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7680<br />K2O: 3.7617<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8132<br />K2O: 3.8212<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7516<br />K2O: 3.5963<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7791<br />K2O: 3.8774<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7403<br />K2O: 3.7684<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8142<br />K2O: 3.8462<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.6677<br />K2O: 4.0115<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7567<br />K2O: 3.9356<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7730<br />K2O: 3.6891<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7638<br />K2O: 3.6751<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7960<br />K2O: 3.7454<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7818<br />K2O: 3.9898<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7882<br />K2O: 4.0042<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8142<br />K2O: 3.9353<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7477<br />K2O: 3.8633<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.9092<br />K2O: 4.0173<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8216<br />K2O: 3.8066<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8595<br />K2O: 4.1300<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8862<br />K2O: 4.0559<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7768<br />K2O: 3.9996<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8536<br />K2O: 4.0046<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7840<br />K2O: 3.9305<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7820<br />K2O: 3.9516<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8281<br />K2O: 3.9518<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.6966<br />K2O: 4.0057<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7538<br />K2O: 3.9786<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7940<br />K2O: 3.8237<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8024<br />K2O: 3.9079<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7968<br />K2O: 3.9631<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7329<br />K2O: 3.8739<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8398<br />K2O: 3.8631<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8543<br />K2O: 3.9071<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7549<br />K2O: 3.9841<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7666<br />K2O: 3.9159<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8807<br />K2O: 4.1204<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8662<br />K2O: 4.0075<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8292<br />K2O: 4.0306<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.6757<br />K2O: 3.9063<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7818<br />K2O: 3.8778<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8239<br />K2O: 3.9823<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8440<br />K2O: 3.9700<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8174<br />K2O: 3.8566<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8154<br />K2O: 3.9306<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8075<br />K2O: 3.9220<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7228<br />K2O: 3.8760<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8252<br />K2O: 4.0213<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.9053<br />K2O: 3.9053<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8243<br />K2O: 4.0171<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.9378<br />K2O: 3.9199<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7519<br />K2O: 3.9683<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7154<br />K2O: 3.7454<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7466<br />K2O: 3.8366<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7683<br />K2O: 3.6838<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7970<br />K2O: 4.0373<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8122<br />K2O: 3.9662<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8705<br />K2O: 4.0273<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7233<br />K2O: 4.0151<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8025<br />K2O: 3.9916<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.6647<br />K2O: 4.0729<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8037<br />K2O: 4.0491<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7861<br />K2O: 3.9893<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.6642<br />K2O: 4.1422<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7589<br />K2O: 4.0350<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7898<br />K2O: 3.9646<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7788<br />K2O: 3.9326<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8036<br />K2O: 3.9727<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8391<br />K2O: 3.8899<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7097<br />K2O: 3.9914<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7747<br />K2O: 4.0136<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7269<br />K2O: 3.9253<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7987<br />K2O: 3.9906<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7722<br />K2O: 3.9574<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7999<br />K2O: 3.9473<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7386<br />K2O: 4.0537<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7664<br />K2O: 4.0840<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8872<br />K2O: 4.1098<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7525<br />K2O: 4.0064<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8049<br />K2O: 3.8470<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7814<br />K2O: 3.9904<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8008<br />K2O: 3.9210<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7694<br />K2O: 4.0367<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7423<br />K2O: 3.8767<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7619<br />K2O: 4.0184<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8012<br />K2O: 3.9434<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7840<br />K2O: 3.9623<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7619<br />K2O: 4.0636<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7921<br />K2O: 3.8990<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.7763<br />K2O: 4.0722<br />id: Borrobol Tephra<br />id: Borrobol Tephra","CaO: 0.8182<br />K2O: 3.9563<br />id: Borrobol Tephra<br />id: Borrobol Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(0,0,0,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.7134,0.7391,0.8604,0.7523,0.7975,0.8097,0.7522,0.6438,0.8062,0.7393,0.817,0.7751,0.7438],"y":[4.0012,3.8413,3.9559,3.9285,3.9874,4.059,3.9072,4.3302,3.9143,3.8505,3.8756,3.8546,3.9916],"text":["CaO: 0.7134<br />K2O: 4.0012<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.7391<br />K2O: 3.8413<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.8604<br />K2O: 3.9559<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.7523<br />K2O: 3.9285<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.7975<br />K2O: 3.9874<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.8097<br />K2O: 4.0590<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.7522<br />K2O: 3.9072<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.6438<br />K2O: 4.3302<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.8062<br />K2O: 3.9143<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.7393<br />K2O: 3.8505<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.8170<br />K2O: 3.8756<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.7751<br />K2O: 3.8546<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden","CaO: 0.7438<br />K2O: 3.9916<br />id: Borrobol Tephra-Sweden<br />id: Borrobol Tephra-Sweden"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(239,19,157,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra-Sweden","legendgroup":"Borrobol Tephra-Sweden","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.8486,0.8787,0.8667,0.8431,0.8238,0.7407,0.6578,0.5896,0.643,0.6603,0.7285,0.7111,0.644,0.6373,0.6328,0.6782,0.5704,0.6997,0.6165,0.7084,0.5725],"y":[3.8892,4.0667,3.9154,3.9244,3.8545,3.9645,3.9509,3.9185,3.98,4.1526,3.7472,3.9098,3.9754,3.9098,3.9366,4.0366,4.0392,4.0334,3.754,4.0307,4.0258],"text":["CaO: 0.8486<br />K2O: 3.8892<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.8787<br />K2O: 4.0667<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.8667<br />K2O: 3.9154<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.8431<br />K2O: 3.9244<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.8238<br />K2O: 3.8545<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.7407<br />K2O: 3.9645<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.6578<br />K2O: 3.9509<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.5896<br />K2O: 3.9185<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.6430<br />K2O: 3.9800<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.6603<br />K2O: 4.1526<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.7285<br />K2O: 3.7472<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.7111<br />K2O: 3.9098<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.6440<br />K2O: 3.9754<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.6373<br />K2O: 3.9098<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.6328<br />K2O: 3.9366<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.6782<br />K2O: 4.0366<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.5704<br />K2O: 4.0392<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.6997<br />K2O: 4.0334<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.6165<br />K2O: 3.7540<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.7084<br />K2O: 4.0307<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","CaO: 0.5725<br />K2O: 4.0258<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(58,112,15,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.8221,0.8115,0.7074,0.7912,0.8141,0.7299,0.7868,0.7667,0.75,0.7664,0.7352,0.797,0.8185,0.8934,0.8209,0.8305,0.8177,0.7666,0.7061,0.7202,0.7538,0.7855,0.8142,0.659,0.7041,0.6523,0.6582,0.7839],"y":[4.0202,3.9697,3.9324,3.9588,3.8883,4.1087,3.8667,3.796,3.8975,3.8257,3.9889,3.9451,3.923,3.9578,3.9702,3.7459,3.8543,4.0731,3.6984,3.8694,3.8751,3.8855,3.9306,3.9689,3.8744,3.9055,3.85,3.8513],"text":["CaO: 0.8221<br />K2O: 4.0202<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.8115<br />K2O: 3.9697<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7074<br />K2O: 3.9324<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7912<br />K2O: 3.9588<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.8141<br />K2O: 3.8883<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7299<br />K2O: 4.1087<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7868<br />K2O: 3.8667<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7667<br />K2O: 3.7960<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7500<br />K2O: 3.8975<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7664<br />K2O: 3.8257<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7352<br />K2O: 3.9889<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7970<br />K2O: 3.9451<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.8185<br />K2O: 3.9230<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.8934<br />K2O: 3.9578<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.8209<br />K2O: 3.9702<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.8305<br />K2O: 3.7459<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.8177<br />K2O: 3.8543<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7666<br />K2O: 4.0731<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7061<br />K2O: 3.6984<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7202<br />K2O: 3.8694<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7538<br />K2O: 3.8751<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7855<br />K2O: 3.8855<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.8142<br />K2O: 3.9306<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.6590<br />K2O: 3.9689<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7041<br />K2O: 3.8744<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.6523<br />K2O: 3.9055<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.6582<br />K2O: 3.8500<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","CaO: 0.7839<br />K2O: 3.8513<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(82,136,255,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.7178,0.7227,0.7332,0.7603,0.7712,0.7254,0.7374,0.7571,0.7421,0.3523],"y":[3.705,4.1507,4.0601,3.9232,3.8633,3.9632,4.0053,3.9183,3.8371,4.7937],"text":["CaO: 0.7178<br />K2O: 3.7050<br />id: Fosen Tephra<br />id: Fosen Tephra","CaO: 0.7227<br />K2O: 4.1507<br />id: Fosen Tephra<br />id: Fosen Tephra","CaO: 0.7332<br />K2O: 4.0601<br />id: Fosen Tephra<br />id: Fosen Tephra","CaO: 0.7603<br />K2O: 3.9232<br />id: Fosen Tephra<br />id: Fosen Tephra","CaO: 0.7712<br />K2O: 3.8633<br />id: Fosen Tephra<br />id: Fosen Tephra","CaO: 0.7254<br />K2O: 3.9632<br />id: Fosen Tephra<br />id: Fosen Tephra","CaO: 0.7374<br />K2O: 4.0053<br />id: Fosen Tephra<br />id: Fosen Tephra","CaO: 0.7571<br />K2O: 3.9183<br />id: Fosen Tephra<br />id: Fosen Tephra","CaO: 0.7421<br />K2O: 3.8371<br />id: Fosen Tephra<br />id: Fosen Tephra","CaO: 0.3523<br />K2O: 4.7937<br />id: Fosen Tephra<br />id: Fosen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(230,71,1,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Fosen Tephra","legendgroup":"Fosen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.6372,0.4472,0.4242,0.5406,0.4983,0.4564,0.5061,0.4683,0.4368,0.4935,0.4685,0.555,0.5082,0.4736,0.532,0.5376,0.8222,0.7289,0.4493,0.4239,0.416,0.3982,0.4608,0.4588,0.5889,0.4983,0.4266,0.4646,0.5163,0.4953,0.4702,0.4588,0.5214,0.5225,0.3785,0.4832,0.5053,0.4834,0.5658,0.5028,0.5529,0.4805,0.4833,0.5062,0.51,0.5866,0.4722,0.4723,0.5354,0.5912,0.5239,0.4115,0.5303,0.508,0.5061,0.5873,0.5482,0.6444,0.3966,0.4358,0.3647,0.4274,0.3854,0.5743,0.5037,0.5456,0.4866,0.6277,0.4645,0.4729,0.4616,0.4936,0.5093,0.4274,0.4851,0.4678,0.3733,0.5444,0.4872,0.486,0.4885,0.4398,0.4408,0.4214,0.4318,0.5071,0.5522,0.5508,0.4882,0.7239,0.716,0.7308,0.5742,0.5345,0.5938,0.7066,0.7539,0.5999,0.6413,0.5483,0.523,0.6177,0.4192,0.5203],"y":[3.817,4.2334,4.3654,4.2497,4.1885,4.2572,4.1064,4.2504,4.0727,4.3622,4.3783,4.4741,4.3945,4.3405,4.0722,4.2631,4.6049,4.4894,4.5012,4.2701,4.2429,4.3692,4.4717,4.3483,4.2587,4.665,4.3184,4.2978,4.0569,4.1834,4.0334,4.3691,4.0146,4.0752,4.4059,4.1597,3.9158,4.8135,4.1282,4.3369,3.9022,4.1157,4.1395,3.9544,4.2157,4.1584,4.1983,4.3246,4.0416,3.9826,4.1806,4.2078,4.4292,4.2544,4.0074,4.1217,4.0169,4.0121,4.3419,4.315,4.4593,4.6279,4.1667,4.3959,4.3337,4.2288,4.1468,4.2872,4.0853,4.3401,4.2593,4.2638,4.1991,4.6492,4.2603,4.2637,4.1891,4.3865,4.247,4.3001,4.2095,4.356,4.3136,4.2984,4.4861,4.3212,4.23,4.5016,4.5319,3.475,3.5018,3.9225,3.815,3.8096,3.8339,3.2427,3.9874,4.1135,4.3683,4.3737,4.3876,4.452,4.3634,4.197],"text":["CaO: 0.6372<br />K2O: 3.8170<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4472<br />K2O: 4.2334<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4242<br />K2O: 4.3654<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5406<br />K2O: 4.2497<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4983<br />K2O: 4.1885<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4564<br />K2O: 4.2572<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5061<br />K2O: 4.1064<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4683<br />K2O: 4.2504<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4368<br />K2O: 4.0727<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4935<br />K2O: 4.3622<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4685<br />K2O: 4.3783<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5550<br />K2O: 4.4741<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5082<br />K2O: 4.3945<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4736<br />K2O: 4.3405<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5320<br />K2O: 4.0722<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5376<br />K2O: 4.2631<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.8222<br />K2O: 4.6049<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.7289<br />K2O: 4.4894<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4493<br />K2O: 4.5012<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4239<br />K2O: 4.2701<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4160<br />K2O: 4.2429<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.3982<br />K2O: 4.3692<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4608<br />K2O: 4.4717<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4588<br />K2O: 4.3483<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5889<br />K2O: 4.2587<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4983<br />K2O: 4.6650<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4266<br />K2O: 4.3184<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4646<br />K2O: 4.2978<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5163<br />K2O: 4.0569<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4953<br />K2O: 4.1834<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4702<br />K2O: 4.0334<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4588<br />K2O: 4.3691<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5214<br />K2O: 4.0146<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5225<br />K2O: 4.0752<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.3785<br />K2O: 4.4059<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4832<br />K2O: 4.1597<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5053<br />K2O: 3.9158<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4834<br />K2O: 4.8135<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5658<br />K2O: 4.1282<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5028<br />K2O: 4.3369<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5529<br />K2O: 3.9022<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4805<br />K2O: 4.1157<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4833<br />K2O: 4.1395<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5062<br />K2O: 3.9544<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5100<br />K2O: 4.2157<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5866<br />K2O: 4.1584<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4722<br />K2O: 4.1983<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4723<br />K2O: 4.3246<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5354<br />K2O: 4.0416<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5912<br />K2O: 3.9826<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5239<br />K2O: 4.1806<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4115<br />K2O: 4.2078<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5303<br />K2O: 4.4292<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5080<br />K2O: 4.2544<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5061<br />K2O: 4.0074<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5873<br />K2O: 4.1217<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5482<br />K2O: 4.0169<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.6444<br />K2O: 4.0121<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.3966<br />K2O: 4.3419<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4358<br />K2O: 4.3150<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.3647<br />K2O: 4.4593<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4274<br />K2O: 4.6279<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.3854<br />K2O: 4.1667<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5743<br />K2O: 4.3959<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5037<br />K2O: 4.3337<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5456<br />K2O: 4.2288<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4866<br />K2O: 4.1468<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.6277<br />K2O: 4.2872<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4645<br />K2O: 4.0853<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4729<br />K2O: 4.3401<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4616<br />K2O: 4.2593<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4936<br />K2O: 4.2638<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5093<br />K2O: 4.1991<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4274<br />K2O: 4.6492<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4851<br />K2O: 4.2603<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4678<br />K2O: 4.2637<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.3733<br />K2O: 4.1891<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5444<br />K2O: 4.3865<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4872<br />K2O: 4.2470<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4860<br />K2O: 4.3001<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4885<br />K2O: 4.2095<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4398<br />K2O: 4.3560<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4408<br />K2O: 4.3136<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4214<br />K2O: 4.2984<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4318<br />K2O: 4.4861<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5071<br />K2O: 4.3212<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5522<br />K2O: 4.2300<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5508<br />K2O: 4.5016<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4882<br />K2O: 4.5319<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.7239<br />K2O: 3.4750<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.7160<br />K2O: 3.5018<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.7308<br />K2O: 3.9225<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5742<br />K2O: 3.8150<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5345<br />K2O: 3.8096<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5938<br />K2O: 3.8339<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.7066<br />K2O: 3.2427<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.7539<br />K2O: 3.9874<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5999<br />K2O: 4.1135<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.6413<br />K2O: 4.3683<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5483<br />K2O: 4.3737<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5230<br />K2O: 4.3876<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.6177<br />K2O: 4.4520<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.4192<br />K2O: 4.3634<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra","CaO: 0.5203<br />K2O: 4.1970<br />id: Hasseldalen Tephra<br />id: Hasseldalen Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(127,154,245,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hasseldalen Tephra","legendgroup":"Hasseldalen Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.4774,0.5122,0.3677,0.387,0.5187,0.5237,0.4406,0.4959,0.5678,0.4648,0.5274,0.446,0.5616,0.3814,0.475,0.5728,0.4429,0.4763,0.4338,0.5313,0.5931,0.4889,0.5739],"y":[5.7971,4.1246,5.9052,5.8832,4.2324,4.1479,4.1754,3.8616,4.0479,4.1517,4.2405,4.1737,4.2276,4.2801,4.2432,4.0624,4.2396,4.0754,4.2319,3.9745,4.194,4.156,4.2619],"text":["CaO: 0.4774<br />K2O: 5.7971<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5122<br />K2O: 4.1246<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.3677<br />K2O: 5.9052<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.3870<br />K2O: 5.8832<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5187<br />K2O: 4.2324<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5237<br />K2O: 4.1479<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.4406<br />K2O: 4.1754<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.4959<br />K2O: 3.8616<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5678<br />K2O: 4.0479<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.4648<br />K2O: 4.1517<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5274<br />K2O: 4.2405<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.4460<br />K2O: 4.1737<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5616<br />K2O: 4.2276<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.3814<br />K2O: 4.2801<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.4750<br />K2O: 4.2432<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5728<br />K2O: 4.0624<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.4429<br />K2O: 4.2396<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.4763<br />K2O: 4.0754<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.4338<br />K2O: 4.2319<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5313<br />K2O: 3.9745<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5931<br />K2O: 4.1940<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.4889<br />K2O: 4.1560<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra","CaO: 0.5739<br />K2O: 4.2619<br />id: Hovsdalur Tephra<br />id: Hovsdalur Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(243,109,32,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Hovsdalur Tephra","legendgroup":"Hovsdalur Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[0.7187,0.6785,0.7077,0.9433,0.8528,0.7712,0.7491,0.7389,0.7848,0.7924,0.5287,0.8265,0.6885,0.6968,0.7936,0.7631,0.8421,0.798,0.8183,0.6866,0.7862,0.6856,0.7733,0.7465,0.7963,0.7593,0.7874,0.7553,0.7296,0.829,0.8098,0.9043,0.8046,0.7702,0.7743,0.7918,0.5947,0.7832,0.6527,0.8024,0.8284,0.6065,0.666,0.6986,0.7686,0.8038,0.6769,0.5509,0.6683,0.6841,0.6214,0.6899,0.7344,0.6898,0.5839,0.7322,0.5549,0.7562,0.8519,0.6467,0.7673,0.6303,0.8071,0.6565,0.5974,0.5553,0.5941,0.6331,0.5991,0.6106,0.6197,0.6246,0.6235,0.6693,0.6763,0.5813,0.5288,0.5901,0.6206,0.9126,0.6085,0.6009,1.0087,0.6003,0.5494,0.6814,0.5814,0.665,0.6266,0.6705,0.5181,0.6972,0.7195,0.6077,0.5885,0.6329,0.5672,0.6486,0.6543,0.6277,0.5998,0.6703,0.6081,0.6341,0.7612,0.5379,0.7111,0.643,0.6808,0.745,0.5948,0.6502,0.5537,0.6898,0.545,0.5743,0.6023,0.662,0.509,0.6697,0.6371,0.6668,0.5674,0.585,0.665,0.6439,0.5451,0.596,0.5292,0.6546,0.5839,0.6039,0.65,0.7173,0.9806,0.7642,0.7565,0.7952,0.7531,0.7707,0.8023,0.7316,0.7891,0.6505,0.7247,0.622,0.7002,0.6138,0.6498,0.7048,0.6414,0.6709,0.7378,0.6915,0.5595,0.6497,0.6257,0.6815,1.0685,0.6389,0.5695,0.9084,0.6387,0.5827,0.6259,0.5842,0.6437,0.5826,0.6406,0.7078,0.6729],"y":[3.7941,3.9689,3.8626,3.964,3.9496,3.7449,3.9984,4.08,3.9815,4.044,3.9748,3.9539,4.0212,4.179,4.0033,3.9901,3.8403,3.9986,3.9647,3.9946,3.8822,3.961,3.9114,3.8275,3.8667,4.0281,4.0584,3.9476,4.0036,3.9249,4.0179,4.0957,3.9289,4.0071,4.0285,4.0752,4.1308,3.9903,3.7816,3.9063,3.9216,4.1556,4.0962,3.8098,4.2071,3.9487,4.1318,3.9805,4.0036,4.0284,4.0429,3.9473,4.1366,4.1567,4.1128,3.8297,4.268,4.045,3.9067,4.0541,3.8115,4.0491,4.0855,4.1213,4.2385,4.1866,4.0907,4.1833,4.125,4.1413,4.1322,4.1229,4.1259,4.047,4.0169,4.1669,4.2492,4.105,4.0693,4.112,4.0925,4.4052,3.9551,4.1454,4.0794,3.9199,4.0163,3.8484,4.0531,4.0143,3.9756,3.895,3.7497,3.9554,3.8861,4.0983,3.8619,4.0244,4.072,3.7932,4.04,3.9267,4.0796,3.9636,3.9718,4.2846,4.0501,3.8682,4.0469,3.8246,3.8687,3.8565,4.0636,3.8545,3.9632,4.035,3.9914,3.9545,3.9735,3.9637,3.967,4.0435,4.1257,3.8884,3.7886,4.0173,4.0281,4.088,4.1048,4.0895,4.2122,4.0419,4.0427,4.0359,3.849,3.9214,3.8979,4.0611,3.9775,4.0541,3.9903,4.0076,3.9769,4.1435,3.8887,3.8286,3.9347,4.1057,3.9322,4.1344,4.1484,3.9833,4.1244,3.981,4.2941,4.1371,4.1551,3.9956,4.0059,4.122,4.0129,4.1523,4.1843,4.0056,4.3228,3.9578,4.1139,4.1358,4.133,4.0131,4.0469],"text":["CaO: 0.7187<br />K2O: 3.7941<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6785<br />K2O: 3.9689<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7077<br />K2O: 3.8626<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.9433<br />K2O: 3.9640<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8528<br />K2O: 3.9496<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7712<br />K2O: 3.7449<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7491<br />K2O: 3.9984<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7389<br />K2O: 4.0800<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7848<br />K2O: 3.9815<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7924<br />K2O: 4.0440<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5287<br />K2O: 3.9748<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8265<br />K2O: 3.9539<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6885<br />K2O: 4.0212<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6968<br />K2O: 4.1790<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7936<br />K2O: 4.0033<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7631<br />K2O: 3.9901<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8421<br />K2O: 3.8403<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7980<br />K2O: 3.9986<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8183<br />K2O: 3.9647<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6866<br />K2O: 3.9946<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7862<br />K2O: 3.8822<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6856<br />K2O: 3.9610<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7733<br />K2O: 3.9114<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7465<br />K2O: 3.8275<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7963<br />K2O: 3.8667<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7593<br />K2O: 4.0281<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7874<br />K2O: 4.0584<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7553<br />K2O: 3.9476<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7296<br />K2O: 4.0036<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8290<br />K2O: 3.9249<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8098<br />K2O: 4.0179<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.9043<br />K2O: 4.0957<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8046<br />K2O: 3.9289<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7702<br />K2O: 4.0071<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7743<br />K2O: 4.0285<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7918<br />K2O: 4.0752<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5947<br />K2O: 4.1308<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7832<br />K2O: 3.9903<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6527<br />K2O: 3.7816<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8024<br />K2O: 3.9063<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8284<br />K2O: 3.9216<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6065<br />K2O: 4.1556<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6660<br />K2O: 4.0962<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6986<br />K2O: 3.8098<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7686<br />K2O: 4.2071<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8038<br />K2O: 3.9487<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6769<br />K2O: 4.1318<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5509<br />K2O: 3.9805<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6683<br />K2O: 4.0036<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6841<br />K2O: 4.0284<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6214<br />K2O: 4.0429<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6899<br />K2O: 3.9473<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7344<br />K2O: 4.1366<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6898<br />K2O: 4.1567<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5839<br />K2O: 4.1128<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7322<br />K2O: 3.8297<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5549<br />K2O: 4.2680<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7562<br />K2O: 4.0450<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8519<br />K2O: 3.9067<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6467<br />K2O: 4.0541<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7673<br />K2O: 3.8115<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6303<br />K2O: 4.0491<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8071<br />K2O: 4.0855<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6565<br />K2O: 4.1213<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5974<br />K2O: 4.2385<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5553<br />K2O: 4.1866<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5941<br />K2O: 4.0907<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6331<br />K2O: 4.1833<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5991<br />K2O: 4.1250<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6106<br />K2O: 4.1413<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6197<br />K2O: 4.1322<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6246<br />K2O: 4.1229<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6235<br />K2O: 4.1259<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6693<br />K2O: 4.0470<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6763<br />K2O: 4.0169<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5813<br />K2O: 4.1669<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5288<br />K2O: 4.2492<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5901<br />K2O: 4.1050<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6206<br />K2O: 4.0693<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.9126<br />K2O: 4.1120<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6085<br />K2O: 4.0925<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6009<br />K2O: 4.4052<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 1.0087<br />K2O: 3.9551<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6003<br />K2O: 4.1454<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5494<br />K2O: 4.0794<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6814<br />K2O: 3.9199<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5814<br />K2O: 4.0163<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6650<br />K2O: 3.8484<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6266<br />K2O: 4.0531<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6705<br />K2O: 4.0143<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5181<br />K2O: 3.9756<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6972<br />K2O: 3.8950<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7195<br />K2O: 3.7497<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6077<br />K2O: 3.9554<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5885<br />K2O: 3.8861<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6329<br />K2O: 4.0983<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5672<br />K2O: 3.8619<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6486<br />K2O: 4.0244<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6543<br />K2O: 4.0720<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6277<br />K2O: 3.7932<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5998<br />K2O: 4.0400<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6703<br />K2O: 3.9267<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6081<br />K2O: 4.0796<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6341<br />K2O: 3.9636<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7612<br />K2O: 3.9718<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5379<br />K2O: 4.2846<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7111<br />K2O: 4.0501<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6430<br />K2O: 3.8682<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6808<br />K2O: 4.0469<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7450<br />K2O: 3.8246<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5948<br />K2O: 3.8687<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6502<br />K2O: 3.8565<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5537<br />K2O: 4.0636<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6898<br />K2O: 3.8545<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5450<br />K2O: 3.9632<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5743<br />K2O: 4.0350<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6023<br />K2O: 3.9914<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6620<br />K2O: 3.9545<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5090<br />K2O: 3.9735<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6697<br />K2O: 3.9637<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6371<br />K2O: 3.9670<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6668<br />K2O: 4.0435<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5674<br />K2O: 4.1257<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5850<br />K2O: 3.8884<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6650<br />K2O: 3.7886<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6439<br />K2O: 4.0173<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5451<br />K2O: 4.0281<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5960<br />K2O: 4.0880<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5292<br />K2O: 4.1048<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6546<br />K2O: 4.0895<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5839<br />K2O: 4.2122<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6039<br />K2O: 4.0419<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6500<br />K2O: 4.0427<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7173<br />K2O: 4.0359<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.9806<br />K2O: 3.8490<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7642<br />K2O: 3.9214<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7565<br />K2O: 3.8979<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7952<br />K2O: 4.0611<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7531<br />K2O: 3.9775<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7707<br />K2O: 4.0541<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.8023<br />K2O: 3.9903<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7316<br />K2O: 4.0076<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7891<br />K2O: 3.9769<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6505<br />K2O: 4.1435<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7247<br />K2O: 3.8887<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6220<br />K2O: 3.8286<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7002<br />K2O: 3.9347<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6138<br />K2O: 4.1057<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6498<br />K2O: 3.9322<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7048<br />K2O: 4.1344<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6414<br />K2O: 4.1484<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6709<br />K2O: 3.9833<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7378<br />K2O: 4.1244<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6915<br />K2O: 3.9810<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5595<br />K2O: 4.2941<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6497<br />K2O: 4.1371<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6257<br />K2O: 4.1551<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6815<br />K2O: 3.9956<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 1.0685<br />K2O: 4.0059<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6389<br />K2O: 4.1220<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5695<br />K2O: 4.0129<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.9084<br />K2O: 4.1523<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6387<br />K2O: 4.1843<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5827<br />K2O: 4.0056<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6259<br />K2O: 4.3228<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5842<br />K2O: 3.9578<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6437<br />K2O: 4.1139<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.5826<br />K2O: 4.1358<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6406<br />K2O: 4.1330<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.7078<br />K2O: 4.0131<br />id: Penifiler Tephra<br />id: Penifiler Tephra","CaO: 0.6729<br />K2O: 4.0469<br />id: Penifiler Tephra<br />id: Penifiler Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(11,48,117,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null}],"layout":{"margin":{"t":25.1324200913242,"r":7.30593607305936,"b":55.2926525529265,"l":42.8393524283935},"plot_bgcolor":"rgba(255,255,255,1)","paper_bgcolor":"rgba(255,255,255,1)","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187},"xaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":true,"range":[0.316085,1.112815],"tickmode":"auto","ticktext":["0.5","0.7","0.9","1.1"],"tickvals":[0.5,0.7,0.9,1.1],"categoryorder":"array","categoryarray":["0.5","0.7","0.9","1.1"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"y","title":{"text":"CaO (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"yaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":true,"range":[3.109575,6.038325],"tickmode":"auto","ticktext":["4","5","6"],"tickvals":[4,5,6],"categoryorder":"array","categoryarray":["4","5","6"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"x","title":{"text":"K2O (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"shapes":[{"type":"rect","fillcolor":"transparent","line":{"color":"rgba(51,51,51,1)","width":0.66417600664176,"linetype":"solid"},"yref":"paper","xref":"paper","x0":0,"x1":1,"y0":0,"y1":1}],"showlegend":true,"legend":{"bgcolor":"rgba(255,255,255,1)","bordercolor":"transparent","borderwidth":1.88976377952756,"font":{"color":"rgba(0,0,0,1)","family":"","size":11.689497716895},"title":{"text":"id","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187}}},"hovermode":"closest","width":1000,"height":800,"barmode":"relative"},"config":{"doubleClick":"reset","modeBarButtonsToAdd":["hoverclosest","hovercompare"],"showSendToCloud":false},"source":"A","attrs":{"724f0e3e7e":{"x":{},"y":{},"fill":{},"shape":{},"type":"scatter"}},"cur_data":"724f0e3e7e","visdat":{"724f0e3e7e":["function (y) ","x"]},"highlight":{"on":"plotly_click","persistent":false,"dynamic":false,"selectize":false,"opacityDim":0.2,"selected":{"opacity":1},"debounce":0},"shinyEvents":["plotly_hover","plotly_click","plotly_selected","plotly_relayout","plotly_brushed","plotly_brushing","plotly_clickannotation","plotly_doubleclick","plotly_deselect","plotly_afterplot","plotly_sunburstclick"],"base_url":"https://plot.ly"},"evals":[],"jsHooks":[]}</script>

## 

# Saving all figures to a .pdf

``` r
l <- list(p1, p2, p3, p4, p5, p6, p7, p8, p9, p47, p10, p11, p12, p13, p14, p15, p16, p17, p18, p19, p20, p21, p22, p23, p24, p25, p26, p27, p28, p29, p30, p31, p32, p33, p34, p35, p36, p37, p38, p39, p40, p41, p42, p43, p44, p45, p46)
pdf("allplotsout.pdf", width = 12, height = 6)
invisible(lapply(l, print))
dev.off()
```

    ## png 
    ##   2

## Harker plot

It is frequently useful to plot all of the collected elemental data
against SiO\[2\]. This permits an assessme tof groupings within the data
and which elements might be useful discriminators. Additionally, wt% K2O
vs SiO2 can further classify the tephra to low, mid and high Potassium
values. The dividing lines included here are from xxxxxxxx.

``` r
g1 <- plot_grid(p1 + theme(legend.position = "none"), 
                p2 + theme(legend.position = "none"),
                p3 + theme(legend.position="none"),
                p4 + theme(legend.position="none"),
                p5 + theme(legend.position="none"),
                p6 + theme(legend.position="none"),
                p7 + theme(legend.position="none"),
                p8 + theme(legend.position="none"), 
                p47 + theme(legend.position="none"), 
                p10 + theme(legend.position="none"),
                labels = c("A", "B", "C", "D", "E", "F", "G", "H", "I", "J"), align = "b")
legend <- get_legend(p1)
legplot <- plot_grid(legend)
px <- plot_grid( g1, rel_widths = c(4, 1))
l2 <- list(px,legplot)
pdf("Script/Output/Plots/Harkerplot.pdf", width = 30, height = 20)
invisible(lapply(l2, print))
dev.off()
```

    ## png 
    ##   2

``` r
ggsave( filename = file.path("Script","Output","Plots","Harker.svg"), plot = px, width = 30, height = 20, dpi = 300)

print(g1)
```

![](Title_files/figure-gfm/unnamed-chunk-70-1.png)<!-- -->

# Other useful R tricks

## Creating an inset within a figure

``` r
p100 <- ggplot(chem, aes(x = TAS_x, y = TAS_y, fill = id, shape = id))
p100 <- p100 + geom_point(aes(fill = id), size=4, alpha=0.8)+xlab("SiO2 (wt%)")+ylab("Na2O+K2O (wt%)")+
  scale_shape_manual(values=c(21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25))+
  scale_fill_manual(values = chempalette) +geom_segment(x=77,y=0,xend=69,yend=8)+ 
  geom_segment(x=69, y=8,xend=69,yend=13)+geom_segment(x=41, y=7,xend=52.5,yend=14)+
  geom_segment(x=52.5,y=14,xend=57.6,yend=11.7)+geom_segment(x=45,y=0,xend=45,yend=5)+
  geom_segment(x=45,y=5,xend=63,yend=14.56)+geom_segment(x=52,y=0,xend=52,yend=5)+
  geom_segment(x=52,y=5,xend=63,yend=7)+geom_segment(x=57,y=0,xend=57,yend=5.9)+
  geom_segment(x=63,y=0,xend=63,yend=7)+geom_segment(x=45,y=5,xend=52,yend=5)+
  geom_segment(x=52,y=5,xend=49.4,yend=7.3)+geom_segment(x=57,y=5.9,xend=53,yend=9.3)+
  geom_segment(x=63,y=7,xend=57.6,yend=11.7)+geom_segment(x=49.4,y=7.3,xend=45,yend=9.4)+
  geom_segment(x=53,y=9.3,xend=48.4,yend=11.5)+geom_segment(x=41,y=0,xend=41,yend=7)+
  geom_segment(x=52.5,y=14,xend=49,yend=15.5)+geom_segment(x=41,y=3,xend=45,yend=3)+
  geom_segment(x=63,y=7,xend=69,yend=8)+
  scale_x_continuous(limits=c(74, 79), expand = c(0, 0)) + ## set x axis of insert
  scale_y_continuous(limits=c(6, 10.5), expand = c(0, 0)) + ## set y axis of insert
  theme_bw()+theme(axis.title.x=element_text(size=9), axis.title.y=element_text(size=9), 
                   axis.text.x=element_text(size=9), axis.text.y=element_text(size=9))+ ## change the text size as neccessary
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), legend.position = "none")
fig_in <- p1 + annotation_custom(ggplotGrob(p100), xmin = 40, xmax = 56, ymin = 7, ymax = 16) + ## place the insert
   annotate("rect", xmin = 74, xmax = 79, ymin = 6, ymax = 10.5,
  alpha = .2) ## use this to highlight the area of the insert plot
```

``` r
ggsave( filename = file.path("Script", "Output","Plots","insert_plot.svg"), plot = fig_in, width = 10, height = 6, dpi = 300)

print(fig_in)
```

![](Title_files/figure-gfm/unnamed-chunk-72-1.png)<!-- --> \## Creating
a HDR plot to simplify your data. Simplifying the data we create to make
more visually compelling figures can be acheived using highest density
regions. The following code permits this as an addition to the
previosuly created plots. It can be added easily to any of the
previously created plots by changing the p code. Visibility of the
density regions can be applied to just reference data or entire
datasets. Opacity is varied using the alpha command and the probability
range can be altered in the ‘probs’ argument. You may need to vary the x
and y axes in order to fit the full range in to the plot.

``` r
p28den <- p28 +
geom_hdr(stat= "hdr", method = "kde", na.rm = TRUE, inherit.aes = TRUE, alpha  = 0.3, xlim = c(0,100), ylim = c(0,30), smooth = TRUE, n = 1000, probs = c(0.75))
print(p28den)
```

![](Title_files/figure-gfm/unnamed-chunk-73-1.png)<!-- -->

The plots are nice but messy and still have lots of overplotting. If you
have particularly messy data I’d suggest creating plot ‘facets’ using
the following code.

``` r
p28den_facet <- p28 +
geom_hdr(method = "kde", alpha  = 0.5, xlim = c(0,100), ylim = c(0,30), show.legend = FALSE, smooth = TRUE, n = 1000, probs = c(0.95)) +
  facet_wrap(~ id)


print(p28den_facet)
```

![](Title_files/figure-gfm/unnamed-chunk-74-1.png)<!-- -->

``` r
chem2 <- dplyr::select(chem, -Total)
chem2 <- rename(chem2, id2=id)
f19 <- ggplot(chem, aes(x = Al2O3, y = CaO,  fill = id, shape = id))

f19 <- f19 + 
    geom_point(data = chem2, inherit.aes = FALSE, aes(x=Al2O3, y = CaO, shape = id2), colour = "grey70") +
  geom_point(aes(fill = id), size=4, alpha=0.8)+xlab("Al2O3 (wt%)")+ylab("CaO (wt%)")+scale_shape_manual(values=c(21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25))+
  scale_fill_manual(values = chempalette) +
  Tephra.theme +
  facet_wrap(~ id)

ggsave( filename = file.path("Script", "Output","Plots","faceted plot.pdf"), plot = f19, width = 25, height = 16, units = "cm", dpi = 300)

print(f19)
```

![](Title_files/figure-gfm/unnamed-chunk-75-1.png)<!-- -->

``` r
unknowns <- here::here("Data","Ardtoe_16.5_B_type.csv") %>% read.csv()
gt(unknowns)
```

<div id="osncjrvket" style="overflow-x:auto;overflow-y:auto;width:auto;height:auto;">
<style>html {
  font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;
}

#osncjrvket .gt_table {
  display: table;
  border-collapse: collapse;
  margin-left: auto;
  margin-right: auto;
  color: #333333;
  font-size: 16px;
  font-weight: normal;
  font-style: normal;
  background-color: #FFFFFF;
  width: auto;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #A8A8A8;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #A8A8A8;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
}

#osncjrvket .gt_heading {
  background-color: #FFFFFF;
  text-align: center;
  border-bottom-color: #FFFFFF;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
}

#osncjrvket .gt_title {
  color: #333333;
  font-size: 125%;
  font-weight: initial;
  padding-top: 4px;
  padding-bottom: 4px;
  border-bottom-color: #FFFFFF;
  border-bottom-width: 0;
}

#osncjrvket .gt_subtitle {
  color: #333333;
  font-size: 85%;
  font-weight: initial;
  padding-top: 0;
  padding-bottom: 4px;
  border-top-color: #FFFFFF;
  border-top-width: 0;
}

#osncjrvket .gt_bottom_border {
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
}

#osncjrvket .gt_col_headings {
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
}

#osncjrvket .gt_col_heading {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: normal;
  text-transform: inherit;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: bottom;
  padding-top: 5px;
  padding-bottom: 6px;
  padding-left: 5px;
  padding-right: 5px;
  overflow-x: hidden;
}

#osncjrvket .gt_column_spanner_outer {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: normal;
  text-transform: inherit;
  padding-top: 0;
  padding-bottom: 0;
  padding-left: 4px;
  padding-right: 4px;
}

#osncjrvket .gt_column_spanner_outer:first-child {
  padding-left: 0;
}

#osncjrvket .gt_column_spanner_outer:last-child {
  padding-right: 0;
}

#osncjrvket .gt_column_spanner {
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  vertical-align: bottom;
  padding-top: 5px;
  padding-bottom: 6px;
  overflow-x: hidden;
  display: inline-block;
  width: 100%;
}

#osncjrvket .gt_group_heading {
  padding: 8px;
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  text-transform: inherit;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: middle;
}

#osncjrvket .gt_empty_group_heading {
  padding: 0.5px;
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  vertical-align: middle;
}

#osncjrvket .gt_from_md > :first-child {
  margin-top: 0;
}

#osncjrvket .gt_from_md > :last-child {
  margin-bottom: 0;
}

#osncjrvket .gt_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  margin: 10px;
  border-top-style: solid;
  border-top-width: 1px;
  border-top-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: middle;
  overflow-x: hidden;
}

#osncjrvket .gt_stub {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  text-transform: inherit;
  border-right-style: solid;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
  padding-left: 12px;
}

#osncjrvket .gt_summary_row {
  color: #333333;
  background-color: #FFFFFF;
  text-transform: inherit;
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
}

#osncjrvket .gt_first_summary_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
}

#osncjrvket .gt_grand_summary_row {
  color: #333333;
  background-color: #FFFFFF;
  text-transform: inherit;
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
}

#osncjrvket .gt_first_grand_summary_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  border-top-style: double;
  border-top-width: 6px;
  border-top-color: #D3D3D3;
}

#osncjrvket .gt_striped {
  background-color: rgba(128, 128, 128, 0.05);
}

#osncjrvket .gt_table_body {
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
}

#osncjrvket .gt_footnotes {
  color: #333333;
  background-color: #FFFFFF;
  border-bottom-style: none;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
}

#osncjrvket .gt_footnote {
  margin: 0px;
  font-size: 90%;
  padding: 4px;
}

#osncjrvket .gt_sourcenotes {
  color: #333333;
  background-color: #FFFFFF;
  border-bottom-style: none;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
}

#osncjrvket .gt_sourcenote {
  font-size: 90%;
  padding: 4px;
}

#osncjrvket .gt_left {
  text-align: left;
}

#osncjrvket .gt_center {
  text-align: center;
}

#osncjrvket .gt_right {
  text-align: right;
  font-variant-numeric: tabular-nums;
}

#osncjrvket .gt_font_normal {
  font-weight: normal;
}

#osncjrvket .gt_font_bold {
  font-weight: bold;
}

#osncjrvket .gt_font_italic {
  font-style: italic;
}

#osncjrvket .gt_super {
  font-size: 65%;
}

#osncjrvket .gt_footnote_marks {
  font-style: italic;
  font-weight: normal;
  font-size: 65%;
}
</style>
<table class="gt_table">
  
  <thead class="gt_col_headings">
    <tr>
      <th class="gt_col_heading gt_columns_bottom_border gt_left" rowspan="1" colspan="1">id2</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">SiO2</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">TiO2</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Al2O3</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">FeO</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">MnO</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">MgO</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">CaO</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Na2O</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">K2O</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Cl</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">P2O5</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Total</th>
    </tr>
  </thead>
  <tbody class="gt_table_body">
    <tr><td class="gt_row gt_left">380</td>
<td class="gt_row gt_right">76.00313</td>
<td class="gt_row gt_right">0.13204995</td>
<td class="gt_row gt_right">12.90136</td>
<td class="gt_row gt_right">1.5669031</td>
<td class="gt_row gt_right">0.05215766</td>
<td class="gt_row gt_right">0.073890020</td>
<td class="gt_row gt_right">0.8094786</td>
<td class="gt_row gt_right">4.229427</td>
<td class="gt_row gt_right">4.206867</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.024940469</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">387</td>
<td class="gt_row gt_right">76.59048</td>
<td class="gt_row gt_right">0.12320307</td>
<td class="gt_row gt_right">12.46894</td>
<td class="gt_row gt_right">1.5890809</td>
<td class="gt_row gt_right">0.05106648</td>
<td class="gt_row gt_right">0.039752971</td>
<td class="gt_row gt_right">0.7755462</td>
<td class="gt_row gt_right">4.462193</td>
<td class="gt_row gt_right">3.900151</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.005189683</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">387</td>
<td class="gt_row gt_right">75.92839</td>
<td class="gt_row gt_right">0.11049529</td>
<td class="gt_row gt_right">13.42150</td>
<td class="gt_row gt_right">1.3561821</td>
<td class="gt_row gt_right">0.05105359</td>
<td class="gt_row gt_right">0.052917614</td>
<td class="gt_row gt_right">0.6484738</td>
<td class="gt_row gt_right">4.296372</td>
<td class="gt_row gt_right">4.118461</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.016258445</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">410</td>
<td class="gt_row gt_right">77.24444</td>
<td class="gt_row gt_right">0.11317187</td>
<td class="gt_row gt_right">11.92802</td>
<td class="gt_row gt_right">1.3273489</td>
<td class="gt_row gt_right">0.04997470</td>
<td class="gt_row gt_right">0.024466780</td>
<td class="gt_row gt_right">0.6460271</td>
<td class="gt_row gt_right">4.554777</td>
<td class="gt_row gt_right">4.095010</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.016658233</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">410</td>
<td class="gt_row gt_right">76.65740</td>
<td class="gt_row gt_right">0.14601109</td>
<td class="gt_row gt_right">12.19382</td>
<td class="gt_row gt_right">1.4629552</td>
<td class="gt_row gt_right">0.03929447</td>
<td class="gt_row gt_right">0.111457235</td>
<td class="gt_row gt_right">0.8955557</td>
<td class="gt_row gt_right">4.487471</td>
<td class="gt_row gt_right">3.965581</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.040453288</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">420</td>
<td class="gt_row gt_right">76.25817</td>
<td class="gt_row gt_right">0.14687726</td>
<td class="gt_row gt_right">12.63333</td>
<td class="gt_row gt_right">1.5402689</td>
<td class="gt_row gt_right">0.03212612</td>
<td class="gt_row gt_right">0.093858662</td>
<td class="gt_row gt_right">0.8514471</td>
<td class="gt_row gt_right">4.611148</td>
<td class="gt_row gt_right">3.811250</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.021627387</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">420</td>
<td class="gt_row gt_right">77.32078</td>
<td class="gt_row gt_right">0.10893876</td>
<td class="gt_row gt_right">12.62702</td>
<td class="gt_row gt_right">1.1756351</td>
<td class="gt_row gt_right">0.02867915</td>
<td class="gt_row gt_right">0.024266975</td>
<td class="gt_row gt_right">0.5681203</td>
<td class="gt_row gt_right">4.075696</td>
<td class="gt_row gt_right">4.062144</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.008824354</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">420</td>
<td class="gt_row gt_right">76.94974</td>
<td class="gt_row gt_right">0.11294698</td>
<td class="gt_row gt_right">12.32582</td>
<td class="gt_row gt_right">1.3819579</td>
<td class="gt_row gt_right">0.05475269</td>
<td class="gt_row gt_right">0.055065562</td>
<td class="gt_row gt_right">0.6674614</td>
<td class="gt_row gt_right">4.356958</td>
<td class="gt_row gt_right">4.079858</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.015330753</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">420</td>
<td class="gt_row gt_right">77.23369</td>
<td class="gt_row gt_right">0.10020921</td>
<td class="gt_row gt_right">11.99594</td>
<td class="gt_row gt_right">1.4343671</td>
<td class="gt_row gt_right">0.03381673</td>
<td class="gt_row gt_right">0.025853769</td>
<td class="gt_row gt_right">0.6393120</td>
<td class="gt_row gt_right">4.414686</td>
<td class="gt_row gt_right">4.112197</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.010031262</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">420</td>
<td class="gt_row gt_right">76.05568</td>
<td class="gt_row gt_right">0.10702770</td>
<td class="gt_row gt_right">12.62792</td>
<td class="gt_row gt_right">1.5104649</td>
<td class="gt_row gt_right">0.04185324</td>
<td class="gt_row gt_right">0.086829867</td>
<td class="gt_row gt_right">0.7079653</td>
<td class="gt_row gt_right">4.610416</td>
<td class="gt_row gt_right">4.240192</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.011764718</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">420</td>
<td class="gt_row gt_right">75.52786</td>
<td class="gt_row gt_right">0.16410136</td>
<td class="gt_row gt_right">13.05794</td>
<td class="gt_row gt_right">1.6359643</td>
<td class="gt_row gt_right">0.03976302</td>
<td class="gt_row gt_right">0.097514075</td>
<td class="gt_row gt_right">0.9487373</td>
<td class="gt_row gt_right">4.601044</td>
<td class="gt_row gt_right">3.897197</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.029980055</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">420</td>
<td class="gt_row gt_right">76.54834</td>
<td class="gt_row gt_right">0.12191103</td>
<td class="gt_row gt_right">12.38466</td>
<td class="gt_row gt_right">1.3845089</td>
<td class="gt_row gt_right">0.04515610</td>
<td class="gt_row gt_right">0.076546362</td>
<td class="gt_row gt_right">0.6711885</td>
<td class="gt_row gt_right">4.759640</td>
<td class="gt_row gt_right">3.979889</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.028157381</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">420</td>
<td class="gt_row gt_right">76.39237</td>
<td class="gt_row gt_right">0.15275863</td>
<td class="gt_row gt_right">12.77143</td>
<td class="gt_row gt_right">1.5077351</td>
<td class="gt_row gt_right">0.06188900</td>
<td class="gt_row gt_right">0.097238986</td>
<td class="gt_row gt_right">0.8168712</td>
<td class="gt_row gt_right">4.433079</td>
<td class="gt_row gt_right">3.745612</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.021018907</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">442</td>
<td class="gt_row gt_right">77.21185</td>
<td class="gt_row gt_right">0.10646580</td>
<td class="gt_row gt_right">12.22102</td>
<td class="gt_row gt_right">1.2313233</td>
<td class="gt_row gt_right">0.03903392</td>
<td class="gt_row gt_right">0.071260827</td>
<td class="gt_row gt_right">0.7180326</td>
<td class="gt_row gt_right">4.497622</td>
<td class="gt_row gt_right">3.883715</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.019782857</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">442</td>
<td class="gt_row gt_right">76.69401</td>
<td class="gt_row gt_right">0.10237887</td>
<td class="gt_row gt_right">12.23788</td>
<td class="gt_row gt_right">1.3744285</td>
<td class="gt_row gt_right">0.03858815</td>
<td class="gt_row gt_right">0.053542372</td>
<td class="gt_row gt_right">0.7210442</td>
<td class="gt_row gt_right">4.747284</td>
<td class="gt_row gt_right">4.009403</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.021542439</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">442</td>
<td class="gt_row gt_right">76.47075</td>
<td class="gt_row gt_right">0.11102017</td>
<td class="gt_row gt_right">12.70541</td>
<td class="gt_row gt_right">1.1456694</td>
<td class="gt_row gt_right">0.04764003</td>
<td class="gt_row gt_right">0.067577494</td>
<td class="gt_row gt_right">0.6471280</td>
<td class="gt_row gt_right">4.583412</td>
<td class="gt_row gt_right">4.204076</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.017314109</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">442</td>
<td class="gt_row gt_right">76.74392</td>
<td class="gt_row gt_right">0.11867632</td>
<td class="gt_row gt_right">12.73449</td>
<td class="gt_row gt_right">1.1364819</td>
<td class="gt_row gt_right">0.03539469</td>
<td class="gt_row gt_right">0.014157877</td>
<td class="gt_row gt_right">0.5949431</td>
<td class="gt_row gt_right">4.177302</td>
<td class="gt_row gt_right">4.424961</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.019779387</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">454</td>
<td class="gt_row gt_right">75.76463</td>
<td class="gt_row gt_right">0.13949886</td>
<td class="gt_row gt_right">12.82045</td>
<td class="gt_row gt_right">1.5436909</td>
<td class="gt_row gt_right">0.05801250</td>
<td class="gt_row gt_right">0.074144316</td>
<td class="gt_row gt_right">0.7587125</td>
<td class="gt_row gt_right">4.976045</td>
<td class="gt_row gt_right">3.837304</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.027506817</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">454</td>
<td class="gt_row gt_right">75.46961</td>
<td class="gt_row gt_right">0.12623091</td>
<td class="gt_row gt_right">13.23725</td>
<td class="gt_row gt_right">1.6791525</td>
<td class="gt_row gt_right">0.04617695</td>
<td class="gt_row gt_right">0.102673364</td>
<td class="gt_row gt_right">0.8101293</td>
<td class="gt_row gt_right">4.674400</td>
<td class="gt_row gt_right">3.828935</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.025538045</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">454</td>
<td class="gt_row gt_right">75.56446</td>
<td class="gt_row gt_right">0.14010431</td>
<td class="gt_row gt_right">12.78176</td>
<td class="gt_row gt_right">1.7300202</td>
<td class="gt_row gt_right">0.05034506</td>
<td class="gt_row gt_right">0.095329786</td>
<td class="gt_row gt_right">0.8687938</td>
<td class="gt_row gt_right">4.773006</td>
<td class="gt_row gt_right">3.975683</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.020390274</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">454</td>
<td class="gt_row gt_right">76.31437</td>
<td class="gt_row gt_right">0.13383242</td>
<td class="gt_row gt_right">12.64378</td>
<td class="gt_row gt_right">1.5893251</td>
<td class="gt_row gt_right">0.05717821</td>
<td class="gt_row gt_right">0.089464629</td>
<td class="gt_row gt_right">0.8199709</td>
<td class="gt_row gt_right">4.441466</td>
<td class="gt_row gt_right">3.884265</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.026245735</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">454</td>
<td class="gt_row gt_right">75.97227</td>
<td class="gt_row gt_right">0.14575976</td>
<td class="gt_row gt_right">12.91750</td>
<td class="gt_row gt_right">1.5434188</td>
<td class="gt_row gt_right">0.03583741</td>
<td class="gt_row gt_right">0.091270132</td>
<td class="gt_row gt_right">0.8381972</td>
<td class="gt_row gt_right">4.493089</td>
<td class="gt_row gt_right">3.951337</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.011526653</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">454</td>
<td class="gt_row gt_right">75.98706</td>
<td class="gt_row gt_right">0.14838109</td>
<td class="gt_row gt_right">13.24833</td>
<td class="gt_row gt_right">1.4673473</td>
<td class="gt_row gt_right">0.03240626</td>
<td class="gt_row gt_right">0.109201816</td>
<td class="gt_row gt_right">0.8817421</td>
<td class="gt_row gt_right">4.331603</td>
<td class="gt_row gt_right">3.768921</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.025008049</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">454</td>
<td class="gt_row gt_right">76.04285</td>
<td class="gt_row gt_right">0.15673637</td>
<td class="gt_row gt_right">12.86868</td>
<td class="gt_row gt_right">1.6107275</td>
<td class="gt_row gt_right">0.04817031</td>
<td class="gt_row gt_right">0.079308605</td>
<td class="gt_row gt_right">0.7418855</td>
<td class="gt_row gt_right">4.458836</td>
<td class="gt_row gt_right">3.981417</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.011494001</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">475</td>
<td class="gt_row gt_right">77.17689</td>
<td class="gt_row gt_right">0.11083083</td>
<td class="gt_row gt_right">12.21404</td>
<td class="gt_row gt_right">1.3087988</td>
<td class="gt_row gt_right">0.02836931</td>
<td class="gt_row gt_right">0.064783636</td>
<td class="gt_row gt_right">0.7981513</td>
<td class="gt_row gt_right">4.204691</td>
<td class="gt_row gt_right">4.080099</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.013443663</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">475</td>
<td class="gt_row gt_right">76.62986</td>
<td class="gt_row gt_right">0.11424276</td>
<td class="gt_row gt_right">12.72582</td>
<td class="gt_row gt_right">1.2411494</td>
<td class="gt_row gt_right">0.03463182</td>
<td class="gt_row gt_right">0.020905791</td>
<td class="gt_row gt_right">0.6802829</td>
<td class="gt_row gt_right">4.507521</td>
<td class="gt_row gt_right">4.027532</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.018160586</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">475</td>
<td class="gt_row gt_right">76.14597</td>
<td class="gt_row gt_right">0.16576605</td>
<td class="gt_row gt_right">12.68678</td>
<td class="gt_row gt_right">1.4035489</td>
<td class="gt_row gt_right">0.04758683</td>
<td class="gt_row gt_right">0.112716714</td>
<td class="gt_row gt_right">0.9232686</td>
<td class="gt_row gt_right">4.548167</td>
<td class="gt_row gt_right">3.944770</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.021324784</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">480</td>
<td class="gt_row gt_right">75.72011</td>
<td class="gt_row gt_right">0.13144165</td>
<td class="gt_row gt_right">13.14479</td>
<td class="gt_row gt_right">1.4961183</td>
<td class="gt_row gt_right">0.04974306</td>
<td class="gt_row gt_right">0.113033613</td>
<td class="gt_row gt_right">0.8535951</td>
<td class="gt_row gt_right">4.578947</td>
<td class="gt_row gt_right">3.895368</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.016960213</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">480</td>
<td class="gt_row gt_right">75.52408</td>
<td class="gt_row gt_right">0.10334690</td>
<td class="gt_row gt_right">13.10485</td>
<td class="gt_row gt_right">1.4388347</td>
<td class="gt_row gt_right">0.02739943</td>
<td class="gt_row gt_right">0.048548039</td>
<td class="gt_row gt_right">0.6299785</td>
<td class="gt_row gt_right">5.011074</td>
<td class="gt_row gt_right">4.104393</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.007605165</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">480</td>
<td class="gt_row gt_right">76.60738</td>
<td class="gt_row gt_right">0.11195173</td>
<td class="gt_row gt_right">12.47452</td>
<td class="gt_row gt_right">1.5198642</td>
<td class="gt_row gt_right">0.05286032</td>
<td class="gt_row gt_right">0.066568700</td>
<td class="gt_row gt_right">0.7041120</td>
<td class="gt_row gt_right">4.360925</td>
<td class="gt_row gt_right">4.085303</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.016616212</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.65605</td>
<td class="gt_row gt_right">0.09946791</td>
<td class="gt_row gt_right">12.89805</td>
<td class="gt_row gt_right">1.1464222</td>
<td class="gt_row gt_right">0.02530779</td>
<td class="gt_row gt_right">0.025722672</td>
<td class="gt_row gt_right">0.5703588</td>
<td class="gt_row gt_right">4.287181</td>
<td class="gt_row gt_right">4.276187</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.015350627</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.71721</td>
<td class="gt_row gt_right">0.09672477</td>
<td class="gt_row gt_right">12.37239</td>
<td class="gt_row gt_right">1.2699973</td>
<td class="gt_row gt_right">0.03887854</td>
<td class="gt_row gt_right">0.039612095</td>
<td class="gt_row gt_right">0.5796151</td>
<td class="gt_row gt_right">4.449968</td>
<td class="gt_row gt_right">4.429743</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.005868459</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.05787</td>
<td class="gt_row gt_right">0.14955098</td>
<td class="gt_row gt_right">12.52087</td>
<td class="gt_row gt_right">1.7823156</td>
<td class="gt_row gt_right">0.04245861</td>
<td class="gt_row gt_right">0.093955429</td>
<td class="gt_row gt_right">0.8774428</td>
<td class="gt_row gt_right">4.393625</td>
<td class="gt_row gt_right">4.065622</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.016289812</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.24703</td>
<td class="gt_row gt_right">0.14635568</td>
<td class="gt_row gt_right">12.82195</td>
<td class="gt_row gt_right">1.6703978</td>
<td class="gt_row gt_right">0.04826290</td>
<td class="gt_row gt_right">0.117941159</td>
<td class="gt_row gt_right">0.8152461</td>
<td class="gt_row gt_right">4.284743</td>
<td class="gt_row gt_right">3.835020</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.013058144</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">75.73803</td>
<td class="gt_row gt_right">0.14102717</td>
<td class="gt_row gt_right">12.70740</td>
<td class="gt_row gt_right">1.7781055</td>
<td class="gt_row gt_right">0.03686645</td>
<td class="gt_row gt_right">0.120984282</td>
<td class="gt_row gt_right">0.8963222</td>
<td class="gt_row gt_right">4.742584</td>
<td class="gt_row gt_right">3.830373</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.008307934</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.85715</td>
<td class="gt_row gt_right">0.11324408</td>
<td class="gt_row gt_right">12.43627</td>
<td class="gt_row gt_right">1.2549926</td>
<td class="gt_row gt_right">0.02068385</td>
<td class="gt_row gt_right">0.003516254</td>
<td class="gt_row gt_right">0.5168894</td>
<td class="gt_row gt_right">4.387768</td>
<td class="gt_row gt_right">4.390457</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.019029141</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">77.57019</td>
<td class="gt_row gt_right">0.10721989</td>
<td class="gt_row gt_right">11.96031</td>
<td class="gt_row gt_right">1.0596218</td>
<td class="gt_row gt_right">0.02662156</td>
<td class="gt_row gt_right">0.026516747</td>
<td class="gt_row gt_right">0.5913339</td>
<td class="gt_row gt_right">4.564025</td>
<td class="gt_row gt_right">4.078863</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.015406964</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.75269</td>
<td class="gt_row gt_right">0.10856079</td>
<td class="gt_row gt_right">13.10689</td>
<td class="gt_row gt_right">0.9835177</td>
<td class="gt_row gt_right">0.03759059</td>
<td class="gt_row gt_right">0.008319228</td>
<td class="gt_row gt_right">0.5732051</td>
<td class="gt_row gt_right">4.347156</td>
<td class="gt_row gt_right">4.061119</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.020952131</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.90239</td>
<td class="gt_row gt_right">0.12989825</td>
<td class="gt_row gt_right">12.50208</td>
<td class="gt_row gt_right">1.3284093</td>
<td class="gt_row gt_right">0.03730896</td>
<td class="gt_row gt_right">0.050445921</td>
<td class="gt_row gt_right">0.7178034</td>
<td class="gt_row gt_right">3.868151</td>
<td class="gt_row gt_right">4.447649</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.015869446</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">77.16865</td>
<td class="gt_row gt_right">0.11003945</td>
<td class="gt_row gt_right">12.48262</td>
<td class="gt_row gt_right">1.3499987</td>
<td class="gt_row gt_right">0.04051881</td>
<td class="gt_row gt_right">0.045858496</td>
<td class="gt_row gt_right">0.7008602</td>
<td class="gt_row gt_right">3.895355</td>
<td class="gt_row gt_right">4.192597</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.013610969</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.27339</td>
<td class="gt_row gt_right">0.10607059</td>
<td class="gt_row gt_right">12.78489</td>
<td class="gt_row gt_right">1.3079264</td>
<td class="gt_row gt_right">0.04881953</td>
<td class="gt_row gt_right">0.019569451</td>
<td class="gt_row gt_right">0.6909682</td>
<td class="gt_row gt_right">4.674601</td>
<td class="gt_row gt_right">4.078669</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.014885274</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">77.51055</td>
<td class="gt_row gt_right">0.09643494</td>
<td class="gt_row gt_right">12.04243</td>
<td class="gt_row gt_right">1.3480998</td>
<td class="gt_row gt_right">0.03696149</td>
<td class="gt_row gt_right">0.035600305</td>
<td class="gt_row gt_right">0.6335807</td>
<td class="gt_row gt_right">4.122411</td>
<td class="gt_row gt_right">4.162199</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.011727159</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.83687</td>
<td class="gt_row gt_right">0.09935218</td>
<td class="gt_row gt_right">12.23137</td>
<td class="gt_row gt_right">1.3357812</td>
<td class="gt_row gt_right">0.04441136</td>
<td class="gt_row gt_right">0.074435944</td>
<td class="gt_row gt_right">0.6581430</td>
<td class="gt_row gt_right">4.373894</td>
<td class="gt_row gt_right">4.322289</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.023352453</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.88847</td>
<td class="gt_row gt_right">0.10963497</td>
<td class="gt_row gt_right">12.17229</td>
<td class="gt_row gt_right">1.3376924</td>
<td class="gt_row gt_right">0.03654499</td>
<td class="gt_row gt_right">0.042271412</td>
<td class="gt_row gt_right">0.6928972</td>
<td class="gt_row gt_right">4.684943</td>
<td class="gt_row gt_right">4.021927</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.013535181</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">76.89560</td>
<td class="gt_row gt_right">0.09150607</td>
<td class="gt_row gt_right">12.56363</td>
<td class="gt_row gt_right">1.1051038</td>
<td class="gt_row gt_right">0.03174278</td>
<td class="gt_row gt_right">0.004756247</td>
<td class="gt_row gt_right">0.6305130</td>
<td class="gt_row gt_right">4.479868</td>
<td class="gt_row gt_right">4.181465</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.015716296</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">77.18127</td>
<td class="gt_row gt_right">0.11148237</td>
<td class="gt_row gt_right">12.42395</td>
<td class="gt_row gt_right">0.9811715</td>
<td class="gt_row gt_right">0.02153637</td>
<td class="gt_row gt_right">0.023647775</td>
<td class="gt_row gt_right">0.5991122</td>
<td class="gt_row gt_right">4.429524</td>
<td class="gt_row gt_right">4.223134</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.004961810</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">76.46034</td>
<td class="gt_row gt_right">0.11591999</td>
<td class="gt_row gt_right">12.34764</td>
<td class="gt_row gt_right">1.4231522</td>
<td class="gt_row gt_right">0.04443073</td>
<td class="gt_row gt_right">0.076753566</td>
<td class="gt_row gt_right">0.6535108</td>
<td class="gt_row gt_right">4.732294</td>
<td class="gt_row gt_right">4.123320</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.022531225</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">77.19453</td>
<td class="gt_row gt_right">0.11599690</td>
<td class="gt_row gt_right">12.73675</td>
<td class="gt_row gt_right">1.2753384</td>
<td class="gt_row gt_right">0.04936929</td>
<td class="gt_row gt_right">0.063071355</td>
<td class="gt_row gt_right">0.6914838</td>
<td class="gt_row gt_right">3.803527</td>
<td class="gt_row gt_right">4.056754</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.012969897</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">77.29433</td>
<td class="gt_row gt_right">0.10890360</td>
<td class="gt_row gt_right">11.97877</td>
<td class="gt_row gt_right">1.4754344</td>
<td class="gt_row gt_right">0.02764476</td>
<td class="gt_row gt_right">0.029634346</td>
<td class="gt_row gt_right">0.5058782</td>
<td class="gt_row gt_right">4.020428</td>
<td class="gt_row gt_right">4.541804</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.017173260</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">77.35520</td>
<td class="gt_row gt_right">0.10626971</td>
<td class="gt_row gt_right">11.70494</td>
<td class="gt_row gt_right">1.2323338</td>
<td class="gt_row gt_right">0.04144830</td>
<td class="gt_row gt_right">0.027112799</td>
<td class="gt_row gt_right">0.5122345</td>
<td class="gt_row gt_right">4.537394</td>
<td class="gt_row gt_right">4.475274</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.007894915</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">77.95664</td>
<td class="gt_row gt_right">0.11758516</td>
<td class="gt_row gt_right">11.93040</td>
<td class="gt_row gt_right">1.2341688</td>
<td class="gt_row gt_right">0.02620047</td>
<td class="gt_row gt_right">0.037821642</td>
<td class="gt_row gt_right">0.5859185</td>
<td class="gt_row gt_right">4.178024</td>
<td class="gt_row gt_right">3.918977</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.014367998</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">76.54875</td>
<td class="gt_row gt_right">0.10491271</td>
<td class="gt_row gt_right">12.84308</td>
<td class="gt_row gt_right">1.3202392</td>
<td class="gt_row gt_right">0.04131332</td>
<td class="gt_row gt_right">0.030380535</td>
<td class="gt_row gt_right">0.6189640</td>
<td class="gt_row gt_right">4.446491</td>
<td class="gt_row gt_right">4.033673</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.012404509</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">75.54970</td>
<td class="gt_row gt_right">0.14337933</td>
<td class="gt_row gt_right">12.87527</td>
<td class="gt_row gt_right">1.7624238</td>
<td class="gt_row gt_right">0.05149390</td>
<td class="gt_row gt_right">0.102670599</td>
<td class="gt_row gt_right">0.9275247</td>
<td class="gt_row gt_right">4.751079</td>
<td class="gt_row gt_right">3.822709</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.013745806</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">75.92387</td>
<td class="gt_row gt_right">0.14512247</td>
<td class="gt_row gt_right">12.74070</td>
<td class="gt_row gt_right">1.7208580</td>
<td class="gt_row gt_right">0.04616577</td>
<td class="gt_row gt_right">0.125352159</td>
<td class="gt_row gt_right">0.9112219</td>
<td class="gt_row gt_right">4.484389</td>
<td class="gt_row gt_right">3.886022</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.016299987</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">75.96993</td>
<td class="gt_row gt_right">0.15329138</td>
<td class="gt_row gt_right">12.74084</td>
<td class="gt_row gt_right">1.6926837</td>
<td class="gt_row gt_right">0.03009401</td>
<td class="gt_row gt_right">0.106896440</td>
<td class="gt_row gt_right">0.9011485</td>
<td class="gt_row gt_right">4.511803</td>
<td class="gt_row gt_right">3.881396</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.011703227</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">77.27263</td>
<td class="gt_row gt_right">0.11252922</td>
<td class="gt_row gt_right">12.13558</td>
<td class="gt_row gt_right">1.2587257</td>
<td class="gt_row gt_right">0.04014444</td>
<td class="gt_row gt_right">0.029016316</td>
<td class="gt_row gt_right">0.6558311</td>
<td class="gt_row gt_right">4.393632</td>
<td class="gt_row gt_right">4.091925</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.009984109</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">575-579</td>
<td class="gt_row gt_right">76.04575</td>
<td class="gt_row gt_right">0.15342392</td>
<td class="gt_row gt_right">12.63895</td>
<td class="gt_row gt_right">1.5826292</td>
<td class="gt_row gt_right">0.04766769</td>
<td class="gt_row gt_right">0.094716315</td>
<td class="gt_row gt_right">0.8835031</td>
<td class="gt_row gt_right">4.670918</td>
<td class="gt_row gt_right">3.867686</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.014754284</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">575-579</td>
<td class="gt_row gt_right">75.96736</td>
<td class="gt_row gt_right">0.14624645</td>
<td class="gt_row gt_right">12.64964</td>
<td class="gt_row gt_right">1.7403431</td>
<td class="gt_row gt_right">0.04519965</td>
<td class="gt_row gt_right">0.097915179</td>
<td class="gt_row gt_right">0.8515907</td>
<td class="gt_row gt_right">4.646900</td>
<td class="gt_row gt_right">3.823598</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.031316155</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">605-609</td>
<td class="gt_row gt_right">76.23718</td>
<td class="gt_row gt_right">0.14228793</td>
<td class="gt_row gt_right">13.05039</td>
<td class="gt_row gt_right">1.5928460</td>
<td class="gt_row gt_right">0.02999413</td>
<td class="gt_row gt_right">0.085562195</td>
<td class="gt_row gt_right">0.8694087</td>
<td class="gt_row gt_right">4.190548</td>
<td class="gt_row gt_right">3.789048</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.012629106</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">605-609</td>
<td class="gt_row gt_right">76.49533</td>
<td class="gt_row gt_right">0.13253017</td>
<td class="gt_row gt_right">12.85034</td>
<td class="gt_row gt_right">1.4540181</td>
<td class="gt_row gt_right">0.04650739</td>
<td class="gt_row gt_right">0.083903993</td>
<td class="gt_row gt_right">0.8073641</td>
<td class="gt_row gt_right">4.090743</td>
<td class="gt_row gt_right">4.002178</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.037078785</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">605-609</td>
<td class="gt_row gt_right">76.45414</td>
<td class="gt_row gt_right">0.06636754</td>
<td class="gt_row gt_right">12.85458</td>
<td class="gt_row gt_right">1.0322203</td>
<td class="gt_row gt_right">0.05258918</td>
<td class="gt_row gt_right">0.075412878</td>
<td class="gt_row gt_right">0.8326970</td>
<td class="gt_row gt_right">4.011607</td>
<td class="gt_row gt_right">4.594296</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.026189409</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">605-609</td>
<td class="gt_row gt_right">76.51119</td>
<td class="gt_row gt_right">0.13518393</td>
<td class="gt_row gt_right">12.34711</td>
<td class="gt_row gt_right">1.6006652</td>
<td class="gt_row gt_right">0.04506131</td>
<td class="gt_row gt_right">0.112497177</td>
<td class="gt_row gt_right">0.8646985</td>
<td class="gt_row gt_right">4.492810</td>
<td class="gt_row gt_right">3.870798</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.019980997</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">605-609</td>
<td class="gt_row gt_right">76.83272</td>
<td class="gt_row gt_right">0.13504035</td>
<td class="gt_row gt_right">12.65311</td>
<td class="gt_row gt_right">1.5101873</td>
<td class="gt_row gt_right">0.04592211</td>
<td class="gt_row gt_right">0.109353327</td>
<td class="gt_row gt_right">0.9304993</td>
<td class="gt_row gt_right">3.969117</td>
<td class="gt_row gt_right">3.795598</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.018452719</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">605-609</td>
<td class="gt_row gt_right">76.16139</td>
<td class="gt_row gt_right">0.12978653</td>
<td class="gt_row gt_right">12.58511</td>
<td class="gt_row gt_right">1.5135492</td>
<td class="gt_row gt_right">0.04984555</td>
<td class="gt_row gt_right">0.100736084</td>
<td class="gt_row gt_right">0.8987874</td>
<td class="gt_row gt_right">4.658730</td>
<td class="gt_row gt_right">3.878862</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.023094061</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">605-609</td>
<td class="gt_row gt_right">76.23662</td>
<td class="gt_row gt_right">0.13762903</td>
<td class="gt_row gt_right">12.75444</td>
<td class="gt_row gt_right">1.4864571</td>
<td class="gt_row gt_right">0.03350599</td>
<td class="gt_row gt_right">0.104653197</td>
<td class="gt_row gt_right">0.8986179</td>
<td class="gt_row gt_right">4.328104</td>
<td class="gt_row gt_right">3.993787</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.026083776</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">76.47049</td>
<td class="gt_row gt_right">0.12827809</td>
<td class="gt_row gt_right">12.42383</td>
<td class="gt_row gt_right">1.6668869</td>
<td class="gt_row gt_right">0.03693327</td>
<td class="gt_row gt_right">0.087807547</td>
<td class="gt_row gt_right">0.7680039</td>
<td class="gt_row gt_right">4.594291</td>
<td class="gt_row gt_right">3.809017</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.014565233</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">75.65204</td>
<td class="gt_row gt_right">0.13396388</td>
<td class="gt_row gt_right">12.84060</td>
<td class="gt_row gt_right">1.7914653</td>
<td class="gt_row gt_right">0.03577266</td>
<td class="gt_row gt_right">0.092211631</td>
<td class="gt_row gt_right">0.8448012</td>
<td class="gt_row gt_right">4.766471</td>
<td class="gt_row gt_right">3.837011</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.005769784</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">75.27886</td>
<td class="gt_row gt_right">0.15208143</td>
<td class="gt_row gt_right">13.58467</td>
<td class="gt_row gt_right">1.3514673</td>
<td class="gt_row gt_right">0.03711573</td>
<td class="gt_row gt_right">0.110416699</td>
<td class="gt_row gt_right">0.8980145</td>
<td class="gt_row gt_right">4.567302</td>
<td class="gt_row gt_right">3.987304</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.032773496</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">76.59546</td>
<td class="gt_row gt_right">0.12812480</td>
<td class="gt_row gt_right">12.34196</td>
<td class="gt_row gt_right">1.6668693</td>
<td class="gt_row gt_right">0.04998218</td>
<td class="gt_row gt_right">0.074401747</td>
<td class="gt_row gt_right">0.8927170</td>
<td class="gt_row gt_right">4.189670</td>
<td class="gt_row gt_right">4.041179</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.019639567</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">75.96815</td>
<td class="gt_row gt_right">0.14878880</td>
<td class="gt_row gt_right">13.20294</td>
<td class="gt_row gt_right">1.4516593</td>
<td class="gt_row gt_right">0.04544289</td>
<td class="gt_row gt_right">0.073085561</td>
<td class="gt_row gt_right">0.8291756</td>
<td class="gt_row gt_right">4.398222</td>
<td class="gt_row gt_right">3.862226</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.020313179</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">76.17420</td>
<td class="gt_row gt_right">0.13646579</td>
<td class="gt_row gt_right">13.12513</td>
<td class="gt_row gt_right">1.6005517</td>
<td class="gt_row gt_right">0.03745506</td>
<td class="gt_row gt_right">0.071154179</td>
<td class="gt_row gt_right">0.7814440</td>
<td class="gt_row gt_right">4.169614</td>
<td class="gt_row gt_right">3.877798</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.026395905</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">76.51764</td>
<td class="gt_row gt_right">0.13979448</td>
<td class="gt_row gt_right">12.83405</td>
<td class="gt_row gt_right">1.5541126</td>
<td class="gt_row gt_right">0.04818713</td>
<td class="gt_row gt_right">0.099897615</td>
<td class="gt_row gt_right">0.8837416</td>
<td class="gt_row gt_right">4.085129</td>
<td class="gt_row gt_right">3.817975</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.019585736</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">76.50526</td>
<td class="gt_row gt_right">0.14789827</td>
<td class="gt_row gt_right">12.54891</td>
<td class="gt_row gt_right">1.5670923</td>
<td class="gt_row gt_right">0.03881018</td>
<td class="gt_row gt_right">0.119682218</td>
<td class="gt_row gt_right">0.8965153</td>
<td class="gt_row gt_right">4.335098</td>
<td class="gt_row gt_right">3.820600</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.019929554</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">76.06042</td>
<td class="gt_row gt_right">0.15925514</td>
<td class="gt_row gt_right">12.67322</td>
<td class="gt_row gt_right">1.4786484</td>
<td class="gt_row gt_right">0.05235356</td>
<td class="gt_row gt_right">0.103766635</td>
<td class="gt_row gt_right">0.9430955</td>
<td class="gt_row gt_right">4.498749</td>
<td class="gt_row gt_right">4.009802</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.020795126</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">795-799</td>
<td class="gt_row gt_right">75.33530</td>
<td class="gt_row gt_right">0.13666351</td>
<td class="gt_row gt_right">13.58413</td>
<td class="gt_row gt_right">1.5086099</td>
<td class="gt_row gt_right">0.03983466</td>
<td class="gt_row gt_right">0.087942663</td>
<td class="gt_row gt_right">0.8680891</td>
<td class="gt_row gt_right">4.492328</td>
<td class="gt_row gt_right">3.939545</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.007354090</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">795-799</td>
<td class="gt_row gt_right">75.98120</td>
<td class="gt_row gt_right">0.13920379</td>
<td class="gt_row gt_right">12.90177</td>
<td class="gt_row gt_right">1.5876109</td>
<td class="gt_row gt_right">0.02271439</td>
<td class="gt_row gt_right">0.080750700</td>
<td class="gt_row gt_right">0.8788802</td>
<td class="gt_row gt_right">4.534543</td>
<td class="gt_row gt_right">3.854465</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.018859196</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">795-799</td>
<td class="gt_row gt_right">76.02033</td>
<td class="gt_row gt_right">0.14636837</td>
<td class="gt_row gt_right">12.72681</td>
<td class="gt_row gt_right">1.6261987</td>
<td class="gt_row gt_right">0.04571390</td>
<td class="gt_row gt_right">0.090064775</td>
<td class="gt_row gt_right">0.8310284</td>
<td class="gt_row gt_right">4.535322</td>
<td class="gt_row gt_right">3.953833</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.024429677</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">795-799</td>
<td class="gt_row gt_right">76.09458</td>
<td class="gt_row gt_right">0.15805704</td>
<td class="gt_row gt_right">12.89237</td>
<td class="gt_row gt_right">1.7420794</td>
<td class="gt_row gt_right">0.03933120</td>
<td class="gt_row gt_right">0.124583675</td>
<td class="gt_row gt_right">0.9393463</td>
<td class="gt_row gt_right">4.105508</td>
<td class="gt_row gt_right">3.875692</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.028452359</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">795-799</td>
<td class="gt_row gt_right">76.11842</td>
<td class="gt_row gt_right">0.13950288</td>
<td class="gt_row gt_right">12.91580</td>
<td class="gt_row gt_right">1.5388064</td>
<td class="gt_row gt_right">0.05046292</td>
<td class="gt_row gt_right">0.107181583</td>
<td class="gt_row gt_right">0.8208566</td>
<td class="gt_row gt_right">4.333660</td>
<td class="gt_row gt_right">3.969263</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.006151472</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">795-799</td>
<td class="gt_row gt_right">76.56116</td>
<td class="gt_row gt_right">0.13616181</td>
<td class="gt_row gt_right">12.37317</td>
<td class="gt_row gt_right">1.6105731</td>
<td class="gt_row gt_right">0.03365097</td>
<td class="gt_row gt_right">0.106769143</td>
<td class="gt_row gt_right">0.8507257</td>
<td class="gt_row gt_right">4.305871</td>
<td class="gt_row gt_right">4.007686</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.014332823</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">795-799</td>
<td class="gt_row gt_right">77.44136</td>
<td class="gt_row gt_right">0.13002308</td>
<td class="gt_row gt_right">12.22340</td>
<td class="gt_row gt_right">1.5432906</td>
<td class="gt_row gt_right">0.04673831</td>
<td class="gt_row gt_right">0.071960517</td>
<td class="gt_row gt_right">0.8779389</td>
<td class="gt_row gt_right">3.626028</td>
<td class="gt_row gt_right">4.011361</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.028001804</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">855-859</td>
<td class="gt_row gt_right">76.52489</td>
<td class="gt_row gt_right">0.14146244</td>
<td class="gt_row gt_right">12.69460</td>
<td class="gt_row gt_right">1.5045983</td>
<td class="gt_row gt_right">0.04330911</td>
<td class="gt_row gt_right">0.102033326</td>
<td class="gt_row gt_right">0.8832751</td>
<td class="gt_row gt_right">4.261071</td>
<td class="gt_row gt_right">3.824834</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.020029152</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">855-859</td>
<td class="gt_row gt_right">76.32537</td>
<td class="gt_row gt_right">0.14330571</td>
<td class="gt_row gt_right">13.02532</td>
<td class="gt_row gt_right">1.4287049</td>
<td class="gt_row gt_right">0.03301339</td>
<td class="gt_row gt_right">0.107320056</td>
<td class="gt_row gt_right">0.8976245</td>
<td class="gt_row gt_right">4.112343</td>
<td class="gt_row gt_right">3.908849</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.018152057</td>
<td class="gt_row gt_right">100</td></tr>
    <tr><td class="gt_row gt_left">855-859</td>
<td class="gt_row gt_right">76.57861</td>
<td class="gt_row gt_right">0.14483409</td>
<td class="gt_row gt_right">12.49259</td>
<td class="gt_row gt_right">1.5230940</td>
<td class="gt_row gt_right">0.03135476</td>
<td class="gt_row gt_right">0.100916660</td>
<td class="gt_row gt_right">0.9157252</td>
<td class="gt_row gt_right">4.354056</td>
<td class="gt_row gt_right">3.829434</td>
<td class="gt_row gt_right">0</td>
<td class="gt_row gt_right">0.029278290</td>
<td class="gt_row gt_right">100</td></tr>
  </tbody>
  
  
</table>
</div>

``` r
unknown_sum <- unknowns %>% group_by(id2) %>% dplyr::summarise(                                            
                                                       count=n(),
                                                       SiO2.= mean(SiO2),
                                                       dev_1 = sd(SiO2),
                                                       TiO2. = mean(TiO2),
                                                       dev_2 = sd(TiO2),
                                                       Al2O3. = mean(Al2O3),
                                                       dev_3 = sd(Al2O3),
                                                       FeOt = mean(FeO),
                                                       dev_4 = sd(FeO),
                                                       MnO.= mean(MnO),
                                                       dev_5 = sd(MnO),
                                                       MgO.= mean(MgO),
                                                       dev_6 = sd(MgO),
                                                       CaO.= mean(CaO),
                                                       dev_7 = sd(CaO),
                                                       Na2O. = mean(Na2O),
                                                       dev_8 = sd(Na2O),
                                                       K2O. = mean(K2O),
                                                       dev_9 = sd(K2O),
                                                       P2O5. = mean(P2O5),
                                                       dev_10 = sd(P2O5),
                                                       Total.=mean(Total),
                                                       dev_11 = sd(Total))
unknown_sum <- unknown_sum %>% mutate(across(where(is.numeric), ~ round(., digits = 2)))
unknown_sum %>% rename(layer = id2, n = count , SiO2 = SiO2., sd1 = dev_1, TiO2 = TiO2. , sd2 = dev_2)
```

    ## # A tibble: 15 x 24
    ##    layer       n  SiO2   sd1  TiO2   sd2 Al2O3. dev_3  FeOt dev_4  MnO. dev_5
    ##    <chr>   <dbl> <dbl> <dbl> <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl>
    ##  1 380         1  76   NA     0.13 NA      12.9 NA     1.57 NA     0.05 NA   
    ##  2 387         2  76.3  0.47  0.12  0.01   13.0  0.67  1.47  0.16  0.05  0   
    ##  3 410         2  77.0  0.42  0.13  0.02   12.1  0.19  1.4   0.1   0.04  0.01
    ##  4 420         8  76.5  0.61  0.13  0.02   12.6  0.32  1.45  0.14  0.04  0.01
    ##  5 442         4  76.8  0.31  0.11  0.01   12.5  0.28  1.22  0.11  0.04  0.01
    ##  6 454         7  75.9  0.29  0.14  0.01   12.9  0.23  1.59  0.09  0.05  0.01
    ##  7 475         3  76.6  0.52  0.13  0.03   12.5  0.28  1.32  0.08  0.04  0.01
    ##  8 480         3  76.0  0.58  0.12  0.01   12.9  0.38  1.48  0.04  0.04  0.01
    ##  9 505-510    16  76.8  0.5   0.11  0.02   12.5  0.31  1.31  0.25  0.04  0.01
    ## 10 520-524    10  76.8  0.78  0.12  0.02   12.4  0.44  1.44  0.21  0.04  0.01
    ## 11 575-579     2  76.0  0.06  0.15  0.01   12.6  0.01  1.66  0.11  0.05  0   
    ## 12 605-609     7  76.4  0.23  0.13  0.03   12.7  0.23  1.46  0.19  0.04  0.01
    ## 13 655-659     9  76.1  0.45  0.14  0.01   12.8  0.4   1.57  0.13  0.04  0.01
    ## 14 795-799     7  76.2  0.65  0.14  0.01   12.8  0.44  1.59  0.08  0.04  0.01
    ## 15 855-859     3  76.5  0.13  0.14  0      12.7  0.27  1.49  0.05  0.04  0.01
    ## # ... with 12 more variables: MgO. <dbl>, dev_6 <dbl>, CaO. <dbl>, dev_7 <dbl>,
    ## #   Na2O. <dbl>, dev_8 <dbl>, K2O. <dbl>, dev_9 <dbl>, P2O5. <dbl>,
    ## #   dev_10 <dbl>, Total. <dbl>, dev_11 <dbl>

``` r
gt(unknown_sum)
```

<div id="nvyzesyyic" style="overflow-x:auto;overflow-y:auto;width:auto;height:auto;">
<style>html {
  font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;
}

#nvyzesyyic .gt_table {
  display: table;
  border-collapse: collapse;
  margin-left: auto;
  margin-right: auto;
  color: #333333;
  font-size: 16px;
  font-weight: normal;
  font-style: normal;
  background-color: #FFFFFF;
  width: auto;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #A8A8A8;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #A8A8A8;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
}

#nvyzesyyic .gt_heading {
  background-color: #FFFFFF;
  text-align: center;
  border-bottom-color: #FFFFFF;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
}

#nvyzesyyic .gt_title {
  color: #333333;
  font-size: 125%;
  font-weight: initial;
  padding-top: 4px;
  padding-bottom: 4px;
  border-bottom-color: #FFFFFF;
  border-bottom-width: 0;
}

#nvyzesyyic .gt_subtitle {
  color: #333333;
  font-size: 85%;
  font-weight: initial;
  padding-top: 0;
  padding-bottom: 4px;
  border-top-color: #FFFFFF;
  border-top-width: 0;
}

#nvyzesyyic .gt_bottom_border {
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
}

#nvyzesyyic .gt_col_headings {
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
}

#nvyzesyyic .gt_col_heading {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: normal;
  text-transform: inherit;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: bottom;
  padding-top: 5px;
  padding-bottom: 6px;
  padding-left: 5px;
  padding-right: 5px;
  overflow-x: hidden;
}

#nvyzesyyic .gt_column_spanner_outer {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: normal;
  text-transform: inherit;
  padding-top: 0;
  padding-bottom: 0;
  padding-left: 4px;
  padding-right: 4px;
}

#nvyzesyyic .gt_column_spanner_outer:first-child {
  padding-left: 0;
}

#nvyzesyyic .gt_column_spanner_outer:last-child {
  padding-right: 0;
}

#nvyzesyyic .gt_column_spanner {
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  vertical-align: bottom;
  padding-top: 5px;
  padding-bottom: 6px;
  overflow-x: hidden;
  display: inline-block;
  width: 100%;
}

#nvyzesyyic .gt_group_heading {
  padding: 8px;
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  text-transform: inherit;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: middle;
}

#nvyzesyyic .gt_empty_group_heading {
  padding: 0.5px;
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  vertical-align: middle;
}

#nvyzesyyic .gt_from_md > :first-child {
  margin-top: 0;
}

#nvyzesyyic .gt_from_md > :last-child {
  margin-bottom: 0;
}

#nvyzesyyic .gt_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  margin: 10px;
  border-top-style: solid;
  border-top-width: 1px;
  border-top-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 1px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 1px;
  border-right-color: #D3D3D3;
  vertical-align: middle;
  overflow-x: hidden;
}

#nvyzesyyic .gt_stub {
  color: #333333;
  background-color: #FFFFFF;
  font-size: 100%;
  font-weight: initial;
  text-transform: inherit;
  border-right-style: solid;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
  padding-left: 12px;
}

#nvyzesyyic .gt_summary_row {
  color: #333333;
  background-color: #FFFFFF;
  text-transform: inherit;
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
}

#nvyzesyyic .gt_first_summary_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
}

#nvyzesyyic .gt_grand_summary_row {
  color: #333333;
  background-color: #FFFFFF;
  text-transform: inherit;
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
}

#nvyzesyyic .gt_first_grand_summary_row {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 5px;
  padding-right: 5px;
  border-top-style: double;
  border-top-width: 6px;
  border-top-color: #D3D3D3;
}

#nvyzesyyic .gt_striped {
  background-color: rgba(128, 128, 128, 0.05);
}

#nvyzesyyic .gt_table_body {
  border-top-style: solid;
  border-top-width: 2px;
  border-top-color: #D3D3D3;
  border-bottom-style: solid;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
}

#nvyzesyyic .gt_footnotes {
  color: #333333;
  background-color: #FFFFFF;
  border-bottom-style: none;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
}

#nvyzesyyic .gt_footnote {
  margin: 0px;
  font-size: 90%;
  padding: 4px;
}

#nvyzesyyic .gt_sourcenotes {
  color: #333333;
  background-color: #FFFFFF;
  border-bottom-style: none;
  border-bottom-width: 2px;
  border-bottom-color: #D3D3D3;
  border-left-style: none;
  border-left-width: 2px;
  border-left-color: #D3D3D3;
  border-right-style: none;
  border-right-width: 2px;
  border-right-color: #D3D3D3;
}

#nvyzesyyic .gt_sourcenote {
  font-size: 90%;
  padding: 4px;
}

#nvyzesyyic .gt_left {
  text-align: left;
}

#nvyzesyyic .gt_center {
  text-align: center;
}

#nvyzesyyic .gt_right {
  text-align: right;
  font-variant-numeric: tabular-nums;
}

#nvyzesyyic .gt_font_normal {
  font-weight: normal;
}

#nvyzesyyic .gt_font_bold {
  font-weight: bold;
}

#nvyzesyyic .gt_font_italic {
  font-style: italic;
}

#nvyzesyyic .gt_super {
  font-size: 65%;
}

#nvyzesyyic .gt_footnote_marks {
  font-style: italic;
  font-weight: normal;
  font-size: 65%;
}
</style>
<table class="gt_table">
  
  <thead class="gt_col_headings">
    <tr>
      <th class="gt_col_heading gt_columns_bottom_border gt_left" rowspan="1" colspan="1">id2</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">count</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">SiO2.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_1</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">TiO2.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_2</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Al2O3.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_3</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">FeOt</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_4</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">MnO.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_5</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">MgO.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_6</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">CaO.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_7</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Na2O.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_8</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">K2O.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_9</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">P2O5.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_10</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">Total.</th>
      <th class="gt_col_heading gt_columns_bottom_border gt_right" rowspan="1" colspan="1">dev_11</th>
    </tr>
  </thead>
  <tbody class="gt_table_body">
    <tr><td class="gt_row gt_left">380</td>
<td class="gt_row gt_right">1</td>
<td class="gt_row gt_right">76.00</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">12.90</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">1.57</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">0.81</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">4.23</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">4.21</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">NA</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">NA</td></tr>
    <tr><td class="gt_row gt_left">387</td>
<td class="gt_row gt_right">2</td>
<td class="gt_row gt_right">76.26</td>
<td class="gt_row gt_right">0.47</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.95</td>
<td class="gt_row gt_right">0.67</td>
<td class="gt_row gt_right">1.47</td>
<td class="gt_row gt_right">0.16</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.71</td>
<td class="gt_row gt_right">0.09</td>
<td class="gt_row gt_right">4.38</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">4.01</td>
<td class="gt_row gt_right">0.15</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">410</td>
<td class="gt_row gt_right">2</td>
<td class="gt_row gt_right">76.95</td>
<td class="gt_row gt_right">0.42</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">12.06</td>
<td class="gt_row gt_right">0.19</td>
<td class="gt_row gt_right">1.40</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.06</td>
<td class="gt_row gt_right">0.77</td>
<td class="gt_row gt_right">0.18</td>
<td class="gt_row gt_right">4.52</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">4.03</td>
<td class="gt_row gt_right">0.09</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">420</td>
<td class="gt_row gt_right">8</td>
<td class="gt_row gt_right">76.54</td>
<td class="gt_row gt_right">0.61</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">12.55</td>
<td class="gt_row gt_right">0.32</td>
<td class="gt_row gt_right">1.45</td>
<td class="gt_row gt_right">0.14</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.73</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">4.48</td>
<td class="gt_row gt_right">0.21</td>
<td class="gt_row gt_right">3.99</td>
<td class="gt_row gt_right">0.17</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">442</td>
<td class="gt_row gt_right">4</td>
<td class="gt_row gt_right">76.78</td>
<td class="gt_row gt_right">0.31</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.47</td>
<td class="gt_row gt_right">0.28</td>
<td class="gt_row gt_right">1.22</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.67</td>
<td class="gt_row gt_right">0.06</td>
<td class="gt_row gt_right">4.50</td>
<td class="gt_row gt_right">0.24</td>
<td class="gt_row gt_right">4.13</td>
<td class="gt_row gt_right">0.24</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">454</td>
<td class="gt_row gt_right">7</td>
<td class="gt_row gt_right">75.87</td>
<td class="gt_row gt_right">0.29</td>
<td class="gt_row gt_right">0.14</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.93</td>
<td class="gt_row gt_right">0.23</td>
<td class="gt_row gt_right">1.59</td>
<td class="gt_row gt_right">0.09</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.09</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.82</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">4.59</td>
<td class="gt_row gt_right">0.23</td>
<td class="gt_row gt_right">3.89</td>
<td class="gt_row gt_right">0.08</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">475</td>
<td class="gt_row gt_right">3</td>
<td class="gt_row gt_right">76.65</td>
<td class="gt_row gt_right">0.52</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">12.54</td>
<td class="gt_row gt_right">0.28</td>
<td class="gt_row gt_right">1.32</td>
<td class="gt_row gt_right">0.08</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.80</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">4.42</td>
<td class="gt_row gt_right">0.19</td>
<td class="gt_row gt_right">4.02</td>
<td class="gt_row gt_right">0.07</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">480</td>
<td class="gt_row gt_right">3</td>
<td class="gt_row gt_right">75.95</td>
<td class="gt_row gt_right">0.58</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.91</td>
<td class="gt_row gt_right">0.38</td>
<td class="gt_row gt_right">1.48</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.08</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.73</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">4.65</td>
<td class="gt_row gt_right">0.33</td>
<td class="gt_row gt_right">4.03</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">505-510</td>
<td class="gt_row gt_right">16</td>
<td class="gt_row gt_right">76.77</td>
<td class="gt_row gt_right">0.50</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">12.50</td>
<td class="gt_row gt_right">0.31</td>
<td class="gt_row gt_right">1.31</td>
<td class="gt_row gt_right">0.25</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.67</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">4.37</td>
<td class="gt_row gt_right">0.25</td>
<td class="gt_row gt_right">4.16</td>
<td class="gt_row gt_right">0.19</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">520-524</td>
<td class="gt_row gt_right">10</td>
<td class="gt_row gt_right">76.75</td>
<td class="gt_row gt_right">0.78</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">12.40</td>
<td class="gt_row gt_right">0.44</td>
<td class="gt_row gt_right">1.44</td>
<td class="gt_row gt_right">0.21</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.06</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.70</td>
<td class="gt_row gt_right">0.16</td>
<td class="gt_row gt_right">4.39</td>
<td class="gt_row gt_right">0.30</td>
<td class="gt_row gt_right">4.08</td>
<td class="gt_row gt_right">0.25</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">575-579</td>
<td class="gt_row gt_right">2</td>
<td class="gt_row gt_right">76.01</td>
<td class="gt_row gt_right">0.06</td>
<td class="gt_row gt_right">0.15</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.64</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">1.66</td>
<td class="gt_row gt_right">0.11</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">0.87</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">4.66</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">3.85</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">605-609</td>
<td class="gt_row gt_right">7</td>
<td class="gt_row gt_right">76.42</td>
<td class="gt_row gt_right">0.23</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.03</td>
<td class="gt_row gt_right">12.73</td>
<td class="gt_row gt_right">0.23</td>
<td class="gt_row gt_right">1.46</td>
<td class="gt_row gt_right">0.19</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.87</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">4.25</td>
<td class="gt_row gt_right">0.26</td>
<td class="gt_row gt_right">3.99</td>
<td class="gt_row gt_right">0.28</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">655-659</td>
<td class="gt_row gt_right">9</td>
<td class="gt_row gt_right">76.14</td>
<td class="gt_row gt_right">0.45</td>
<td class="gt_row gt_right">0.14</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.84</td>
<td class="gt_row gt_right">0.40</td>
<td class="gt_row gt_right">1.57</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.09</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.86</td>
<td class="gt_row gt_right">0.06</td>
<td class="gt_row gt_right">4.40</td>
<td class="gt_row gt_right">0.23</td>
<td class="gt_row gt_right">3.90</td>
<td class="gt_row gt_right">0.09</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">795-799</td>
<td class="gt_row gt_right">7</td>
<td class="gt_row gt_right">76.22</td>
<td class="gt_row gt_right">0.65</td>
<td class="gt_row gt_right">0.14</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">12.80</td>
<td class="gt_row gt_right">0.44</td>
<td class="gt_row gt_right">1.59</td>
<td class="gt_row gt_right">0.08</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.87</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">4.28</td>
<td class="gt_row gt_right">0.33</td>
<td class="gt_row gt_right">3.94</td>
<td class="gt_row gt_right">0.06</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
    <tr><td class="gt_row gt_left">855-859</td>
<td class="gt_row gt_right">3</td>
<td class="gt_row gt_right">76.48</td>
<td class="gt_row gt_right">0.13</td>
<td class="gt_row gt_right">0.14</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">12.74</td>
<td class="gt_row gt_right">0.27</td>
<td class="gt_row gt_right">1.49</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.04</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">0.10</td>
<td class="gt_row gt_right">0.00</td>
<td class="gt_row gt_right">0.90</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">4.24</td>
<td class="gt_row gt_right">0.12</td>
<td class="gt_row gt_right">3.85</td>
<td class="gt_row gt_right">0.05</td>
<td class="gt_row gt_right">0.02</td>
<td class="gt_row gt_right">0.01</td>
<td class="gt_row gt_right">100</td>
<td class="gt_row gt_right">0</td></tr>
  </tbody>
  
  
</table>
</div>

``` r
chem_red <- filter(chem, age == "WI"|age == "GS2")

c28 <- ggplot(chem_red, aes(x = FeO, y = CaO,  fill = id, shape = id))
c28 <- c28 + 
  geom_hdr(method = "kde", alpha  = 0.5, xlim = c(0,100), ylim = c(0,30), show.legend = FALSE, smooth = TRUE, n = 1000, probs = c(0.95)) +
   scale_fill_manual(values = chempalette) +
    geom_point(data = unknowns, inherit.aes = FALSE, aes(x=FeO, y = CaO, shape = id2, fill = id2), size=4, alpha=0.8) +
  xlab("FeO (wt%)") +
  ylab("CaO (wt%)") + 
   scale_fill_manual(values = chempalette) +
  scale_shape_manual(values=c(1:5,7,11, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25)) +
  Tephra.theme
```

    ## Scale for 'fill' is already present. Adding another scale for 'fill', which
    ## will replace the existing scale.

``` r
print(c28)
```

![](Title_files/figure-gfm/unnamed-chunk-78-1.png)<!-- -->

``` r
u28 <- ggplot(chem_red, aes(x = FeO, y = CaO,  fill = id, shape = id))
u28 <- u28 + geom_point(aes(fill = id), size=4, alpha=0.8)+xlab("FeO (wt%)")+ylab("CaO (wt%)")+scale_shape_manual(values=c(21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25, 21:25))+
      geom_point(data = unknowns, inherit.aes = FALSE, aes(x=FeO, y = CaO, shape = id2, fill = id2), size=4, alpha=0.8) +
  scale_fill_manual(values = chempalette) +
  Tephra.theme

ggplotly(u28, width = 1000, height = 800)
```

<div id="htmlwidget-bb3486349adfa5d821dc" style="width:1000px;height:800px;" class="plotly html-widget"></div>
<script type="application/json" data-for="htmlwidget-bb3486349adfa5d821dc">{"x":{"data":[{"x":[1.3013,1.6491,1.6082,1.5857,1.5998,1.7135,1.5096,1.4933,1.6272,1.6835,1.3803,1.6167,1.645,1.6165,1.4252,1.4708,1.7516,1.6061,1.7137,1.5599,1.8257,1.1974,1.5916,1.5857,1.6455,1.4562,1.7472,1.635,1.4325,1.5216,1.6508,1.6576,1.684,1.5218,1.5084],"y":[0.9134,0.9018,1.0067,1.0151,1.048,0.9426,0.954,0.9072,0.9884,0.9502,0.9566,0.9756,0.8845,0.9504,0.8973,0.908,0.991,1.0766,0.9515,0.9276,0.9345,0.8102,0.969,0.9232,0.9252,0.9688,0.9951,0.999,0.951,0.9828,1.0333,1.0223,1.0099,0.9539,1.0144],"text":["FeO: 1.3013<br />CaO: 0.9134<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6491<br />CaO: 0.9018<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6082<br />CaO: 1.0067<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5857<br />CaO: 1.0151<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5998<br />CaO: 1.0480<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.7135<br />CaO: 0.9426<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5096<br />CaO: 0.9540<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4933<br />CaO: 0.9072<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6272<br />CaO: 0.9884<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6835<br />CaO: 0.9502<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.3803<br />CaO: 0.9566<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6167<br />CaO: 0.9756<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6450<br />CaO: 0.8845<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6165<br />CaO: 0.9504<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4252<br />CaO: 0.8973<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4708<br />CaO: 0.9080<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.7516<br />CaO: 0.9910<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6061<br />CaO: 1.0766<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.7137<br />CaO: 0.9515<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5599<br />CaO: 0.9276<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.8257<br />CaO: 0.9345<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.1974<br />CaO: 0.8102<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5916<br />CaO: 0.9690<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5857<br />CaO: 0.9232<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6455<br />CaO: 0.9252<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4562<br />CaO: 0.9688<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.7472<br />CaO: 0.9951<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6350<br />CaO: 0.9990<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.4325<br />CaO: 0.9510<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5216<br />CaO: 0.9828<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6508<br />CaO: 1.0333<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6576<br />CaO: 1.0223<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.6840<br />CaO: 1.0099<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5218<br />CaO: 0.9539<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra","FeO: 1.5084<br />CaO: 1.0144<br />id: Borrobol-type:GS-2.1-RHY Tephra<br />id: Borrobol-type:GS-2.1-RHY Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(128,221,184,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol-type:GS-2.1-RHY Tephra","legendgroup":"Borrobol-type:GS-2.1-RHY Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.4829,1.5334,1.5915,1.4596,1.5658,1.451,1.5396,1.5186,1.4584,1.6774,1.6552,1.5205,1.5743,1.7267,1.4836,1.4749,1.4743,1.4754,1.3884,1.6397,1.5442,1.6075,1.6104,1.5936,1.6838,1.6215,1.5273,1.7028,1.5041,1.4468,1.6387,1.6264,1.6338,1.2911,1.6035,1.5023,1.6094,1.5197,1.64,1.5258,1.4222,1.3991,1.5288,1.5742,1.5823,1.6041,1.4957,1.6185,1.618,1.4436,1.5752,1.7161,1.5199,1.491,1.6271,1.5492,1.6315,1.6787,1.4151,1.4035,1.6019,1.5253,1.4277,1.5412,1.3611,1.5431,1.667,1.7299,1.5228,1.4364,1.4924,1.522,1.1402,1.6887,1.5633,1.5317,1.5091,1.4949,1.6569,1.6132,1.619,1.6737,1.6381,1.549,1.4829,1.5676,1.6798,1.6314,1.552,1.3924,1.6466,1.3628,1.6156,1.5934,1.5501,1.4658,1.5003,1.5921,1.6922,1.6178,1.3084,1.7201,1.6029,1.5937,1.7079,1.554,1.5154,1.5373,1.9138,1.6874,1.5218,1.5474,1.5053,1.4482,1.6017,1.5704,1.4538,1.5343,1.5711,1.5468,1.5571,1.345,1.7633,1.6461],"y":[0.7822,0.7457,0.8213,0.7169,0.8313,0.729,0.7774,0.8527,0.7814,0.7732,0.7882,0.8417,0.7564,0.7601,0.7808,0.759,0.7277,0.7581,0.7801,0.8218,0.7261,0.8557,0.7716,0.7304,0.7229,0.7869,0.8023,0.7433,0.6712,0.7073,0.756,0.7471,0.8866,0.7516,0.7407,0.768,0.8132,0.7516,0.7791,0.7403,0.8142,0.6677,0.7567,0.773,0.7638,0.796,0.7818,0.7882,0.8142,0.7477,0.9092,0.8216,0.8595,0.8862,0.7768,0.8536,0.784,0.782,0.8281,0.6966,0.7538,0.794,0.8024,0.7968,0.7329,0.8398,0.8543,0.7549,0.7666,0.8807,0.8662,0.8292,0.6757,0.7818,0.8239,0.844,0.8174,0.8154,0.8075,0.7228,0.8252,0.9053,0.8243,0.9378,0.7519,0.7154,0.7466,0.7683,0.797,0.8122,0.8705,0.7233,0.8025,0.6647,0.8037,0.7861,0.6642,0.7589,0.7898,0.7788,0.8036,0.8391,0.7097,0.7747,0.7269,0.7987,0.7722,0.7999,0.7386,0.7664,0.8872,0.7525,0.8049,0.7814,0.8008,0.7694,0.7423,0.7619,0.8012,0.784,0.7619,0.7921,0.7763,0.8182],"text":["FeO: 1.4829<br />CaO: 0.7822<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5334<br />CaO: 0.7457<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5915<br />CaO: 0.8213<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4596<br />CaO: 0.7169<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5658<br />CaO: 0.8313<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4510<br />CaO: 0.7290<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5396<br />CaO: 0.7774<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5186<br />CaO: 0.8527<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4584<br />CaO: 0.7814<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6774<br />CaO: 0.7732<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6552<br />CaO: 0.7882<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5205<br />CaO: 0.8417<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5743<br />CaO: 0.7564<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7267<br />CaO: 0.7601<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4836<br />CaO: 0.7808<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4749<br />CaO: 0.7590<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4743<br />CaO: 0.7277<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4754<br />CaO: 0.7581<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3884<br />CaO: 0.7801<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6397<br />CaO: 0.8218<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5442<br />CaO: 0.7261<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6075<br />CaO: 0.8557<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6104<br />CaO: 0.7716<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5936<br />CaO: 0.7304<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6838<br />CaO: 0.7229<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6215<br />CaO: 0.7869<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5273<br />CaO: 0.8023<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7028<br />CaO: 0.7433<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5041<br />CaO: 0.6712<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4468<br />CaO: 0.7073<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6387<br />CaO: 0.7560<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6264<br />CaO: 0.7471<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6338<br />CaO: 0.8866<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.2911<br />CaO: 0.7516<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6035<br />CaO: 0.7407<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5023<br />CaO: 0.7680<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6094<br />CaO: 0.8132<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5197<br />CaO: 0.7516<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6400<br />CaO: 0.7791<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5258<br />CaO: 0.7403<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4222<br />CaO: 0.8142<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3991<br />CaO: 0.6677<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5288<br />CaO: 0.7567<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5742<br />CaO: 0.7730<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5823<br />CaO: 0.7638<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6041<br />CaO: 0.7960<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4957<br />CaO: 0.7818<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6185<br />CaO: 0.7882<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6180<br />CaO: 0.8142<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4436<br />CaO: 0.7477<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5752<br />CaO: 0.9092<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7161<br />CaO: 0.8216<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5199<br />CaO: 0.8595<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4910<br />CaO: 0.8862<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6271<br />CaO: 0.7768<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5492<br />CaO: 0.8536<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6315<br />CaO: 0.7840<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6787<br />CaO: 0.7820<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4151<br />CaO: 0.8281<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4035<br />CaO: 0.6966<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6019<br />CaO: 0.7538<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5253<br />CaO: 0.7940<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4277<br />CaO: 0.8024<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5412<br />CaO: 0.7968<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3611<br />CaO: 0.7329<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5431<br />CaO: 0.8398<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6670<br />CaO: 0.8543<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7299<br />CaO: 0.7549<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5228<br />CaO: 0.7666<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4364<br />CaO: 0.8807<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4924<br />CaO: 0.8662<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5220<br />CaO: 0.8292<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.1402<br />CaO: 0.6757<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6887<br />CaO: 0.7818<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5633<br />CaO: 0.8239<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5317<br />CaO: 0.8440<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5091<br />CaO: 0.8174<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4949<br />CaO: 0.8154<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6569<br />CaO: 0.8075<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6132<br />CaO: 0.7228<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6190<br />CaO: 0.8252<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6737<br />CaO: 0.9053<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6381<br />CaO: 0.8243<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5490<br />CaO: 0.9378<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4829<br />CaO: 0.7519<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5676<br />CaO: 0.7154<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6798<br />CaO: 0.7466<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6314<br />CaO: 0.7683<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5520<br />CaO: 0.7970<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3924<br />CaO: 0.8122<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6466<br />CaO: 0.8705<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3628<br />CaO: 0.7233<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6156<br />CaO: 0.8025<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5934<br />CaO: 0.6647<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5501<br />CaO: 0.8037<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4658<br />CaO: 0.7861<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5003<br />CaO: 0.6642<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5921<br />CaO: 0.7589<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6922<br />CaO: 0.7898<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6178<br />CaO: 0.7788<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3084<br />CaO: 0.8036<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7201<br />CaO: 0.8391<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6029<br />CaO: 0.7097<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5937<br />CaO: 0.7747<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7079<br />CaO: 0.7269<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5540<br />CaO: 0.7987<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5154<br />CaO: 0.7722<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5373<br />CaO: 0.7999<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.9138<br />CaO: 0.7386<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6874<br />CaO: 0.7664<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5218<br />CaO: 0.8872<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5474<br />CaO: 0.7525<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5053<br />CaO: 0.8049<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4482<br />CaO: 0.7814<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6017<br />CaO: 0.8008<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5704<br />CaO: 0.7694<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.4538<br />CaO: 0.7423<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5343<br />CaO: 0.7619<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5711<br />CaO: 0.8012<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5468<br />CaO: 0.7840<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.5571<br />CaO: 0.7619<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.3450<br />CaO: 0.7921<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.7633<br />CaO: 0.7763<br />id: Borrobol Tephra<br />id: Borrobol Tephra","FeO: 1.6461<br />CaO: 0.8182<br />id: Borrobol Tephra<br />id: Borrobol Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(124,188,146,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra","legendgroup":"Borrobol Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.5557,1.5329,1.5704,1.6236,1.4647,1.4913,1.1509,1.2205,1.3866,1.329,1.4184,1.2181,1.6155,1.2151,1.1694,1.3604,1.2176,1.2409,1.2833,1.3667,1.1153],"y":[0.8486,0.8787,0.8667,0.8431,0.8238,0.7407,0.6578,0.5896,0.643,0.6603,0.7285,0.7111,0.644,0.6373,0.6328,0.6782,0.5704,0.6997,0.6165,0.7084,0.5725],"text":["FeO: 1.5557<br />CaO: 0.8486<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.5329<br />CaO: 0.8787<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.5704<br />CaO: 0.8667<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.6236<br />CaO: 0.8431<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.4647<br />CaO: 0.8238<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.4913<br />CaO: 0.7407<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.1509<br />CaO: 0.6578<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2205<br />CaO: 0.5896<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.3866<br />CaO: 0.6430<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.3290<br />CaO: 0.6603<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.4184<br />CaO: 0.7285<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2181<br />CaO: 0.7111<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.6155<br />CaO: 0.6440<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2151<br />CaO: 0.6373<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.1694<br />CaO: 0.6328<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.3604<br />CaO: 0.6782<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2176<br />CaO: 0.5704<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2409<br />CaO: 0.6997<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.2833<br />CaO: 0.6165<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.3667<br />CaO: 0.7084<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK","FeO: 1.1153<br />CaO: 0.5725<br />id: Borrobol Tephra - ASHIK<br />id: Borrobol Tephra - ASHIK"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(177,14,137,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Borrobol Tephra - ASHIK","legendgroup":"Borrobol Tephra - ASHIK","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.4536,1.445,1.5122,1.5621,1.6022,1.476,1.6259,1.5315,1.5183,1.6955,1.6632,1.3014,1.4657,1.6839,1.3647,1.5479,1.6219,1.6722,1.402,1.6388,1.482,1.5805,1.6949,1.3482,1.5915,1.5549,1.3531,1.4831],"y":[0.8221,0.8115,0.7074,0.7912,0.8141,0.7299,0.7868,0.7667,0.75,0.7664,0.7352,0.797,0.8185,0.8934,0.8209,0.8305,0.8177,0.7666,0.7061,0.7202,0.7538,0.7855,0.8142,0.659,0.7041,0.6523,0.6582,0.7839],"text":["FeO: 1.4536<br />CaO: 0.8221<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4450<br />CaO: 0.8115<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5122<br />CaO: 0.7074<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5621<br />CaO: 0.7912<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6022<br />CaO: 0.8141<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4760<br />CaO: 0.7299<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6259<br />CaO: 0.7868<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5315<br />CaO: 0.7667<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5183<br />CaO: 0.7500<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6955<br />CaO: 0.7664<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6632<br />CaO: 0.7352<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.3014<br />CaO: 0.7970<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4657<br />CaO: 0.8185<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6839<br />CaO: 0.8934<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.3647<br />CaO: 0.8209<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5479<br />CaO: 0.8305<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6219<br />CaO: 0.8177<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6722<br />CaO: 0.7666<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4020<br />CaO: 0.7061<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6388<br />CaO: 0.7202<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4820<br />CaO: 0.7538<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5805<br />CaO: 0.7855<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.6949<br />CaO: 0.8142<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.3482<br />CaO: 0.6590<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5915<br />CaO: 0.7041<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.5549<br />CaO: 0.6523<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.3531<br />CaO: 0.6582<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra","FeO: 1.4831<br />CaO: 0.7839<br />id: CRUM1 597 Tephra<br />id: CRUM1 597 Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(56,75,39,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"CRUM1 597 Tephra","legendgroup":"CRUM1 597 Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.4239,1.3992,1.6169,1.511,1.7797,1.4837,1.5169,1.4977,1.7797,1.5537,1.3727,1.6259,1.1187,1.4831,1.4908,1.5049,1.4448,1.6685,1.5434,1.4823,1.5478,1.4628,1.6112,1.5309,1.461,1.4981,1.4122,1.5463,1.3792,1.2068,1.0382,1.3191,1.4838,1.53,1.5591,1.4886,1.6672,1.6617,1.6473,1.4253,1.6148,1.2589,1.3156,1.1689,1.3964,1.2135,1.2766,0.9823,1.6758,1.113,1.3973,1.2582,1.3143,1.4523,1.3777,1.5464,1.052,1.488,1.4843,1.4091,1.6465,1.4594,1.4296,1.4021,1.1728,1.0362,1.2175,1.1409,1.1168,1.314,1.1131,1.27,1.2544,1.4209,1.3973,1.1771,1.1097,0.9711,1.8068,2.0565,1.3435,1.179,1.8985,1.057,1.167,1.4674,1.2782,1.3882,1.1677,1.4395,1.1583,1.5199,1.3316,1.4004,1.0589,1.2798,1.1018,1.4023,1.5622,1.4493,1.4068,1.5177,1.277,1.3755,1.483,1.345,1.5268,1.4329,1.4316,1.4547,1.2878,1.4722,1.0601,1.4174,1.1805,1.112,1.3872,1.4653,1.0683,1.4402,1.2821,1.4674,1.545,1.2092,1.4913,1.2449,1.0435,1.1614,0.9902,1.0491,0.9818,1.2806,1.2846,1.2547,1.6552,1.1489,1.5655,1.5375,1.5062,1.5625,1.5412,1.5373,1.4729,1.2296,1.1774,1.1908,1.3834,1.3145,1.481,1.3072,1.3966,1.2837,1.1684,1.3919,1.3378,1.1592,1.3975,1.3529,1.804,1.1856,1.1072,1.064,1.2698,1.1233,0.8976,1.3406,0.9696,1.2849,1.4364,1.1794,1.2033],"y":[0.7187,0.6785,0.7077,0.9433,0.8528,0.7712,0.7491,0.7389,0.7848,0.7924,0.5287,0.8265,0.6885,0.6968,0.7936,0.7631,0.8421,0.798,0.8183,0.6866,0.7862,0.6856,0.7733,0.7465,0.7963,0.7593,0.7874,0.7553,0.7296,0.829,0.8098,0.9043,0.8046,0.7702,0.7743,0.7918,0.5947,0.7832,0.6527,0.8024,0.8284,0.6065,0.666,0.6986,0.7686,0.8038,0.6769,0.5509,0.6683,0.6841,0.6214,0.6899,0.7344,0.6898,0.5839,0.7322,0.5549,0.7562,0.8519,0.6467,0.7673,0.6303,0.8071,0.6565,0.5974,0.5553,0.5941,0.6331,0.5991,0.6106,0.6197,0.6246,0.6235,0.6693,0.6763,0.5813,0.5288,0.5901,0.6206,0.9126,0.6085,0.6009,1.0087,0.6003,0.5494,0.6814,0.5814,0.665,0.6266,0.6705,0.5181,0.6972,0.7195,0.6077,0.5885,0.6329,0.5672,0.6486,0.6543,0.6277,0.5998,0.6703,0.6081,0.6341,0.7612,0.5379,0.7111,0.643,0.6808,0.745,0.5948,0.6502,0.5537,0.6898,0.545,0.5743,0.6023,0.662,0.509,0.6697,0.6371,0.6668,0.5674,0.585,0.665,0.6439,0.5451,0.596,0.5292,0.6546,0.5839,0.6039,0.65,0.7173,0.9806,0.7642,0.7565,0.7952,0.7531,0.7707,0.8023,0.7316,0.7891,0.6505,0.7247,0.622,0.7002,0.6138,0.6498,0.7048,0.6414,0.6709,0.7378,0.6915,0.5595,0.6497,0.6257,0.6815,1.0685,0.6389,0.5695,0.9084,0.6387,0.5827,0.6259,0.5842,0.6437,0.5826,0.6406,0.7078,0.6729],"text":["FeO: 1.4239<br />CaO: 0.7187<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3992<br />CaO: 0.6785<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6169<br />CaO: 0.7077<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5110<br />CaO: 0.9433<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.7797<br />CaO: 0.8528<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4837<br />CaO: 0.7712<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5169<br />CaO: 0.7491<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4977<br />CaO: 0.7389<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.7797<br />CaO: 0.7848<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5537<br />CaO: 0.7924<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3727<br />CaO: 0.5287<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6259<br />CaO: 0.8265<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1187<br />CaO: 0.6885<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4831<br />CaO: 0.6968<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4908<br />CaO: 0.7936<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5049<br />CaO: 0.7631<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4448<br />CaO: 0.8421<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6685<br />CaO: 0.7980<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5434<br />CaO: 0.8183<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4823<br />CaO: 0.6866<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5478<br />CaO: 0.7862<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4628<br />CaO: 0.6856<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6112<br />CaO: 0.7733<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5309<br />CaO: 0.7465<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4610<br />CaO: 0.7963<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4981<br />CaO: 0.7593<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4122<br />CaO: 0.7874<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5463<br />CaO: 0.7553<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3792<br />CaO: 0.7296<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2068<br />CaO: 0.8290<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0382<br />CaO: 0.8098<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3191<br />CaO: 0.9043<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4838<br />CaO: 0.8046<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5300<br />CaO: 0.7702<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5591<br />CaO: 0.7743<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4886<br />CaO: 0.7918<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6672<br />CaO: 0.5947<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6617<br />CaO: 0.7832<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6473<br />CaO: 0.6527<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4253<br />CaO: 0.8024<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6148<br />CaO: 0.8284<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2589<br />CaO: 0.6065<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3156<br />CaO: 0.6660<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1689<br />CaO: 0.6986<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3964<br />CaO: 0.7686<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2135<br />CaO: 0.8038<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2766<br />CaO: 0.6769<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9823<br />CaO: 0.5509<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6758<br />CaO: 0.6683<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1130<br />CaO: 0.6841<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3973<br />CaO: 0.6214<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2582<br />CaO: 0.6899<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3143<br />CaO: 0.7344<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4523<br />CaO: 0.6898<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3777<br />CaO: 0.5839<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5464<br />CaO: 0.7322<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0520<br />CaO: 0.5549<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4880<br />CaO: 0.7562<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4843<br />CaO: 0.8519<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4091<br />CaO: 0.6467<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6465<br />CaO: 0.7673<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4594<br />CaO: 0.6303<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4296<br />CaO: 0.8071<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4021<br />CaO: 0.6565<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1728<br />CaO: 0.5974<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0362<br />CaO: 0.5553<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2175<br />CaO: 0.5941<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1409<br />CaO: 0.6331<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1168<br />CaO: 0.5991<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3140<br />CaO: 0.6106<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1131<br />CaO: 0.6197<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2700<br />CaO: 0.6246<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2544<br />CaO: 0.6235<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4209<br />CaO: 0.6693<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3973<br />CaO: 0.6763<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1771<br />CaO: 0.5813<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1097<br />CaO: 0.5288<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9711<br />CaO: 0.5901<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.8068<br />CaO: 0.6206<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 2.0565<br />CaO: 0.9126<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3435<br />CaO: 0.6085<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1790<br />CaO: 0.6009<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.8985<br />CaO: 1.0087<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0570<br />CaO: 0.6003<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1670<br />CaO: 0.5494<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4674<br />CaO: 0.6814<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2782<br />CaO: 0.5814<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3882<br />CaO: 0.6650<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1677<br />CaO: 0.6266<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4395<br />CaO: 0.6705<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1583<br />CaO: 0.5181<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5199<br />CaO: 0.6972<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3316<br />CaO: 0.7195<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4004<br />CaO: 0.6077<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0589<br />CaO: 0.5885<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2798<br />CaO: 0.6329<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1018<br />CaO: 0.5672<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4023<br />CaO: 0.6486<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5622<br />CaO: 0.6543<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4493<br />CaO: 0.6277<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4068<br />CaO: 0.5998<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5177<br />CaO: 0.6703<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2770<br />CaO: 0.6081<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3755<br />CaO: 0.6341<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4830<br />CaO: 0.7612<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3450<br />CaO: 0.5379<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5268<br />CaO: 0.7111<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4329<br />CaO: 0.6430<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4316<br />CaO: 0.6808<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4547<br />CaO: 0.7450<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2878<br />CaO: 0.5948<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4722<br />CaO: 0.6502<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0601<br />CaO: 0.5537<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4174<br />CaO: 0.6898<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1805<br />CaO: 0.5450<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1120<br />CaO: 0.5743<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3872<br />CaO: 0.6023<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4653<br />CaO: 0.6620<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0683<br />CaO: 0.5090<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4402<br />CaO: 0.6697<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2821<br />CaO: 0.6371<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4674<br />CaO: 0.6668<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5450<br />CaO: 0.5674<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2092<br />CaO: 0.5850<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4913<br />CaO: 0.6650<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2449<br />CaO: 0.6439<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0435<br />CaO: 0.5451<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1614<br />CaO: 0.5960<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9902<br />CaO: 0.5292<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0491<br />CaO: 0.6546<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9818<br />CaO: 0.5839<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2806<br />CaO: 0.6039<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2846<br />CaO: 0.6500<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2547<br />CaO: 0.7173<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.6552<br />CaO: 0.9806<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1489<br />CaO: 0.7642<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5655<br />CaO: 0.7565<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5375<br />CaO: 0.7952<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5062<br />CaO: 0.7531<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5625<br />CaO: 0.7707<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5412<br />CaO: 0.8023<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.5373<br />CaO: 0.7316<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4729<br />CaO: 0.7891<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2296<br />CaO: 0.6505<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1774<br />CaO: 0.7247<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1908<br />CaO: 0.6220<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3834<br />CaO: 0.7002<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3145<br />CaO: 0.6138<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4810<br />CaO: 0.6498<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3072<br />CaO: 0.7048<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3966<br />CaO: 0.6414<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2837<br />CaO: 0.6709<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1684<br />CaO: 0.7378<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3919<br />CaO: 0.6915<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3378<br />CaO: 0.5595<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1592<br />CaO: 0.6497<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3975<br />CaO: 0.6257<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3529<br />CaO: 0.6815<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.8040<br />CaO: 1.0685<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1856<br />CaO: 0.6389<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1072<br />CaO: 0.5695<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.0640<br />CaO: 0.9084<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2698<br />CaO: 0.6387<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1233<br />CaO: 0.5827<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.8976<br />CaO: 0.6259<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.3406<br />CaO: 0.5842<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 0.9696<br />CaO: 0.6437<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2849<br />CaO: 0.5826<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.4364<br />CaO: 0.6406<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.1794<br />CaO: 0.7078<br />id: Penifiler Tephra<br />id: Penifiler Tephra","FeO: 1.2033<br />CaO: 0.6729<br />id: Penifiler Tephra<br />id: Penifiler Tephra"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(248,150,253,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"Penifiler Tephra","legendgroup":"Penifiler Tephra","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.566903066],"y":[0.80947862],"text":"FeO: 1.5669031<br />CaO: 0.8094786<br />id2: 380<br />id2: 380","type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(32,154,36,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"380","legendgroup":"380","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.589080907,1.356182144],"y":[0.775546214,0.648473777],"text":["FeO: 1.5890809<br />CaO: 0.7755462<br />id2: 387<br />id2: 387","FeO: 1.3561821<br />CaO: 0.6484738<br />id2: 387<br />id2: 387"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(167,105,238,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"387","legendgroup":"387","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.327348863,1.462955218],"y":[0.646027115,0.895555722],"text":["FeO: 1.3273489<br />CaO: 0.6460271<br />id2: 410<br />id2: 410","FeO: 1.4629552<br />CaO: 0.8955557<br />id2: 410<br />id2: 410"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(180,196,40,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"410","legendgroup":"410","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.540268936,1.175635117,1.381957894,1.434367105,1.510464873,1.635964285,1.384508852,1.507735064],"y":[0.851447145,0.568120339,0.667461363,0.639312,0.707965339,0.948737261,0.671188533,0.816871176],"text":["FeO: 1.5402689<br />CaO: 0.8514471<br />id2: 420<br />id2: 420","FeO: 1.1756351<br />CaO: 0.5681203<br />id2: 420<br />id2: 420","FeO: 1.3819579<br />CaO: 0.6674614<br />id2: 420<br />id2: 420","FeO: 1.4343671<br />CaO: 0.6393120<br />id2: 420<br />id2: 420","FeO: 1.5104649<br />CaO: 0.7079653<br />id2: 420<br />id2: 420","FeO: 1.6359643<br />CaO: 0.9487373<br />id2: 420<br />id2: 420","FeO: 1.3845089<br />CaO: 0.6711885<br />id2: 420<br />id2: 420","FeO: 1.5077351<br />CaO: 0.8168712<br />id2: 420<br />id2: 420"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(227,3,3,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"420","legendgroup":"420","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.231323282,1.374428498,1.145669374,1.136481934],"y":[0.718032606,0.721044244,0.647127957,0.594943139],"text":["FeO: 1.2313233<br />CaO: 0.7180326<br />id2: 442<br />id2: 442","FeO: 1.3744285<br />CaO: 0.7210442<br />id2: 442<br />id2: 442","FeO: 1.1456694<br />CaO: 0.6471280<br />id2: 442<br />id2: 442","FeO: 1.1364819<br />CaO: 0.5949431<br />id2: 442<br />id2: 442"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(0,0,0,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"442","legendgroup":"442","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.543690856,1.679152512,1.730020159,1.589325068,1.543418805,1.467347302,1.610727455],"y":[0.758712474,0.810129327,0.868793842,0.819970921,0.838197232,0.881742144,0.741885497],"text":["FeO: 1.5436909<br />CaO: 0.7587125<br />id2: 454<br />id2: 454","FeO: 1.6791525<br />CaO: 0.8101293<br />id2: 454<br />id2: 454","FeO: 1.7300202<br />CaO: 0.8687938<br />id2: 454<br />id2: 454","FeO: 1.5893251<br />CaO: 0.8199709<br />id2: 454<br />id2: 454","FeO: 1.5434188<br />CaO: 0.8381972<br />id2: 454<br />id2: 454","FeO: 1.4673473<br />CaO: 0.8817421<br />id2: 454<br />id2: 454","FeO: 1.6107275<br />CaO: 0.7418855<br />id2: 454<br />id2: 454"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(239,19,157,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"454","legendgroup":"454","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.308798825,1.241149354,1.403548948],"y":[0.798151338,0.680282883,0.923268596],"text":["FeO: 1.3087988<br />CaO: 0.7981513<br />id2: 475<br />id2: 475","FeO: 1.2411494<br />CaO: 0.6802829<br />id2: 475<br />id2: 475","FeO: 1.4035489<br />CaO: 0.9232686<br />id2: 475<br />id2: 475"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(58,112,15,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"475","legendgroup":"475","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.496118283,1.43883468,1.519864162],"y":[0.8535951,0.629978518,0.704111993],"text":["FeO: 1.4961183<br />CaO: 0.8535951<br />id2: 480<br />id2: 480","FeO: 1.4388347<br />CaO: 0.6299785<br />id2: 480<br />id2: 480","FeO: 1.5198642<br />CaO: 0.7041120<br />id2: 480<br />id2: 480"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(82,136,255,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"480","legendgroup":"480","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.146422163,1.269997296,1.78231557,1.670397814,1.77810548,1.254992564,1.059621806,0.983517657,1.328409251,1.349998744,1.307926356,1.348099781,1.335781171,1.337692356,1.105103764,0.981171515],"y":[0.570358769,0.579615071,0.877442815,0.815246062,0.896322182,0.516889397,0.59133395,0.573205101,0.717803416,0.700860213,0.690968178,0.633580721,0.658143021,0.692897153,0.630512982,0.599112153],"text":["FeO: 1.1464222<br />CaO: 0.5703588<br />id2: 505-510<br />id2: 505-510","FeO: 1.2699973<br />CaO: 0.5796151<br />id2: 505-510<br />id2: 505-510","FeO: 1.7823156<br />CaO: 0.8774428<br />id2: 505-510<br />id2: 505-510","FeO: 1.6703978<br />CaO: 0.8152461<br />id2: 505-510<br />id2: 505-510","FeO: 1.7781055<br />CaO: 0.8963222<br />id2: 505-510<br />id2: 505-510","FeO: 1.2549926<br />CaO: 0.5168894<br />id2: 505-510<br />id2: 505-510","FeO: 1.0596218<br />CaO: 0.5913339<br />id2: 505-510<br />id2: 505-510","FeO: 0.9835177<br />CaO: 0.5732051<br />id2: 505-510<br />id2: 505-510","FeO: 1.3284093<br />CaO: 0.7178034<br />id2: 505-510<br />id2: 505-510","FeO: 1.3499987<br />CaO: 0.7008602<br />id2: 505-510<br />id2: 505-510","FeO: 1.3079264<br />CaO: 0.6909682<br />id2: 505-510<br />id2: 505-510","FeO: 1.3480998<br />CaO: 0.6335807<br />id2: 505-510<br />id2: 505-510","FeO: 1.3357812<br />CaO: 0.6581430<br />id2: 505-510<br />id2: 505-510","FeO: 1.3376924<br />CaO: 0.6928972<br />id2: 505-510<br />id2: 505-510","FeO: 1.1051038<br />CaO: 0.6305130<br />id2: 505-510<br />id2: 505-510","FeO: 0.9811715<br />CaO: 0.5991122<br />id2: 505-510<br />id2: 505-510"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(230,71,1,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"505-510","legendgroup":"505-510","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.423152203,1.275338368,1.475434384,1.23233383,1.23416879,1.320239218,1.76242383,1.720857989,1.692683707,1.258725695],"y":[0.653510818,0.691483798,0.505878177,0.512234521,0.585918517,0.618963971,0.927524708,0.911221858,0.901148484,0.655831135],"text":["FeO: 1.4231522<br />CaO: 0.6535108<br />id2: 520-524<br />id2: 520-524","FeO: 1.2753384<br />CaO: 0.6914838<br />id2: 520-524<br />id2: 520-524","FeO: 1.4754344<br />CaO: 0.5058782<br />id2: 520-524<br />id2: 520-524","FeO: 1.2323338<br />CaO: 0.5122345<br />id2: 520-524<br />id2: 520-524","FeO: 1.2341688<br />CaO: 0.5859185<br />id2: 520-524<br />id2: 520-524","FeO: 1.3202392<br />CaO: 0.6189640<br />id2: 520-524<br />id2: 520-524","FeO: 1.7624238<br />CaO: 0.9275247<br />id2: 520-524<br />id2: 520-524","FeO: 1.7208580<br />CaO: 0.9112219<br />id2: 520-524<br />id2: 520-524","FeO: 1.6926837<br />CaO: 0.9011485<br />id2: 520-524<br />id2: 520-524","FeO: 1.2587257<br />CaO: 0.6558311<br />id2: 520-524<br />id2: 520-524"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(127,154,245,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"520-524","legendgroup":"520-524","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.582629152,1.740343142],"y":[0.883503059,0.851590652],"text":["FeO: 1.5826292<br />CaO: 0.8835031<br />id2: 575-579<br />id2: 575-579","FeO: 1.7403431<br />CaO: 0.8515907<br />id2: 575-579<br />id2: 575-579"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(243,109,32,1)","opacity":0.8,"size":15.1181102362205,"symbol":"circle","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"575-579","legendgroup":"575-579","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.592846032,1.454018069,1.032220336,1.600665201,1.510187264,1.513549212,1.486457113],"y":[0.869408726,0.807364059,0.832697004,0.864698469,0.930499303,0.898787405,0.898617878],"text":["FeO: 1.5928460<br />CaO: 0.8694087<br />id2: 605-609<br />id2: 605-609","FeO: 1.4540181<br />CaO: 0.8073641<br />id2: 605-609<br />id2: 605-609","FeO: 1.0322203<br />CaO: 0.8326970<br />id2: 605-609<br />id2: 605-609","FeO: 1.6006652<br />CaO: 0.8646985<br />id2: 605-609<br />id2: 605-609","FeO: 1.5101873<br />CaO: 0.9304993<br />id2: 605-609<br />id2: 605-609","FeO: 1.5135492<br />CaO: 0.8987874<br />id2: 605-609<br />id2: 605-609","FeO: 1.4864571<br />CaO: 0.8986179<br />id2: 605-609<br />id2: 605-609"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(11,48,117,1)","opacity":0.8,"size":15.1181102362205,"symbol":"square","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"605-609","legendgroup":"605-609","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.666886879,1.791465336,1.351467312,1.666869297,1.451659346,1.600551706,1.55411259,1.56709232,1.478648421],"y":[0.768003928,0.844801215,0.898014464,0.892717046,0.829175589,0.781443992,0.883741559,0.896515265,0.943095548],"text":["FeO: 1.6668869<br />CaO: 0.7680039<br />id2: 655-659<br />id2: 655-659","FeO: 1.7914653<br />CaO: 0.8448012<br />id2: 655-659<br />id2: 655-659","FeO: 1.3514673<br />CaO: 0.8980145<br />id2: 655-659<br />id2: 655-659","FeO: 1.6668693<br />CaO: 0.8927170<br />id2: 655-659<br />id2: 655-659","FeO: 1.4516593<br />CaO: 0.8291756<br />id2: 655-659<br />id2: 655-659","FeO: 1.6005517<br />CaO: 0.7814440<br />id2: 655-659<br />id2: 655-659","FeO: 1.5541126<br />CaO: 0.8837416<br />id2: 655-659<br />id2: 655-659","FeO: 1.5670923<br />CaO: 0.8965153<br />id2: 655-659<br />id2: 655-659","FeO: 1.4786484<br />CaO: 0.9430955<br />id2: 655-659<br />id2: 655-659"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(193,133,34,1)","opacity":0.8,"size":15.1181102362205,"symbol":"diamond","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"655-659","legendgroup":"655-659","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.508609903,1.587610863,1.626198679,1.742079365,1.538806406,1.610573053,1.543290583],"y":[0.86808907,0.878880201,0.831028416,0.939346265,0.820856619,0.850725729,0.877938903],"text":["FeO: 1.5086099<br />CaO: 0.8680891<br />id2: 795-799<br />id2: 795-799","FeO: 1.5876109<br />CaO: 0.8788802<br />id2: 795-799<br />id2: 795-799","FeO: 1.6261987<br />CaO: 0.8310284<br />id2: 795-799<br />id2: 795-799","FeO: 1.7420794<br />CaO: 0.9393463<br />id2: 795-799<br />id2: 795-799","FeO: 1.5388064<br />CaO: 0.8208566<br />id2: 795-799<br />id2: 795-799","FeO: 1.6105731<br />CaO: 0.8507257<br />id2: 795-799<br />id2: 795-799","FeO: 1.5432906<br />CaO: 0.8779389<br />id2: 795-799<br />id2: 795-799"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(150,52,166,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-up","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"795-799","legendgroup":"795-799","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null},{"x":[1.504598316,1.428704877,1.52309403],"y":[0.883275133,0.897624522,0.915725245],"text":["FeO: 1.5045983<br />CaO: 0.8832751<br />id2: 855-859<br />id2: 855-859","FeO: 1.4287049<br />CaO: 0.8976245<br />id2: 855-859<br />id2: 855-859","FeO: 1.5230940<br />CaO: 0.9157252<br />id2: 855-859<br />id2: 855-859"],"type":"scatter","mode":"markers","marker":{"autocolorscale":false,"color":"rgba(29,125,70,1)","opacity":0.8,"size":15.1181102362205,"symbol":"triangle-down","line":{"width":1.88976377952756,"color":"rgba(0,0,0,1)"}},"hoveron":"points","name":"855-859","legendgroup":"855-859","showlegend":true,"xaxis":"x","yaxis":"y","hoverinfo":"text","frame":null}],"layout":{"margin":{"t":25.1324200913242,"r":7.30593607305936,"b":55.2926525529265,"l":64.0929846409298},"plot_bgcolor":"rgba(255,255,255,1)","paper_bgcolor":"rgba(255,255,255,1)","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187},"xaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":false,"range":[0.839655,2.114445],"tickmode":"array","ticktext":["0.9","1.2","1.5","1.8","2.1"],"tickvals":[0.9,1.2,1.5,1.8,2.1],"categoryorder":"array","categoryarray":["0.9","1.2","1.5","1.8","2.1"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"y","title":{"text":"FeO (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"yaxis":{"domain":[0,1],"automargin":true,"type":"linear","autorange":false,"range":[0.47734208585,1.10513609115],"tickmode":"array","ticktext":["0.5","0.6","0.7","0.8","0.9","1.0","1.1"],"tickvals":[0.5,0.6,0.7,0.8,0.9,1,1.1],"categoryorder":"array","categoryarray":["0.5","0.6","0.7","0.8","0.9","1.0","1.1"],"nticks":null,"ticks":"outside","tickcolor":"rgba(51,51,51,1)","ticklen":3.65296803652968,"tickwidth":0.66417600664176,"showticklabels":true,"tickfont":{"color":"rgba(77,77,77,1)","family":"","size":21.2536322125363},"tickangle":-0,"showline":false,"linecolor":null,"linewidth":0,"showgrid":false,"gridcolor":null,"gridwidth":0,"zeroline":false,"anchor":"x","title":{"text":"CaO (wt%)","font":{"color":"rgba(0,0,0,1)","family":"","size":21.2536322125363}},"hoverformat":".2f"},"shapes":[{"type":"rect","fillcolor":"transparent","line":{"color":"rgba(51,51,51,1)","width":0.66417600664176,"linetype":"solid"},"yref":"paper","xref":"paper","x0":0,"x1":1,"y0":0,"y1":1}],"showlegend":true,"legend":{"bgcolor":"rgba(255,255,255,1)","bordercolor":"transparent","borderwidth":1.88976377952756,"font":{"color":"rgba(0,0,0,1)","family":"","size":11.689497716895},"title":{"text":"id","font":{"color":"rgba(0,0,0,1)","family":"","size":14.6118721461187}}},"hovermode":"closest","width":1000,"height":800,"barmode":"relative"},"config":{"doubleClick":"reset","modeBarButtonsToAdd":["hoverclosest","hovercompare"],"showSendToCloud":false},"source":"A","attrs":{"724ba5c39":{"x":{},"y":{},"fill":{},"shape":{},"type":"scatter"},"72489e3aae":{"x":{},"y":{},"shape":{},"fill":{}}},"cur_data":"724ba5c39","visdat":{"724ba5c39":["function (y) ","x"],"72489e3aae":["function (y) ","x"]},"highlight":{"on":"plotly_click","persistent":false,"dynamic":false,"selectize":false,"opacityDim":0.2,"selected":{"opacity":1},"debounce":0},"shinyEvents":["plotly_hover","plotly_click","plotly_selected","plotly_relayout","plotly_brushed","plotly_brushing","plotly_clickannotation","plotly_doubleclick","plotly_deselect","plotly_afterplot","plotly_sunburstclick"],"base_url":"https://plot.ly"},"evals":[],"jsHooks":[]}</script>

# References

R. W. Le Maitre (editor), A. Streckeisen, B. Zanettin, M. J. Le Bas, B.
Bonin, P. Bateman, G. Bellieni, A. Dudek, S. Efremova, J. Keller, J.
Lamere, P. A. Sabine, R. Schmid, H. Sorensen, and A. R. Woolley, Igneous
Rocks: A Classification and Glossary of Terms, Recommendations of the
International Union of Geological Sciences, Subcommission of the
Systematics of Igneous Rocks. Cambridge University Press, 2002.
